(function () {
    
	var module = angular.module('aralco.barcodesets',['ionic']);
	
	module.factory('barcodeSetFactory', function($filter) {

        var elementId = 4;

		var barcodeSets = [
			{
                ID: 1,
				name: "Manufacturer",
                desc: "Manufacturer",
                prefix: ""  
			},
			{
                ID: 2,
				name: "Supplier Barcode",
				desc: "Supplier Barcode",
                prefix: ""
			},
			{
                ID: 3,
				name: "Multipost",
				desc: "Multipost",
                prefix: ""
			}
		];

		return {
			getBarcodeSets : function(searchText) {
                return $filter('filter')(barcodeSets, {name: searchText})
			},
		    addBarcodeSet : function(barcodeSet) {
				var temp = {
                    ID: elementId++,
					name: barcodeSet.name,
                    desc: barcodeSet.desc,
                    prefix: barcodeSet.prefix
				}

				barcodeSets.push(temp);
			},
			deleteBarcodeSet: function(item) {
                var index = barcodeSets.findIndex(barcodeSet => barcodeSet.ID == item.ID);
                barcodeSets.splice(index, 1);
            },
            
            saveBarcodeSet: function(item,barcodeSet) {
                var index = barcodeSets.findIndex(barcodeSet => barcodeSet.ID == item.ID);
                barcodeSets[index].name = barcodeSet.name;
                barcodeSets[index].desc = barcodeSet.desc;
                barcodeSets[index].prefix = barcodeSet.prefix;
            },
            
            getBarcodeSetByIndex : function(item) {
                return barcodeSets.filter(barcodeSet => barcodeSet.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.barcodesets', {
			url: '/barcodesets',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'BarcodeSetController'
				}
			}
		})
		.state('tab.editbarcodesets', {
			url: '/editbarcodeset/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/barcode_sets/templates/barcode-sets-edit.html',
                    controller: 'EditBarcodeSetController'
				}
			}
		})
		.state('tab.addbarcodesets', {
			url: '/editbarcodeset/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/barcode_sets/templates/barcode-sets-edit.html',
                    controller: 'AddBarcodeSetController'
				}
			}	
		})
	}]);

    module.controller('BarcodeSetController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,barcodeSetFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Manage Barcode Sets";
        $scope.searchTitle = "Barcode Sets"

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editbarcodesets',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addbarcodesets',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        barcodeSetFactory.deleteBarcodeSet($scope.selectedItem);
                        $rootScope.$emit('updateBarcodeSets', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(barcodeSetFactory.getBarcodeSets($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateBarcodeSets', function(event, arg) {
            $scope.entries = angular.copy(barcodeSetFactory.getBarcodeSets($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditBarcodeSetController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,barcodeSetFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.barcodeSet = angular.copy(barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.barcodeSet.name;
        $scope.title = "Edit Barcode Set";

        $scope.autoFillDescription = function() {
            if($scope.barcodeSet.desc.length == 0) {
                $scope.barcodeSet.desc = $scope.barcodeSet.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.barcodeSet, barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveBarcodeSet(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveBarcodeSet = function() {
            barcodeSetFactory.saveBarcodeSet($scope.selectedItem,$scope.barcodeSet);
            $rootScope.$emit('updateBarcodeSets', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearBarcodeSet = function() {
            if(!angular.equals($scope.barcodeSet, barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveBarcodeSet(); 
                    }
                    else{
                        $scope.barcodeSet = angular.copy(barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteBarcodeSet = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    barcodeSetFactory.deleteBarcodeSet($scope.selectedItem);
                    $rootScope.$emit('updateBarcodeSets', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.barcodeSet, barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.barcodeSet = angular.copy(barcodeSetFactory.getBarcodeSetByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddBarcodeSetController', function($scope,$ionicPopup,$ionicHistory,$rootScope,barcodeSetFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Barcode Set";
        $scope.barcodeSet = {
            name : "",
            desc : "",
            prefix: ""
        }
        var oriBarcodeSet = angular.copy($scope.barcodeSet);

        $scope.autoFillDescription = function() {
            if($scope.barcodeSet.desc.length == 0) {
                $scope.barcodeSet.desc = angular.copy($scope.barcodeSet.name);
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.barcodeSet, oriBarcodeSet)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveBarcodeSet(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveBarcodeSet = function() {
            if(!angular.equals($scope.barcodeSet, oriBarcodeSet)) {
                barcodeSetFactory.addBarcodeSet($scope.barcodeSet);
                $rootScope.$emit('updateBarcodeSets', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.barcodeSet = angular.copy(oriBarcodeSet);
                })
            }
        }

        $scope.addBarcodeSet = function() {
            $scope.clearBarcodeSet();
        }

        $scope.clearBarcodeSet = function() {
            if(!angular.equals($scope.barcodeSet, oriBarcodeSet)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveBarcodeSet(); 
                    }
                    $scope.barcodeSet = angular.copy(oriBarcodeSet);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.barcodeSet, oriBarcodeSet)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.barcodeSet = angular.copy(oriBarcodeSet); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();