(function () {
    
	var module = angular.module('aralco.coupons',['ionic']);
	
	module.factory('couponFactory', function($filter) {

        var elementId = 5;

		var coupons = [
			{
                ID: 1,
                number: "C100",
                remark: "August Promo",
                value: 0,
                minPurchase: 0,
                currency: "percentage",
                validFrom: "",
                validTo: ""
			},
			{
                ID: 2,
                number: "C201",
                remark: "Weekend",
                value: 0,
                minPurchase: 0,
                currency: "percentage",
                validFrom: "",
                validTo: ""
			},
			{
                ID: 3,
				number: "C530",
                remark: "Back to School",
                value: 0,
                minPurchase: 0,
                currency: "dollar",
                validFrom: "",
                validTo: ""
			},
			{
                ID: 4,
				number: "C982",
                remark: "Seniors Day",
                value: 0,
                minPurchase: 0,
                currency: "dollar",
                validFrom: "",
                validTo: ""
			}
        ];
        
		return {
			getCoupons : function(searchText) {
                return $filter('filter')(coupons, {number: searchText})
			},
			addCoupon : function(coupon) {
				var temp = {
                    ID: elementId++,
                    number: coupon.number,
                    remark: coupon.remark,
                    value: coupon.value,
                    minPurchase: coupon.minPurchase,
                    currency: coupon.currency,
                    validFrom: coupon.validFrom,
                    validTo: coupon.validTo
				}

				coupons.push(temp);
			},
			deleteCoupon: function(item) {
                var index = coupons.findIndex(coupon => coupon.ID == item.ID);
                coupons.splice(index, 1);
            },
			saveCoupon: function(item,coupon) {
                var index = coupons.findIndex(coupon => coupon.ID == item.ID);
				coupons[index].number = coupon.number;
                coupons[index].remark = coupon.remark;
                coupons[index].value = coupon.value;
                coupons[index].minPurchase = coupon.minPurchase;
                coupons[index].currency = coupon.currency;
                coupons[index].validFrom = coupon.validFrom;
                coupons[index].validTo = coupon.validTo;
			},
			getCouponByIndex : function(item) {
                return coupons.filter(coupon => coupon.ID == item.ID)[0];
            }
		};
	});
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
    
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.coupons', {
			url: '/coupons',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/coupons/templates/coupons.html',
					controller: 'CouponController'
				}
			}
		})
		.state('tab.editcoupons', {
			url: '/editcoupon/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/coupons/templates/coupons-edit.html',
                    controller: 'EditCouponController'
				}
			}
		})
		.state('tab.addcoupons', {
			url: '/editcoupon/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/coupons/templates/coupons-edit.html',
                    controller: 'AddCouponController'
				}
			}
		})
	}]);

    module.controller('CouponController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,couponFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editCoupon' && $scope.selectedItem != null){
                $state.go('tab.editcoupons',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addCoupon'){
                $state.go('tab.addcoupons',{name: 'addCoupon'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteCoupon = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        couponFactory.deleteCoupon($scope.selectedItem);
                        $rootScope.$emit('updateCoupons', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(couponFactory.getCoupons($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateCoupons', function(event, arg) {
            $scope.entries = angular.copy(couponFactory.getCoupons($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditCouponController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,couponFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.coupon = angular.copy(couponFactory.getCouponByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.coupon.number + "- " + $scope.coupon.remark;

        
       

        
            
            {
        }
        
        $scope.saveCoupon = function() {
            if(angular.isDefined($scope.coupon.value) && angular.isDefined($scope.coupon.minPurchase)) {
                couponFactory.saveCoupon($scope.selectedItem,$scope.coupon);
                $rootScope.$emit('updateCoupons', {
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            }
            else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                })
            }
        }
      
        $scope.clearCoupon = function() {
            if(!angular.equals($scope.coupon, couponFactory.getCouponByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveCoupon(); 
                    }
                    else{
                        $scope.coupon = angular.copy(couponFactory.getCouponByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.coupon, couponFactory.getCouponByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveCoupon(); 
                        if(angular.isDefined($scope.coupon.value) && angular.isDefined($scope.coupon.minPurchase)) {
                            $ionicHistory.goBack(); 
                        }
                    }
                    else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack(); 
            }
        }

        $scope.deleteCoupon = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    couponFactory.deleteCoupon($scope.selectedItem);
                    $rootScope.$emit('updateCoupons', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.coupon, couponFactory.getCouponByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.coupon = angular.copy(couponFactory.getCouponByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack(); 
            }
        }
    })

    module.controller('AddCouponController', function($scope,$ionicPopup,$ionicHistory,$rootScope,couponFactory){
        $scope.showSearchbar = true;
        $scope.coupon = {
            number: "",
            remark: "",
            value: 0,
            minPurchase: 0,
            currency: "",
            validFrom: "",
            validTo: ""
        }
        var oriCoupon = angular.copy($scope.coupon);

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.coupon, oriCoupon)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveCoupon(); 
                        if(angular.isDefined($scope.coupon.value) && angular.isDefined($scope.coupon.minPurchase)) {
                            $ionicHistory.goBack(); 
                        }
                    }
                    else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack(); 
            }
        }
       
        $scope.saveCoupon = function() {
            if(!angular.equals($scope.coupon, oriCoupon)) {
                if(angular.isDefined($scope.coupon.value) && angular.isDefined($scope.coupon.minPurchase)) {
                    couponFactory.addCoupon($scope.coupon);
                    $rootScope.$emit('updateCoupons', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.coupon = angular.copy(oriCoupon);
                    })
                }
                else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
                
            }
        }

        $scope.addCoupon = function() {
            $scope.clearCoupon();
        }

        $scope.clearCoupon = function() {
            if(!angular.equals($scope.coupon, oriCoupon)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveCoupon();
                        if(angular.isDefined($scope.coupon.value) && angular.isDefined($scope.coupon.minPurchase)) {
                            $scope.coupon = angular.copy(oriCoupon);
                        } 
                    }
                    else {
                        $scope.coupon = angular.copy(oriCoupon);
                    }
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.coupon, oriCoupon)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.coupon = angular.copy(oriCoupon);
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();