﻿/// <reference path="../../Scripts/underscore.js" />
/// <reference path="../../js/aralco.mobile.fw/aralco.mobile.fw.js" />
(function () {

    var module = angular.module('aralco.customer', ['aralco.database', 'aralco.images', 'aralco.salutation']);

    module.config(['$stateProvider', '$urlRouterProvider', function ($stateProvider, $urlRouterProvider) {
        // Each tab has its own nav history stack:
        $stateProvider.state('tab.customer', {
            url: '/customer',
            views: {
                'tab-view': {
                    templateUrl: 'modules/customer/templates/tab-customers.html',
                    controller: 'CustomerListCtr'
                }
            }
        });

        $stateProvider.state('tab.customer-detail', {
            url: '/customer/:cid',
            views: {
                'tab-view': {
                    templateUrl: 'modules/customer/templates/tab-customer-detail.html',
                    controller: 'CustomerCtr'
                }
            }
        });


    }]);

    module.factory('customerFct', ['$q', '$http', 'ImgService', function ($q, $http, ImgService) {

        var self = this;

        function _getPicture(id) {
            var def = $q.defer();

            var imgsp = ImgService.SearchParam;
            imgsp.input = id;
            imgsp.Type = 4;

            ImgService.Search(imgsp).then(function (pic) {
                def.resolve(pic[0]);
            }, function () {
                def.resolve(null);
            });

            return def.promise;
        }

        function _search(input, page) {
            /// <summary>
            /// Search the customer by values
            /// </summary>
            /// <param name="id"></param>
            /// <param name="number"></param>
            /// <param name="company"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/Search?";
            var paging = "MaxItems={MaxItems}&Page={Page}&ForceLoad={ForceLoad}"
            var filter = "&Number={Number}&Company={Company}";

            paging = paging.replace("{MaxItems}", $f.genericReturnList)
                .replace("{Page}", page)
                .replace("{ForceLoad}", $f.ForceLoad);

            filter = filter.replace("{Number}", input || '')
                .replace("{Company}", input || '');

            url = $f.serviceUrl + url + paging + filter;

            var httpreq = {
                method: 'get',
                url: url
            };

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }

        function _get(id, page) {
            /// <summary>
            /// get the required customer
            /// </summary>
            /// <param name="id"></param>
            /// <param name="page"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/Get/{ID}?";
            var paging = "MaxItems={MaxItems}&Page={Page}&ForceLoad={ForceLoad}"

            url = url.replace("{ID}", id || '');
            paging = paging.replace("{MaxItems}", $f.genericReturnList)
                .replace("{Page}", page)
                .replace("{ForceLoad}", $f.ForceLoad);

            url = $f.serviceUrl + url + paging;

            var httpreq = {
                method: 'get',
                url: url
            };

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }

        function _detail(id, page, forceLoad) {
            /// <summary>
            /// get the required customer
            /// </summary>
            /// <param name="id"></param>
            /// <param name="page"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/Detail/{ID}?ForceLoad={ForceLoad}";

            url = $f.serviceUrl + url.replace("{ID}", id || '').replace("{ForceLoad}", forceLoad || $f.ForceLoad);

            var httpreq = {
                method: 'get',
                url: url
            };


            $http(httpreq).success(
                function (data, status, headers, config) {
                    if (data!=undefined && data != null && data.ID!=undefined) {
                        var imgsp = ImgService.SearchParam;
                        imgsp.input = data.ID;
                        imgsp.Type = 4;
                        _getPicture(data.ID).then(function (pic) {
                            data.image = pic;
                            def.resolve(data);
                        }, function () {
                            data.image = null;
                            def.resolve(data);
                        })
                    }
                    else
                        def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }

        function _post(customer) {
            /// <summary>
            /// Post the customer to the server
            /// </summary>
            /// <param name="customer"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/post/";

            url = $f.serviceUrl + url;

            var httpreq = {
                method: 'post',
                url: url,
                data: customer
            };

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }

        function _update(customer) {
            /// <summary>
            /// Post the customer to the server
            /// </summary>
            /// <param name="customer"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/update/";

            url = $f.serviceUrl + url;

            var httpreq = {
                method: 'post',
                url: url,
                data: customer
            };

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }


        function _getPoints(id) {
            /// <summary>
            /// Post the customer to the server
            /// </summary>
            /// <param name="customer"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            var url = "Customer/getPoints/" + id;

            url = $f.serviceUrl + url;

            var req = {
                method: 'get',
                url: url
            }

            $http(req).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }


        /*Post the customer to the server*/
        self.$post = _post;

        /*Update the customer to the server*/
        self.$update = _update;

        /*search for the customer*/
        self.$search = _search;

        /*get the customer*/
        self.$get = _get;

        /*Retrieve customer detail*/
        self.$detail = _detail;

        /*get customer picture*/
        self.$getPicture = _getPicture;

        /*get current customer points*/
        self.$getPoints = _getPoints;

        return self;

    }]);

    module.controller('CustomerCtr', ['$scope', '$q', '$stateParams', '$ionicSideMenuDelegate', '$ionicLoading', '$filter', 'customerFct',
        function ($scope, $q, $stateParams, $ionicSideMenuDelegate, $ionicLoading, $filter, customerFct) {
            var customerID = $stateParams.cid;

            init();

            function init() {
                customerFct.$detail(customerID).then(function (data) {
                    $scope.customer = data;
                });
            }
        }]);

    module.controller('CustomerListCtr', ['$scope', '$q', '$ionicSideMenuDelegate', '$ionicLoading', '$filter', 'customerFct',
        function ($scope, $q, $ionicSideMenuDelegate, $ionicLoading, $filter, customerFct) {
            $scope.toggleLeft = function () {
                $ionicSideMenuDelegate.toggleLeft();
            };

            init();

            $scope.clearSearch = function () {
                $scope.param.grids = {
                    grid1: null,
                    grid2: null,
                    grid3: null,
                    grid4: null
                };
                $scope.param.price_range = {
                    min: null,
                    max: null
                };
            };

            var settings = {};

            function init() {
                $scope.searchDescription = '';

                $scope.param = {};
                $scope.customer = [];
                $scope.param.searchterm = "";

                $scope.param.page = 0;
                $scope.param.input = "";

                $scope.param.MoreAvailable = false;
                $scope.param.TotalFound = null;
            }

            $scope.clear = function () {
                init();
            };

            $scope.search = function () {
                $scope.param.input = $scope.param.searchterm;

                $scope.param.MoreAvailable = false;
                $scope.param.TotalFound = null;
                $scope.param.page = 0;
                $ionicLoading.show({
                    template: 'Searching...'
                });

                $scope.loadMore().then(function () {
                    $ionicLoading.hide();
                }, function () {
                    $ionicLoading.hide();
                });
            };

            $scope.loadMore = function () {
                var def = $q.defer();
                $scope.param.page = $scope.param.page + 1;

                customerFct.$search($scope.param.input, $scope.param.page).then(function (searchResult) {
                    if ($scope.param.page <= 1) {
                        $scope.customer = [];
                    }

                    if (!_.isEmpty(searchResult.Result)) {
                        $scope.param.TotalFound = searchResult.Total || searchResult.Result.length;
                        $scope.param.MoreAvailable = searchResult.MoreAvailable || false;
                        _.each(searchResult.Result, function (c) {
                            customerFct.$detail(c.ID).then(function (detail) {
                                //c.detail = detail;
                                // Add extra details
                                c.Contact = detail.Contact;
                                c.Attributes = detail.Attributes;
                                c.POSCustomerID = detail.POSCustomerID;
                                c.Salutation = detail.Salutation;
                                c.Totals = detail.Totals;
                                c.image = detail.image;
                            }, function () {
                                //do nothing
                            });

                            $scope.customer.push(c);
                        });

                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        def.resolve();

                    } else {
                        def.resolve(false);
                    }
                });

                return def.promise;
            };

            $scope.moreDataCanBeLoaded = function () {
                return _.isEmpty($scope.param) ? false : $scope.param.MoreAvailable || false;
            }
        }]);

    module.directive('customerCard', function () {
        return {
            restrict: 'A',
            scope: {
                source: '='
            },
            transclude: true,
            templateUrl: 'modules/customer/templates/customer-card.html'
        };
    });

    module.directive('customerSelector', function () {
        return {
            transclude: true,
            templateUrl: 'modules/customer/templates/customer-selector.html',
            controller: "customerSelectorCtr"
        };
    });

    module.directive('customerAdd', function () {
        return {
            transclude: true,
            templateUrl: 'modules/customer/templates/customer-new.html',
            controller: "customerNewCtr"
        };
    });

    module.directive('customerUpdate', function () {
        return {
            transclude: true,
            templateUrl: 'modules/customer/templates/customer-extra-details.html',
            controller: "customerNewCtr"
        };
    });

    module.controller('customerSelectorCtr', ['$scope', '$rootScope', '$q', '$ionicSideMenuDelegate', '$ionicLoading', '$filter', 'customerFct', '$ionicModal',
        function ($scope, $rootScope, $q, $ionicSideMenuDelegate, $ionicLoading, $filter, customerFct, $ionicModal) {

            init();

            $scope.clearSearch = function () {
                $scope.param.grids = {
                    grid1: null,
                    grid2: null,
                    grid3: null,
                    grid4: null
                };
                $scope.param.price_range = {
                    min: null,
                    max: null
                };
            };

            var settings = {};

            function init() {
                $scope.searchDescription = '';

                $scope.param = {};
                $scope.customer = [];
                $scope.param.searchterm = "";

                $scope.param.page = 0;
                $scope.param.input = "";

                $scope.param.MoreAvailable = false;
                $scope.param.TotalFound = null;
                $scope.param.showloadingspinner=false;
                $scope.isCustomerDetails =[];
                $scope.isCustomerMoreAvailable = false;
              }

            $scope.clear = function () {
                init();
            };

            $scope.search = function () {
                $scope.param.showloadingspinner=true;

                $ionicLoading.show({
                    template:'wait...'
                });
                $scope.param.input = $scope.param.searchterm;

                $scope.param.MoreAvailable = false;
                $scope.param.TotalFound = null;
                $scope.param.page = 0;


                $scope.loadMore().then(function () {
                    $scope.param.showloadingspinner=false;
                    //$ionicLoading.hide();
                }, function () {
                    $scope.param=showloadingspinner=false;
                    $ionicLoading.hide();
                });
            };

            $scope.loadMore = function () {
                var def = $q.defer();
                $scope.param.page = $scope.param.page + 1;

                customerFct.$search($scope.param.input, $scope.param.page).then(function (searchResult) {
                    $scope.iscustomer = [];
                    if ($scope.param.page <= 1) {
                        $scope.customer = [];
                    }

                    if (!_.isEmpty(searchResult.Result)) {
                        $scope.param.TotalFound = searchResult.Total || searchResult.Result.length;
                        //$scope.param.MoreAvailable = searchResult.MoreAvailable || false;
                        $scope.isCustomerMoreAvailable = searchResult.MoreAvailable || false;
                        _.each(searchResult.Result, function (c) {
                            c.detail = {
                                Contact: {
                                    Address: {},
                                    Contact: {}
                                },
                                image: {value: null}
                            };
                            $scope.iscustomer.push(c);
                        });
                    }
                     if($scope.iscustomer.length > 0){
                          $scope.getCustomerDetails($scope.iscustomer,0,def);
                      }
                     else{
                      $ionicLoading.hide();
                      $scope.$broadcast('scroll.infiniteScrollComplete');
                      def.resolve();
                    }
                });

                def.resolve(false);
                return def.promise;
            };
           $scope.getCustomerDetails = function(iscustomer,i,callback){
              if(i == 0) $scope.isCustomerDetails =[];
              if($scope.iscustomer.length > i){
                var c = iscustomer[i];
                customerFct.$detail(c.ID).then(function (detail) {
                 
                 // Add extra details
                 c.Contact = detail.Contact;
                 c.Attributes = detail.Attributes;
                 c.POSCustomerID = detail.POSCustomerID;
                 c.Salutation = detail.Salutation;
                 c.Totals = detail.Totals;
                 c.image = detail.image;

                 $scope.isCustomerDetails.push(c);
                 i=i+1;
                 $scope.getCustomerDetails($scope.iscustomer,i,callback);
              }, function () {
                 //do nothing
             });
           }
           else {
                if ($scope.isCustomerDetails.length > 0){
                    var isdetails = _.sortBy($scope.isCustomerDetails,function(isObject) { return (isObject.Contact.Contact.Name).toLowerCase()});
                        isdetails = _.sortBy(isdetails,function(isObject) { return (isObject.Contact.Contact.Surname).toLowerCase()});
                   _.each(isdetails, function (c) {
                        if (!_.where($scope.customer,c).length)
                         $scope.customer.push(c);
                   })
               }
               $scope.param.MoreAvailable = $scope.isCustomerMoreAvailable || false;
               $ionicLoading.hide();
               $scope.$broadcast('scroll.infiniteScrollComplete');
               callback.resolve();
              }
           }

            $scope.selected = function (selected) {
                $rootScope.$broadcast('selCustomer.selected', selected);
            };

            $scope.moreDataCanBeLoaded = function () {
                return _.isEmpty($scope.param) ? false : $scope.param.MoreAvailable || false;
            };
        }]);

    module.controller('customerNewCtr', ['$scope', '$rootScope', '$q', '$ionicLoading', '$ionicModal', '$filter','popupFctr', 'customerFct', 'salutationSrv',
        function ($scope, $rootScope, $q, $ionicLoading, $ionicModal, $filter, popupFctr,customerFct, salutationSrv) {

            init();

            function customerTpl() {
                return {
                    ID: null,
                    Salutation: {
                        ID: null
                    },
                    Company: null,
                    Contact: {
                        Address: {
                            Address1: null,
                            Address2: null,
                            Address3: null,
                            City: null,
                            ZipPostalCode: null,
                            Country: null,
                            ProvinceState: null,
                            Latitude: null,
                            Longitude: null
                        },
                        Contact: {
                            Prefix: null,
                            Name: null,
                            Surname: null,
                            Phone1: null,
                            Mobile1: null,
                            Email: null
                        }
                    }
                };

            }

            function init() {
                $ionicLoading.show({
                    template:'wait...'
                })
                /// <summary>
                /// Init the scope variables
                /// </summary>
                $scope.customer = {};
                $scope.salutations = null;
                salutationSrv.get().then(function (data) {
                    $scope.salutations = data;
                    $ionicLoading.hide();
                });
            }

            $scope.hide = function () {
                $rootScope.$broadcast('customer.cancel-add-new');
            };

            /// <summary>
            /// Save the customer
            /// </summary>
            /// <param name="customer"></param>
            /// <param name="method"> Add or Edit</param>
            $scope.save = function (customer, method) {

                if (customer.Contact.Contact.Phone1){
                    customer.Contact.Contact.Phone1 = customer.Contact.Contact.Phone1.replace(/[^0-9]/g, "");
                }

                if (customer.Contact.Contact.Mobile1){
                    customer.Contact.Contact.Mobile1 = customer.Contact.Contact.Mobile1.replace(/[^0-9]/g, "");
                }

                var tpl = customerTpl();
               

                var valErr = '';

                if($f.pos_choiceType != 0){
                    // Validate for fields required in order
                    if(_.isEmpty(customer.Contact.Contact)){
                        valErr += 'Contact Information <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address)){
                        valErr += 'Address Information <br />';
                    }
                    if(_.isEmpty(customer.Company)){
                        valErr += 'Company <br />';
                    }
                    if(_.isEmpty(customer.Contact.Contact.Name)){
                        valErr += 'Firstname <br />';
                    }
                    if(_.isEmpty(customer.Contact.Contact.Surname)){
                        valErr += 'Lastname <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address.Address1)){
                        valErr += 'Address1 <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address.City )){
                        valErr += 'City <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address.ZipPostalCode)){
                        valErr += 'PostalCode <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address.ProvinceState)){
                        valErr += 'Province/State <br />';
                    }
                    if(_.isEmpty(customer.Contact.Address.Country)){
                        valErr += 'Country <br />';
                    }

                    if (!_.isEmpty(valErr)) {
                        //alert(valMsg + valErr);
                        popupFctr.alert('The Following are required:', valErr);
                        return false;
                    }
                }
                


                //company: "Aralco"
                //email: "vincenzo@aralco.com"
                //firstname: "vincenzo"
                //lastname: "Militello"
                //mobile: "6049804185"
                //phone: "6049804185"
                //salutation: "4"
                var salutation = _.find($scope.salutations, function (s) {
                    return s.ID == customer.salutation;
                });

                tpl.Company = customer.company; // required
                tpl.Salutation = customer.Salutation;
                if (!_.isEmpty(salutation)) {
                    tpl.Contact.Contact.Prefix = salutation.Code;
                }
                if(_.isEmpty(customer.Salutation)){
                    customer.Salutation = {ID: null};
                }
                tpl = customer;
                switch(method){
                    case 'Add':     
                        customerFct.$post(tpl).then(function (data) {
                            $rootScope.$broadcast('customer.ok-customer-add', data);
                        }, function (data) {
                            console.error(JSON.stringify(data));
                        })
                        break;
                    
                    case 'Update':
                        customerFct.$update(tpl).then(function (data) {
                            $rootScope.$broadcast('customer.ok-customer-update', data);
                        }, function (data) {
                            console.error(JSON.stringify(data));
                        })
                        break;
                }
                
            }
            $rootScope.$on('aralco.posContainerCtrl.updateCustomerInfo', function (event, id) {
                //console.log(event.name);
                if (id){
                    customerFct.$detail(id, undefined, true).then(function (data) {
                        $rootScope.$broadcast('aralco.customer.customerInfoUpdated', data);
                    });
                }
            });
        }]);

})();
