(function () {
    
	var module = angular.module('aralco.discountreasons',['ionic']);
	
	module.factory('discountReasonFactory', function($filter) {

        var elementId = 6;

		var discountReasons = [
			{
                ID: 1,
				name: "Promotion",
				desc: "Promotion"  
			},
			{
                ID: 2,
				name: "Damaged",
				desc: "Damaged"
			},
			{
                ID: 3,
				name: "VIP",
				desc: "VIP"
			},
			{
                ID: 4,
				name: "Friends",
				desc: "Friends"
			},
			{
                ID: 5,
				name: "Family",
				desc: "Family"
			}
		];

		return {
			getDiscountReasons : function(searchText) {
                return $filter('filter')(discountReasons, {name: searchText});
			},
			addDiscountReason : function(discountReason) {
				var temp = {
                    ID: elementId++,
					name: discountReason.name,
					desc: discountReason.desc
				}

				discountReasons.push(temp);
			},
			deleteDiscountReason: function(item) {
                var index = discountReasons.findIndex(discountReason => discountReason.ID == item.ID);
                discountReasons.splice(index, 1);
            },
            
            saveDiscountReason: function(item,discountReason) {
                var index = discountReasons.findIndex(discountReason => discountReason.ID == item.ID);
                discountReasons[index].name = discountReason.name;
                discountReasons[index].desc = discountReason.desc;
            },
            
            getDiscountReasonByIndex : function(item) {
                return discountReasons.filter(discountReason => discountReason.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.discountreasons', {
			url: '/discountreasons',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/discount_reasons/templates/discount-reasons.html',
					controller: 'DiscountReasonController'
				}
			}
		})
		.state('tab.editdiscountreasons', {
			url: '/editdiscountreason/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/discount_reasons/templates/discount-reasons-edit.html',
                    controller: 'EditDiscountReasonController'
				}
			}
		})
		.state('tab.adddiscountreasons', {
			url: '/editdiscountreason/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/discount_reasons/templates/discount-reasons-edit.html',
                    controller: 'AddDiscountReasonController'
				}
			}	
		})
	}]);

    module.controller('DiscountReasonController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,discountReasonFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editDiscountReason' && $scope.selectedItem != null){
                $state.go('tab.editdiscountreasons',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addDiscountReason'){
                $state.go('tab.adddiscountreasons',{name: 'addDiscountReason'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteDiscountReason = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        discountReasonFactory.deleteDiscountReason($scope.selectedItem);
                        $rootScope.$emit('updateDiscountReasons', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(discountReasonFactory.getDiscountReasons($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateDiscountReasons', function(event, arg) {
            $scope.entries = angular.copy(discountReasonFactory.getDiscountReasons($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditDiscountReasonController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,discountReasonFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.discountReason = angular.copy(discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.discountReason.name;

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.discountReason.desc.length == 0) {
                $scope.discountReason.desc = $scope.discountReason.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.discountReason, discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDiscountReason(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveDiscountReason = function() {
            discountReasonFactory.saveDiscountReason($scope.selectedItem,$scope.discountReason);
            $rootScope.$emit('updateDiscountReasons', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearDiscountReason = function() {
            if(!angular.equals($scope.discountReason, discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDiscountReason(); 
                    }
                    else{
                        $scope.discountReason = angular.copy(discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteDiscountReason = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    discountReasonFactory.deleteDiscountReason($scope.selectedItem);
                    $rootScope.$emit('updateDiscountReasons', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.discountReason, discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.discountReason = angular.copy(discountReasonFactory.getDiscountReasonByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddDiscountReasonController', function($scope,$ionicPopup,$ionicHistory,$rootScope,discountReasonFactory){
        $scope.showSearchbar = true;
        $scope.discountReason = {
            name : "",
            desc : ""
        }
        var oriDiscountReason = angular.copy($scope.discountReason);

        $scope.autoFillDescription = function() {
            if($scope.discountReason.desc.length == 0) {
                $scope.discountReason.desc = angular.copy($scope.discountReason.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.discountReason, oriDiscountReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDiscountReason(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveDiscountReason = function() {
            if(!angular.equals($scope.discountReason, oriDiscountReason)) {
                discountReasonFactory.addDiscountReason($scope.discountReason);
                $rootScope.$emit('updateDiscountReasons', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.discountReason = angular.copy(oriDiscountReason);
                })
            }
        }

        $scope.addDiscountReason = function() {
            $scope.clearDiscountReason();
        }

        $scope.clearDiscountReason = function() {
            if(!angular.equals($scope.discountReason, oriDiscountReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDiscountReason(); 
                    }
                    $scope.discountReason = angular.copy(oriDiscountReason);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.discountReason, oriDiscountReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.discountReason = angular.copy(oriDiscountReason); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();