(function () {
    
	var module = angular.module('aralco.dutyrates',['ionic']);
	
	module.factory('dutyRateFactory', function($filter) {

        var elementId = 12;

		var dutyRates = [
			{
                ID: 1,
                name: "Dairy",
                desc: "Dairy",
                rate: 2.00,
                lastUpdateDate: ""
            },
            {
                ID: 2,
                name: "Veg",
                desc: "Veg",
                rate: 1.50,
                lastUpdateDate: ""
            },
            {
                ID: 3,
                name: "Meat",
                desc: "Meat Product",
                rate: 3.00,
                lastUpdateDate: ""
            },
            {
                ID: 4,
                name: "Cereals",
                desc: "Cereals",
                rate: 4.50,
                lastUpdateDate: ""
            },
            {
                ID: 5,
                name: "POP",
                desc: "POP",
                rate: 5.00,
                lastUpdateDate: ""
            },
            {
                ID: 6,
                name: "Apparel",
                desc: "Apparel",
                rate: 8.00,
                lastUpdateDate: ""
            },
            {
                ID: 7,
                name: "Vapor",
                desc: "Vapor",
                rate: 2.00,
                lastUpdateDate: ""
            },
            {
                ID: 8,
                name: "Books",
                desc: "Books",
                rate: 5.58,
                lastUpdateDate: ""
            },
            {
                ID: 9,
                name: "CH-Remotes",
                desc: "CH-Remotes",
                rate: 10.00,
                lastUpdateDate: ""
            },
            {
                ID: 10,
                name: "JP-Remotes",
                desc: "JP-Remotes",
                rate: 7.00,
                lastUpdateDate: ""
            },
            {
                ID: 11,
                name: "Vats",
                desc: "Vats",
                rate: 6.35,
                lastUpdateDate: ""
            }
		];

		return {
			getDutyRates : function(searchText) {
				return $filter('filter')(dutyRates, {name: searchText})
            },

            addDutyRate : function(dutyRate) {
                var temp = {
                    ID: elementId++,
                    name: dutyRate.name,
                    desc: dutyRate.desc,
                    rate: dutyRate.rate,
                    lastUpdateDate: dutyRate.lastUpdateDate
                }

                dutyRates.push(temp);
            },
            deleteDutyRate: function(item) {
                var index = dutyRates.findIndex(dutyRate => dutyRate.ID == item.ID);
                dutyRates.splice(index, 1);
            },
            saveDutyRate: function(item,dutyRate) {
                var index = dutyRates.findIndex(dutyRate => dutyRate.ID == item.ID);
                dutyRates[index].name = dutyRate.name;
                dutyRates[index].desc = dutyRate.desc;
                dutyRates[index].rate = (dutyRate.rate != undefined? dutyRate.rate: 0);
                dutyRates[index].lastUpdateDate = dutyRate.lastUpdateDate;
			},
			getDutyRateByIndex : function(item) {
                return dutyRates.filter(dutyRate => dutyRate.ID == item.ID)[0];
            }
		};
    });
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.dutyrates', {
			url: '/dutyrates',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'DutyRateController'
				}
			}
		})
		.state('tab.editdutyrates', {
			url: '/editdutyrate/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/duty_rates/templates/duty-rates-edit.html',
                    controller: 'EditDutyRateController'
				}
			}
		})
		.state('tab.adddutyrates', {
			url: '/editdutyrate/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/duty_rates/templates/duty-rates-edit.html',
                    controller: 'AddDutyRateController'
				}
			}	
		})
	}]);

    module.controller('DutyRateController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,dutyRateFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Duty Rate";
        $scope.searchTitle = "Duty Rates"

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editdutyrates',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.adddutyrates',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        dutyRateFactory.deleteDutyRate($scope.selectedItem);
                        $rootScope.$emit('updateDutyRates', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(dutyRateFactory.getDutyRates($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateDutyRates', function(event, arg) {
            $scope.entries = angular.copy(dutyRateFactory.getDutyRates($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditDutyRateController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,dutyRateFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.dutyRate = angular.copy(dutyRateFactory.getDutyRateByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.dutyRate.name;
        $scope.title = "Edit DutyRate";

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.dutyRate.desc.length == 0) {
                $scope.dutyRate.desc = $scope.dutyRate.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.dutyRate, dutyRateFactory.getDutyRateByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            dutyRateFactory.saveDutyRate($scope.selectedItem,$scope.dutyRate);
                            $rootScope.$emit('updateDutyRates', {
                                editType: "Saved"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveDutyRate = function() {
            var errorCheck = document.getElementsByClassName('error-message');
            var validity = true;
            for(var i = 0; i < errorCheck.length; i++) {
                if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                    validity = false;
                }
            }

            if(validity) {
                dutyRateFactory.saveDutyRate($scope.selectedItem,$scope.dutyRate);
                $rootScope.$emit('updateDutyRates', {
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            } else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                })
            }
        }

        $scope.clearDutyRate = function() {
            if(!angular.equals($scope.dutyRate, dutyRateFactory.getDutyRateByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDutyRate(); 
                    }
                    else{
                        $scope.dutyRate = angular.copy(dutyRateFactory.getDutyRateByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteDutyRate = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    dutyRateFactory.deleteDutyRate($scope.selectedItem);
                    $rootScope.$emit('updateDutyRates', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.dutyRate, dutyRateFactory.getDutyRateByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.dutyRate = angular.copy(dutyRateFactory.getDutyRateByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddDutyRateController', function($scope,$ionicPopup,$ionicHistory,$rootScope,dutyRateFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Duty Rate";

        $scope.dutyRate = {
            name : "",
            desc : "",
            rate: 0.00,
            lastUpdateDate: ""
        }
        var oriDutyRate = angular.copy($scope.dutyRate);

        $scope.autoFillDescription = function() {
            if($scope.dutyRate.desc.length == 0) {
                $scope.dutyRate.desc = angular.copy($scope.dutyRate.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.dutyRate, oriDutyRate)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            dutyRateFactory.addDutyRate($scope.dutyRate);
                            $rootScope.$emit('updateDutyRates', {
                                editType: "Added"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            }).then(function() {
                                $scope.dutyRate = angular.copy(oriDutyRate);
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveDutyRate = function() {
            if(!angular.equals($scope.dutyRate, oriDutyRate)) {
                var errorCheck = document.getElementsByClassName('error-message');
                var validity = true;
                for(var i = 0; i < errorCheck.length; i++) {
                    if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                        validity = false;
                    }
                }
    
                if(validity) {
                    dutyRateFactory.addDutyRate($scope.dutyRate);
                    $rootScope.$emit('updateDutyRates', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.dutyRate = angular.copy(oriDutyRate);
                    })
                } else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
            }
        }

        $scope.addDutyRate = function() {
            $scope.clearDutyRate();
        }

        $scope.clearDutyRate = function() {
            if(!angular.equals($scope.dutyRate, oriDutyRate)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveDutyRate(); 
                    }
                    $scope.dutyRate = angular.copy(oriDutyRate);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.dutyRate, oriDutyRate)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.dutyRate = angular.copy(oriDutyRate); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();