(function () {
    
	var module = angular.module('aralco.expenses',['ionic']);
	
	module.factory('expenseFactory', function($filter) {

        var elementId = 9;

		var expenses = [
			{
                ID: 1,
				name: "Freight",
				desc: "Freight"  
			},
			{
                ID: 2,
				name: "Advertising",
				desc: "Advertising"
			},
			{
                ID: 3,
				name: "Postage",
				desc: "Postage"
			},
			{
                ID: 4,
				name: "Maint./Repairs",
				desc: "Maint./Repairs"
			},
			{
                ID: 5,
				name: "Supplies",
				desc: "Supplies"
			},
			{
                ID: 6,
				name: "Fixture",
				desc: "Fixture"
			},
			{
                ID: 7,
				name: "Repairs",
				desc: "Repairs"
			},
			{
                ID: 8,
				name: "Equipment",
				desc: "Equipment"
			}
        ];
        
		return {
			getExpenses : function(searchText) {
                return $filter('filter')(expenses, {name: searchText})
			},
			addExpense : function(expense) {
				var temp = {
                    ID: elementId++,
					name: expense.name,
					desc: expense.desc
				}

				expenses.push(temp);
			},
			deleteExpense: function(item) {
                var index = expenses.findIndex(expense => expense.ID == item.ID);
                expenses.splice(index, 1);
            },
            
            saveExpense: function(item,expense) {
                var index = expenses.findIndex(expense => expense.ID == item.ID);
                expenses[index].name = expense.name;
                expenses[index].desc = expense.desc;
            },
            
            getExpenseByIndex : function(item) {
                return expenses.filter(expense => expense.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.expenses', {
			url: '/expenses',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/expenses/templates/expenses.html',
                    controller: 'ExpenseController'
				}
			} 
		})
		.state('tab.editexpenses', {
			url: '/editexpense/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/expenses/templates/expenses-edit.html',
                    controller: 'EditExpenseController'
				}
			}
		})
		.state('tab.addexpenses', {
			url: '/editexpense/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/expenses/templates/expenses-edit.html',
                    controller: 'AddExpenseController'
				}
			}	
		})
	}]);

    module.controller('ExpenseController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,expenseFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editExpense' && $scope.selectedItem != null){
                $state.go('tab.editexpenses',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addExpense'){
                $state.go('tab.addexpenses',{name: 'addExpense'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteExpense = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        expenseFactory.deleteExpense($scope.selectedItem);
                        $rootScope.$emit('updateExpenses', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(expenseFactory.getExpenses($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateExpenses', function(event, arg) {
            $scope.entries = angular.copy(expenseFactory.getExpenses($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditExpenseController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,expenseFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.expense = angular.copy(expenseFactory.getExpenseByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.expense.name;
        
        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.expense.desc.length == 0) {
                $scope.expense.desc = $scope.expense.name;
            }
        }
        
        $scope.goBack = function() {
            if(!angular.equals($scope.expense, expenseFactory.getExpenseByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveExpense(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveExpense = function() {
            expenseFactory.saveExpense($scope.selectedItem,$scope.expense);
            $rootScope.$emit('updateExpenses', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearExpense = function() {
            if(!angular.equals($scope.expense, expenseFactory.getExpenseByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveExpense(); 
                    }
                    else{
                        $scope.expense = angular.copy(expenseFactory.getExpenseByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteExpense = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    expenseFactory.deleteExpense($scope.selectedItem);
                    $rootScope.$emit('updateExpenses', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.expense, expenseFactory.getExpenseByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.expense = angular.copy(expenseFactory.getExpenseByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddExpenseController', function($scope,$ionicPopup,$ionicHistory,$rootScope,expenseFactory){
        $scope.showSearchbar = true;
        $scope.expense = {
            name : "",
            desc : ""
        }
        var oriExpense = angular.copy($scope.expense);

        $scope.autoFillDescription = function() {
            if($scope.expense.desc.length == 0) {
                $scope.expense.desc = $scope.expense.name;
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.expense, oriExpense)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveExpense(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveExpense = function() {
            if(!angular.equals($scope.expense, oriExpense)) {
                expenseFactory.addExpense($scope.expense);
                $rootScope.$emit('updateExpenses', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.expense = angular.copy(oriExpense);
                })
            }
        }

        $scope.addExpense = function() {
            $scope.clearExpense();
        }

        $scope.clearExpense = function() {
            if(!angular.equals($scope.expense, oriExpense)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveExpense(); 
                    }
                    $scope.expense = angular.copy(oriExpense);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.expense, oriExpense)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.expense = angular.copy(oriExpense);
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();