(function () {
    
	var module = angular.module('aralco.freightservices',['ionic']);
	
	module.factory('freightServiceFactory', function($filter) {

        var elementId = 3;

        var currencyList = [
            "US $",
            "BDT",
            "Euro",
            "Rupi"
        ];

		var freightServices = [
			{
                ID: 1,
                name: "UPS",
                desc: "UPS",
                region: "North America",
                currency: "US $",
                ratePerUnit: 2.25,
                lastUpdateDate: ""
            },
            {
                ID: 2,
                name: "Fedex",
                desc: "Fedex",
                region: "",
                currency: "",
                ratePerUnit: 0,
                lastUpdateDate: ""
            }
		];

		return {
			getFreightServices : function(searchText) {
				return $filter('filter')(freightServices, {name: searchText})
            },
            getCurrencyList : function() {
                return currencyList;
            },
            addFreightService : function(freightService) {
                var temp = {
                    ID: elementId++,
                    name: freightService.name,
                    desc: freightService.desc,
                    region: freightService.region,
                    currency: freightService.currency,
                    ratePerUnit: freightService.ratePerUnit,
                    lastUpdateDate: freightService.lastUpdateDate
                }

                freightServices.push(temp);
            },
            deleteFreightService: function(item) {
                var index = freightServices.findIndex(freightService => freightService.ID == item.ID);
                freightServices.splice(index, 1);
            },
            saveFreightService: function(item,freightService) {
                var index = freightServices.findIndex(freightService => freightService.ID == item.ID);
                freightServices[index].name = freightService.name;
                freightServices[index].desc = freightService.desc;
                freightServices[index].region = freightService.region;
                freightServices[index].currency = freightService.currency;
                freightServices[index].ratePerUnit = (freightService.ratePerUnit != undefined? freightService.ratePerUnit: 0);
                freightServices[index].lastUpdateDate = freightService.lastUpdateDate;
			},
			getFreightServiceByIndex : function(item) {
                return freightServices.filter(freightService => freightService.ID == item.ID)[0];
            }
		};
    });
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.freightservices', {
			url: '/freightservices',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'FreightServiceController'
				}
			}
		})
		.state('tab.editfreightservices', {
			url: '/editfreightservice/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/freight_services/templates/freight-services-edit.html',
                    controller: 'EditFreightServiceController'
				}
			}
		})
		.state('tab.addfreightservices', {
			url: '/editfreightservice/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/freight_services/templates/freight-services-edit.html',
                    controller: 'AddFreightServiceController'
				}
			}	
		})
	}]);

    module.controller('FreightServiceController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,freightServiceFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Freight Services";
        $scope.searchTitle = "Freight Services"

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editfreightservices',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addfreightservices',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        freightServiceFactory.deleteFreightService($scope.selectedItem);
                        $rootScope.$emit('updateFreightServices', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(freightServiceFactory.getFreightServices($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateFreightServices', function(event, arg) {
            $scope.entries = angular.copy(freightServiceFactory.getFreightServices($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditFreightServiceController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,freightServiceFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.freightService = angular.copy(freightServiceFactory.getFreightServiceByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.freightService.name;
        $scope.title = "Edit Freight Service";
        $scope.currencyList = angular.copy(freightServiceFactory.getCurrencyList());

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.freightService.desc.length == 0) {
                $scope.freightService.desc = $scope.freightService.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.freightService, freightServiceFactory.getFreightServiceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            freightServiceFactory.saveFreightService($scope.selectedItem,$scope.freightService);
                            $rootScope.$emit('updateFreightServices', {
                                editType: "Saved"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveFreightService = function() {
            var errorCheck = document.getElementsByClassName('error-message');
            var validity = true;
            for(var i = 0; i < errorCheck.length; i++) {
                if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                    validity = false;
                }
            }

            if(validity) {
                freightServiceFactory.saveFreightService($scope.selectedItem,$scope.freightService);
                $rootScope.$emit('updateFreightServices', {
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            } else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                })
            }
        }

        $scope.clearFreightService = function() {
            if(!angular.equals($scope.freightService, freightServiceFactory.getFreightServiceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveFreightService(); 
                    }
                    else{
                        $scope.freightService = angular.copy(freightServiceFactory.getFreightServiceByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteFreightService = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    freightServiceFactory.deleteFreightService($scope.selectedItem);
                    $rootScope.$emit('updateFreightServices', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.freightService, freightServiceFactory.getFreightServiceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.freightService = angular.copy(freightServiceFactory.getFreightServiceByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddFreightServiceController', function($scope,$ionicPopup,$ionicHistory,$rootScope,freightServiceFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Freight Service";
        $scope.currencyList = angular.copy(freightServiceFactory.getCurrencyList());

        $scope.freightService = {
            name : "",
            desc : "",
            region: "",
            currency: "",
            ratePerUnit: 0.00,
            lastUpdateDate: ""
        }
        var oriFreightService = angular.copy($scope.freightService);

        $scope.autoFillDescription = function() {
            if($scope.freightService.desc.length == 0) {
                $scope.freightService.desc = angular.copy($scope.freightService.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.freightService, oriFreightService)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            freightServiceFactory.addFreightService($scope.freightService);
                            $rootScope.$emit('updateFreightServices', {
                                editType: "Added"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            }).then(function() {
                                $scope.freightService = angular.copy(oriFreightService);
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveFreightService = function() {
            if(!angular.equals($scope.freightService, oriFreightService)) {
                var errorCheck = document.getElementsByClassName('error-message');
                var validity = true;
                for(var i = 0; i < errorCheck.length; i++) {
                    if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                        validity = false;
                    }
                }
    
                if(validity) {
                    freightServiceFactory.addFreightService($scope.freightService);
                    $rootScope.$emit('updateFreightServices', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.freightService = angular.copy(oriFreightService);
                    })
                } else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
            }
        }

        $scope.addFreightService = function() {
            $scope.clearFreightService();
        }

        $scope.clearFreightService = function() {
            if(!angular.equals($scope.freightService, oriFreightService)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveFreightService(); 
                    }
                    $scope.freightService = angular.copy(oriFreightService);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.freightService, oriFreightService)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.freightService = angular.copy(oriFreightService); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();