(function () {
    
	var module = angular.module('aralco.giftcards',['ionic']);
	
	module.factory('giftCardFactory', function($filter) {

        var elementId = 2;

		var giftCards = [
			{
                ID: 1,
				number: "123456",
                totalPurchase: "$500.00",
                totalUsed: "$150.00",
                balance: "$350.00",
                history: [
                    {
                        type: "Load",
                        trans: "1231",
                        date: "08/04/17",
                        amt: "$500.00",
                        gift: "102"
                    },
                    {
                        type: "Used",
                        trans: "1242",
                        date: "06/13/17",
                        amt: "$150.00",
                        gift: "131"
                    },
                    {
                        type: "Load",
                        trans: "4534",
                        date: "04/12/17",
                        amt: "$56.67",
                        gift: "92"
                    }
                ]  
			}
		];

		return {
			getGiftCards : function(searchText) {
                return $filter('filter')(giftCards, {number: searchText})
			},
			addGiftCard : function(giftCard) {
				var temp = {
                    ID: elementId++,
					number: giftCard.number,
                    totalPurchase: giftCard.totalPurchase,
                    totalUsed: giftCard.totalUsed,
                    balance: giftCard.balance,
                    history: giftCard.history
				}

				giftCards.push(temp);
			},
			deleteGiftCard: function(item) {
                var index = giftCards.findIndex(giftCard => giftCard.ID == item.ID);
                giftCards.splice(index, 1);
            },
			saveGiftCard: function(item,giftCard) {
                var index = giftCards.findIndex(giftCard => giftCard.ID == item.ID);
				giftCards[index].number = giftCard.number;
                giftCards[index].totalPurchase = giftCard.totalPurchase;
                giftCards[index].totalUsed = giftCard.totalUsed;
                giftCards[index].balance = giftCard.balance;
                giftCards[index].history = giftCard.history;
			},
			getGiftCardByIndex : function(item) {
                return giftCards.filter(giftCard => giftCard.ID == item.ID)[0];
            }
		};
	});
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
    
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.giftcards', {
			url: '/giftcards',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/gift_cards/templates/gift-cards.html',
					controller: 'GiftCardController'
				}
			}
		})
		.state('tab.editgiftcards', {
			url: '/editgiftcard/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/gift_cards/templates/gift-cards-edit.html',
                    controller: 'EditGiftCardController'
				}
			}
		})
		.state('tab.addgiftcards', {
			url: '/editgiftcard/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/gift_cards/templates/gift-cards-add.html',
                    controller: 'AddGiftCardController'
				}
			}
		})
	}]);

    module.controller('GiftCardController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,giftCardFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.entries = giftCardFctr.getGiftCards();

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editGiftCard' && $scope.selectedItem != null){
                $state.go('tab.editgiftcards',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addGiftCard'){
                $state.go('tab.addgiftcards',{name: 'addGiftCard'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteGiftCard = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        giftCardFactory.deleteGiftCard($scope.selectedItem);
                        $rootScope.$emit('updateGiftCards', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(giftCardFactory.getGiftCards($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateGiftCards', function(event, arg) {
            $scope.entries = angular.copy(giftCardFactory.getGiftCards($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditGiftCardController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,giftCardFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.giftCard = angular.copy(giftCardFactory.getGiftCardByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.giftCard.number;
        
        
       

        
            
            {
        }

        $scope.cancelEdit = function() {
            $ionicHistory.goBack();;
        }

        $scope.deleteGiftCard = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    giftCardFactory.deleteGiftCard($scope.selectedItem);
                    $rootScope.$emit('updateGiftCards', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack();
                }
            })
        }
    })

    module.controller('AddGiftCardController', function($scope,$ionicPopup,$ionicHistory,$rootScope,giftCardFactory){
        $scope.showSearchbar = true;
        $scope.giftCard = {
            number: 0,
            totalPurchase: 0,
            totalUsed: 0,
            balance: 0,
            history: ""
        }
        var oriGiftCard = angular.copy($scope.giftCard);
      
        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.giftCard, oriGiftCard)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveGiftCard();
                        if(angular.isDefined($scope.giftCard.number) && angular.isDefined($scope.giftCard.totalPurchase) && angular.isDefined($scope.giftCard.totalUsed) && angular.isDefined($scope.giftCard.balance)) {
                            $ionicHistory.goBack();
                        } 
                    }
                    else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveGiftCard = function() {
            if(!angular.equals($scope.giftCard, oriGiftCard)) {
                if(angular.isDefined($scope.giftCard.number) && angular.isDefined($scope.giftCard.totalPurchase) && angular.isDefined($scope.giftCard.totalUsed) && angular.isDefined($scope.giftCard.balance)) {
                    giftCardFactory.addGiftCard($scope.giftCard);
                    $rootScope.$emit('updateGiftCards', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.giftCard = angular.copy(oriGiftCard);
                    })
                }
                else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
            }
        }

        $scope.addGiftCard = function() {
            $scope.clearGiftCard();
        }

        $scope.clearGiftCard = function() {
            if(!angular.equals($scope.giftCard, oriGiftCard)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveGiftCard();
                        if(angular.isDefined($scope.giftCard.number) && angular.isDefined($scope.giftCard.totalPurchase) && angular.isDefined($scope.giftCard.totalUsed) && angular.isDefined($scope.giftCard.balance)) {
                            $scope.giftCard = angular.copy(oriGiftCard);
                        }
                    }
                    else {
                        $scope.giftCard = angular.copy(oriGiftCard);
                    }
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.giftCard, oriGiftCard)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.giftCard = angular.copy(oriGiftCard); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();