﻿(function () {
    'use strict';
    var module = angular.module('aralco.physicalcount');

    module.factory('physicalCountFctr', ['$q', '$http', 'storeFctr', 'localScanService',
                                            function ($q, $http, storeFctr, localScanService) {


        function recordsManager() {

            var self = this;

            var verifyBarcodeOnline = function (snID, barcode, forceLoad) {
                forceLoad = forceLoad || $f.ForceLoad;
                snID = snID || '';
                var deferred = $q.defer();

                var url = $f.serviceUrl + 'PhysicalCount/Verify/{snID}/{barcode}?forceLoad={forceLoad}';
                url = url.replace('{snID}', snID).replace('{barcode}', barcode).replace('{forceLoad}', forceLoad);

                var req = {
                    method: 'get',
                    //headers: h,
                    url: url

                };

                $http(req).success(function (data, status, headers, config) {
                    data = data || false;
                    deferred.resolve(data);
                }).error(function (data, status, headers, config) {
                    if (forceLoad)
                        deferred.reject(data); //if loading is forced, then throw and exception
                    else
                        deferred.resolve(false); //in case of error, let's say is not online!
                });

                return deferred.promise;
            };

            self.$verify = function (snID, Barcode, forceLoad) {
                var def = $q.defer();
                verifyBarcodeOnline(snID, Barcode, forceLoad).then(function (result) {
                    var retval = result || false;
                    def.resolve(retval);
                }, function (error) {
                    def.reject(error);
                });

                return def.promise;
            };

            return self;
        }

        var searchPhysicalCount = function (number, forceLoad) {
            forceLoad = forceLoad || $f.ForceLoad;
            number = number || '';

            var url = $f.serviceUrl + 'PhysicalCount/Search/{number}?forceLoad={forceLoad}';
            url = url.replace('{number}', number).replace('{forceLoad}', forceLoad);

            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req).then(function (data) {
                return data.data;
            });
        };

        var loadPhysicalCount = function (id, forceLoad) {
            forceLoad = forceLoad || $f.ForceLoad;
            id = id || '';

            var url = $f.serviceUrl + 'PhysicalCount/Get/{id}?forceLoad={forceLoad}';
            url = url.replace('{id}', id).replace('{forceLoad}', forceLoad);

            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req);
        };

        this.PhysicalCount = {
            $search: searchPhysicalCount,
            $get: loadPhysicalCount
        };


        this.Snapshots = {
            /// <summary>
            /// Return the list of snapshots related to the specified physical count
            /// </summary>
            /// <param name="id"></param>
            /// <param name="forceLoad"></param>
            /// <returns type=""></returns>
            $getAll: function (ID, forceLoad) {
                forceLoad = forceLoad || $f.ForceLoad;
                ID = ID || '';
                var deferred = $q.defer();
                
                var url = $f.serviceUrl + 'PhysicalCount/Snapshot/{ID}?forceLoad={forceLoad}';
                url = url.replace('{ID}', ID).replace('{forceLoad}', forceLoad);
    
                var req = {
                    method: 'get',
                    //headers: h,
                    url: url
                };
    
                $http(req)
                    .success(function (data, status, headers, config) {
                        if (!_.isEmpty(data)) {
                            _.forEach(data, function (ss) {
                                if ((ss.StoreID || 0) > 0) {
                                    storeFctr.Get(ss.StoreID).then(function (store) {
                                        ss.Store = store;
                                    });
                                }
                            });
                        }
                        deferred.resolve(data);
                    })
                    .error(function (data, status) {
                        deferred.reject(data, status);
                    });
    
                return deferred.promise;
            },

            /// <summary>
            /// Retrieve a single snapshot
            /// </summary>
            /// <param name="id"></param>
            /// <returns type=""></returns>
            $get: function (ID,  forceLoad) {
                forceLoad = forceLoad || $f.ForceLoad;
                ID = ID || '';
                var deferred = $q.defer();
                
                // Get single snapshot
                var url = $f.serviceUrl + 'Snapshot/get/{ID}';
                url = url.replace('{ID}', ID);
    
                var req = {
                    method: 'get',
                    //headers: h,
                    url: url
                };
    
                $http(req)
                    .success(function (data, status, headers, config) {
                        if (!_.isEmpty(data)) {
                            if ((data.StoreID || 0) > 0) {
                                storeFctr.Get(data.StoreID).then(function (store) {
                                    data.Store = store;
                                    deferred.resolve(data);
                                });
                            }
                        }
                    })
                    .error(function (data, status) {
                        deferred.reject(data, status);
                    });
    
                return deferred.promise;
            },
            
            $submit: function (snID,scan_type) {
                var deferred = $q.defer();
                var paramsValues = [];
                localScanService.GetScans(snID, scan_type).then(function(source){
                    for(var i=0;i<source.length;i++){
                        var User = source[i].UserInfo || $f.UserInfo;
                        var item =  {
                            "Input": source[i].input || source[i].barcode,
                            "Product": {
                                ID: source[i].product.ID,
                                Barcode: source[i].product.Barcode,
                                SerialNumber: source[i].SerialNumber || null
                            },
                            "Snapshot": {
                                ID: source[i].parentReference
                            },
                            "Location": {
                                Name: source[i].location
                            },
                            "Employee": {
                                "ID": User.EmployeeID,
                                "Info": {
                                    Name: User.FirstName,
                                    Surname: User.LastName
                                }
                            },
                            "Quantity": {
                                "Quantity": source[i].count.scanned.count,
                                "TimeStamp": new Date(source[i].count.scanned.modifiedOn).toISOString()
                            }
                        }
                        paramsValues.push(item);
                    }
                    
                    var url = $f.serviceUrl + 'PhysicalCount/Post';
                    var req = {
                        method: 'post',
                        url: url,
                        data: paramsValues
                    };
                    $http(req).
                        success(function (data, status, headers, config) {
                            deferred.resolve(data)
                        }).
                        error(function (data, status) {
                            deferred.reject(data, status);
                        });
                   
                });
                return deferred.promise;
            },

            Product: new recordsManager()
        };

        return this;
    }]);

})();