(function () {
    
	var module = angular.module('aralco.inventoryzones',['ionic']);
	
	module.factory('inventoryZoneFactory', function($filter) {

        var elementId = 8;
        
		var inventoryZones = [
			{
                ID: 1,
				name: "Alberta",
				desc: "Alberta"  
			},
			{
                ID: 2,
				name: "All",
				desc: "All"
			},
			{
                ID: 3,
				name: "Ontario",
				desc: "Ontario"
			},
			{
                ID: 4,
				name: "Vancouver",
				desc: "Vancouver"
			},
			{
                ID: 5,
				name: "Washington USA",
				desc: "Washington USA"
			},
			{
                ID: 6,
				name: "Kerrisdale",
				desc: "Kerrisdale"
			},
			{
                ID: 7,
				name: "Mount Pleasant",
				desc: "Mount Pleasant"
			}
		];

		return {
			 getInventoryZones : function(searchText) {
                return $filter('filter')(inventoryZones, {name: searchText})
			 },
			 addInventoryZone : function(inventoryZone) {
				var temp = {
                    ID: elementId++,
					name: inventoryZone.name,
					desc: inventoryZone.desc
				}

				inventoryZones.push(temp);
			 },
			 deleteInventoryZone: function(item) {
                var index = inventoryZones.findIndex(inventoryZone => inventoryZone.ID == item.ID);
                inventoryZones.splice(index, 1);
             },
			 saveInventoryZone: function(item,inventoryZone) {
                var index = inventoryZones.findIndex(inventoryZone => inventoryZone.ID == item.ID);
                inventoryZones[index].name = inventoryZone.name;
                inventoryZones[index].desc = inventoryZone.desc;
            },
			getInventoryZoneByIndex : function(item) {
                return inventoryZones.filter(inventoryZone => inventoryZone.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.bosinventoryzones', {
			url: '/bosinventoryzones',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'InventoryZoneController'
				}
			}
		})
		.state('tab.editinventoryzones', {
			url: '/editinventoryzone/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'EditInventoryZoneController'
				}
			}
		})
		.state('tab.addinventoryzones', {
			url: '/editinventoryzone/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'AddInventoryZoneController'
				}
			}	
		})
	}]);

    module.controller('InventoryZoneController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,inventoryZoneFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Manage Inventory Zones";
        $scope.searchTitle = "Inventory Zone";

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editinventoryzones',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addinventoryzones',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        inventoryZoneFactory.deleteInventoryZone($scope.selectedItem);
                        $rootScope.$emit('updateInventoryZones', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(inventoryZoneFactory.getInventoryZones($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateInventoryZones', function(event, arg) {
            $scope.entries = angular.copy(inventoryZoneFactory.getInventoryZones($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditInventoryZoneController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,inventoryZoneFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.item = angular.copy(inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.item.name;
        $scope.title = "Edit Inventory Zone"
        $scope.param = "Inventory";

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = $scope.item.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                       $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
       $scope.saveItem = function() {
            inventoryZoneFactory.saveInventoryZone($scope.selectedItem,$scope.item);
            $rootScope.$emit('updateInventoryZones', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                       $scope.saveItem(); 
                    }
                    else{
                        $scope.item = angular.copy(inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteItem = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    inventoryZoneFactory.deleteInventoryZone($scope.selectedItem);
                    $rootScope.$emit('updateInventoryZones', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(inventoryZoneFactory.getInventoryZoneByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddInventoryZoneController', function($scope,$ionicPopup,$ionicHistory,$rootScope,inventoryZoneFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Inventory Zone"
        $scope.param = "Inventory";
        $scope.item = {
            name : "",
            desc : ""
        }
        var oriInventoryZone = angular.copy($scope.item);

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = angular.copy($scope.item.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, oriInventoryZone)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                       $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

       $scope.saveItem = function() {
            if(!angular.equals($scope.item, oriInventoryZone)) {
                inventoryZoneFactory.addInventoryZone($scope.item);
                $rootScope.$emit('updateInventoryZones', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.item = angular.copy(oriInventoryZone);
                })
            }
        }

        $scope.addInventoryZone = function() {
            $scope.clearItem();
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, oriInventoryZone)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                       $scope.saveItem(); 
                    }
                    $scope.item = angular.copy(oriInventoryZone);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, oriInventoryZone)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(oriInventoryZone); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();