
var module = angular.module('aralco.physicalcount');
var SCANS_TABLE = {
    "name": "SCANS",
    "columns": [
         { "name": "id", "type": "integer", "attribute": "primary key" },
         { "name": "scan_type", "type": "integer" },
         { "name": "reference_id", "type": "integer" },
         { "name": "value", "type": "text" }
    ]
};
var TRANSACTION_TABLE = {
    "name": "TRANSACTIONS",
    "columns": [
         { "name": "number", "type": "integer", "attribute": "primary key" },
         { "name": "status", "type": "integer" }, //Can be 0/1 
         { "name": "type", "type": "integer" },
         { "name": "value", "type": "text" }
    ]
};
var POS_CONFIG_TABLE = {
    "name": "POS_CONFIG",
    "columns": [
             { "name": "config_name", "type": "text" },
             { "name": "config_status", "type": "integer" },  //0 Not Active 1 Active
             { "name": "config_value", "type": "text" } 
             
    ]
};           
module.run(['$ionicPlatform', '$cordovaSQLite', function ($ionicPlatform, $cordovaSQLite) {
    $ionicPlatform.ready(function () {
        /*Create SCANS table if not exist*/    
        var query = "CREATE TABLE IF NOT EXISTS {table} ({columns})";  
        var cols = [];
        _.each(SCANS_TABLE.columns, function (c) {
        cols.push("{name} {type} {attribute}"
                .replace("{name}", c.name)
                .replace("{type}", c.type)
                .replace("{attribute}", c.attribute || '')
                .trim());
        });    
        query = query.replace("{table}", SCANS_TABLE.name)
                      .replace("{columns}", cols.toString());  
        $cordovaSQLite.execute(db, query).then(function (val) {
            console.log("TABLE {table} created".replace("{table}", SCANS_TABLE.name))
        }, function (err) {
            console.log(err.message);
        });    
        /* Create Transactions Table if doesnt exist*/ 
        query = "CREATE TABLE IF NOT EXISTS {table} ({columns})";  
        cols = [];
        _.each(TRANSACTION_TABLE.columns, function (c) {
        cols.push("{name} {type} {attribute}"
                .replace("{name}", c.name)
                .replace("{type}", c.type)
                .replace("{attribute}", c.attribute || '')
                .trim());
        });    
        query = query.replace("{table}", TRANSACTION_TABLE.name)
                      .replace("{columns}", cols.toString());  
        $cordovaSQLite.execute(db, query).then(function (val) {
            console.log("TABLE {table} created".replace("{table}", TRANSACTION_TABLE.name))
        }, function (err) {
            console.log(err.message);
        });  
        /* Create POC CONFIG Table if doesnt exist*/
        query = "CREATE TABLE IF NOT EXISTS {table} ({columns})";  
        cols = [];
        _.each(POS_CONFIG_TABLE.columns, function (c) {
            cols.push("{name} {type} {attribute}"
                    .replace("{name}", c.name)
                    .replace("{type}", c.type)
                    .replace("{attribute}", c.attribute || '')
                    .trim());
        });    
        query = query.replace("{table}", POS_CONFIG_TABLE.name)
                      .replace("{columns}", cols.toString());  
        $cordovaSQLite.execute(db, query).then(function (val) {
            console.log("TABLE {table} created".replace("{table}", POS_CONFIG_TABLE.name))
        }, function (err) {
            console.log(err.message);
        });
    });
}]);
module.factory('localScanService', ['$q', '$http', 'storeFctr', '$cordovaSQLite', 
function ($q, $http, storeFctr, $cordovaSQLite) {
    var self = this;
    
    /// <summary>
    /// Remove all records related to the scan type and the scan ID
    /// </summary>
    /// <param name="scanID">Scan ID</param>
    /// <param name="scan_type">A type of a scan (number)</param>
    var resetScans =  function(scanID, scan_type){
        var query = "DELETE FROM {table} \
                    WHERE  {type_of_scan_column}= {type_of_scan_value} AND \
                            {scan_ID_column} = {value}"
                    .replace("{table}", SCANS_TABLE.name)
                    .replace("{type_of_scan_column}", "scan_type")
                    .replace("{type_of_scan_value}", scan_type)
                    .replace("{scan_ID_column}", "reference_id")
                    .replace("{value}", scanID);
    
        return $cordovaSQLite.execute(db, query);
    };
    
    /// <summary>
    /// Get the scans on the local database
    /// </summary>
    /// <param name="scanID">Scan ID</param>
    /// <param name="scan_type">A type of a scan (number)</param>
    var getScans = function(scanID, scan_type){
        var def = $q.defer();
        var query = "SELECT * FROM {table} \
                    WHERE  {type_of_scan_column} = {type_of_scan_value} AND \
                    {scan_ID_column} = {value}" 
                    .replace("{table}", SCANS_TABLE.name)
                    .replace("{type_of_scan_column}", "scan_type")
                    .replace("{type_of_scan_value}", scan_type)
                    .replace("{scan_ID_column}", "reference_id")
                    .replace("{value}", scanID);
  
        $cordovaSQLite.execute(db, query).then(
            function (data) {
                if (data.rows != null && data.rows.length > 0) {
                    var retval = [];
                    for (var i = 0; i < data.rows.length; i++) {
                        var ci = data.rows.item(i);
                        var s = new scan(JSON.parse (ci.value));
                        _.extend(s, JSON.parse(ci.value));
                        s.ScanID = ci.id;
                        retval.push(s);
                    }
                    data = retval;
  
                }
                else {
                    data = null;
                };
  
                def.resolve(data);
  
            }, function (ex) {
                console.log(ex.message);
                def.reject(ex.message);
            });
          return def.promise;
    };
    /// <summary>
    /// Check if there are any scans which are still in the memory
    /// </summary>
    /// <param name="scan_type">A type of a scan (number)</param>
    var checkPendingScans = function (scan_type){
        var def = $q.defer();
        var query = "SELECT * FROM {table} \
                    WHERE  {type_of_scan_column}= {type_of_scan_value}"
                  .replace("{table}", SCANS_TABLE.name)
                   .replace("{type_of_scan_column}", "scan_type")
                   .replace("{type_of_scan_value}", scan_type);
        $cordovaSQLite.execute(db, query).then(
            function (data) {
                if (data.rows != null && data.rows.length > 0) {
                    var ci = data.rows.item(0);
                    data= ci.reference_id;
                } else {
                    data = null;
                };
                def.resolve(data);
            }, function (ex) {
                console.log(ex.message);
                def.reject(ex.message);
            });           
        return def.promise;
    };     
    /// <summary>
    /// Function to Save a  Scan to Local Database
    /// </summary>
    /// <param name="scan">Scan (object)</param>
    /// <param name="scan_type">A type of a scan (number)</param>
    var saveScan = function (scan,scan_type) {
        /*
        Zeeshan [Cenedex] Notes:
        Before Saving to DB,escape ' (single quote) with ''(two single quotes)
        --replacement is necessary for successfull inserts
        */
        
        // Transfers = 94 which is a special case
        if(scan_type == 94)
            scan.parentReference.replace("-", "\-")

        var def = $q.defer();
        var query = "INSERT INTO {table} ( scan_type, reference_id,  value) VALUES \
                        ({type_of_scan_value} , {scan_ID_value}, '{value}' )"
                    .replace("{table}", SCANS_TABLE.name)
                    .replace("{type_of_scan_value}", scan_type)
                    .replace("{scan_ID_value}", scan.parentReference)
                    .replace("{value}", JSON.stringify(scan).replace(/'/g, "''")); //Refer to Note above
    
        $cordovaSQLite.execute(db, query).then(function (value) {
            def.resolve(value.insertId);
        }, function (ex) {
            console.log(ex.message);
            def.reject(ex.message);
        });
    
        return def.promise;
    };
    
    /// <summary>
    /// Update a scan in Local Database/Qty Chnages
    /// </summary>
    /// <param name="scan">Scan (object)</param>
    /// <param name="scan_type">A type of a scan (number)</param>   
    var updateScan = function (scan,scan_type) {
        /*
        Zeeshan [Cenedex] Notes:
        Before Saving to DB,escape ' (single quote) with ''(two single quotes)
        --replacement is necessary for successfull inserts
        */         
        var def = $q.defer();
        var query = "UPDATE {table} \
                    SET value = '{scan_value}' \
                    WHERE  {type_of_scan_column}= {type_of_scan_value} AND \
                            {scan_ID_column} = {value} AND \
                            {id} = {scan_id}"
                    .replace("{table}", SCANS_TABLE.name)
                    .replace("{type_of_scan_column}", "scan_type")
                    .replace("{type_of_scan_value}", scan_type)
                    .replace("{scan_ID_column}", "reference_id")
                    .replace("{value}", scan.parentReference.replace("-", "\-"))
                    .replace("{scan_value}", JSON.stringify(scan).replace(/'/g, "''")) //Refer Note above
                    .replace("{id}", "id")
                    .replace("{scan_id}", scan.ScanID)
    
        $cordovaSQLite.execute(db, query).then(function (data) {
            def.resolve(scan);
        }, function (ex) {
            def.reject(ex.message);
        });
        return def.promise;
    };

    /// <summary>
    /// Delete a scan in Local Database/Qty Chnages
    /// </summary>
    /// <param name="scan">Scan (object)</param>
    /// <param name="scan_type">A type of a scan (number)</param>   
    var deleteScan = function (scan,scan_type) {
        var def = $q.defer();
    
        var query = "DELETE FROM {table} \
                        WHERE  id = {scan_id} AND \
                        {type_of_scan_column}= {type_of_scan_value}"
                .replace("{table}",  SCANS_TABLE.name)
                .replace("{scan_id}", scan.ScanID)
                .replace("{type_of_scan_column}", "scan_type")
                .replace("{type_of_scan_value}", scan_type)
    
        $cordovaSQLite.execute(db, query).then(function (data) {
            def.resolve(data);
        }, function (ex) {
            def.reject(ex.message);
        });
        return def.promise;
    };

    self.GetScans = getScans;
    self.SaveScan = saveScan;
    self.UpdateScan = updateScan;
    self.DeleteScan = deleteScan;
    self.Reset = resetScans;
    self.CheckPendingScans = checkPendingScans;
    return self;
}]);