﻿/// <reference path="../../Scripts/underscore.js" />
/// <reference path="../../js/aralco.mobile.fw/aralco.mobile.fw.js" />

(function () {
    'use strict';

    var module = angular.module('aralco.login', ['aralco.database', 'base64', 'aralco.localStorage']);

    module.config(['$httpProvider', '$stateProvider', '$urlRouterProvider', '$provide',
        function ($httpProvider, $stateProvider, $urlRouterProvider, $provide) {

            $httpProvider.interceptors.push('httpLoginRequestInterceptor');

            $provide.decorator('$http', ['$delegate', '$injector', function ($delegate, $injector) {
                var _fullname = function (userInfo) {
                    var Result = userInfo.LastName || '';

                    if ((userInfo.FirstName || '') != '') {
                        if (Result != '') {
                            Result = Result + ', ';
                        }

                        Result = Result + userInfo.FirstName;
                    }

                    return Result;
                };

                function addHeaderToConfig(config) {
                    config = config || {};
                    config.headers = config.headers || {};

                    var $base64 = $injector.get('$base64');
                    var localStorageService = $injector.get('localStorageService');
                    var auth = localStorageService.get($f.CONSTANT.LS_KEY);

                    if (!_.isEmpty(auth)) {
                        auth = JSON.parse($base64.decode(auth));
                    } else {
                        auth = {name: '', key: ''};
                    }

                    if (auth.key.trim() != '') {
                        config.headers['CompanyKey'] = auth.key.trim();
                    }

                    if (auth.name.trim() != '') {
                        config.headers['CompanyName'] = auth.name.trim();
                    }

                    config.headers["token"] = $f.sessionTkn.retrieve(false);
                    config.headers["user"] = config.headers["user"] || 'unknown';

                    return config;
                }

                function decorateRegularCall(method) {
                    return function (url, config) {
                        return $delegate[method](url, addHeaderToConfig(config));
                    };
                }

                function decorateDataCall(method) {
                    return function (url, data, config) {
                        return $delegate[method](url, data, addHeaderToConfig(config));
                    };
                }

                function copyNotOverriddenAttributes(newHttp) {
                    for (var attr in $delegate) {
                        if (!newHttp.hasOwnProperty(attr)) {
                            if (typeof ($delegate[attr]) === 'function') {
                                newHttp[attr] = function () {
                                    return $delegate.apply($delegate, arguments);
                                };
                            } else {
                                newHttp[attr] = $delegate[attr];
                            }
                        }
                    }
                }

                var newHttp = function (config) {
                    return $delegate(addHeaderToConfig(config));
                };

                newHttp.get = decorateRegularCall('get');
                newHttp.delete = decorateRegularCall('delete');
                newHttp.head = decorateRegularCall('head');
                newHttp.jsonp = decorateRegularCall('jsonp');
                newHttp.post = decorateDataCall('post');
                newHttp.put = decorateDataCall('put');

                copyNotOverriddenAttributes(newHttp);

                return newHttp;
            }]);

            $stateProvider
                .state('signin', {
                    url: '/login',
                    LoginRequired: false,
                    cache: false,
                    templateUrl: 'modules/login/templates/user-login.html',
                    controller: 'SignInCtrl'
                })

                .state('forgotpassword', {
                    url: '/forgot-password',
                    LoginRequired: false,
                    templateUrl: 'modules/login/templates/forgot-password.html'
                });
        }]);

    module.run(['$ionicPlatform', '$state', '$rootScope', 'accountFctr', 'localStorageService', '$base64', '$q',
        function ($ionicPlatform, $state, $rootScope, accountFctr, localStorageService, $base64, $q) {
            $ionicPlatform.ready(function () {
               // $state.reload();

              //  var isLogged = accountFctr.isLogged();

                $rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams) {
                    var isLogged = accountFctr.isLogged();

                    if (toState.name == 'signin' && $f.isLogged) {
                        event.preventDefault();
                    } else {
                        var loginRequired = toState.LoginRequired;

                        if (_.isUndefined(loginRequired)) {
                            loginRequired = true;
                        }

                        if (loginRequired && !$f.isLogged) {
                            $state.transitionTo('signin');
                            event.preventDefault();
                        }
                    }
                });

                $ionicPlatform.registerBackButtonAction(function (event) {
                    if ($ionicHistory.currentStateName() == 'signin') {
                        accountFctr.isLogged().then(function (val) {
                            if (!val)
                                ionic.Platform.exitApp();
                        });
                    }
                });

                //  accountFctr.logout();
            });
        }]);

    module.factory("accountFctr", ["$q", '$http', '$rootScope', 'errorFctr', 'localStorageService', '$base64', '$location', '$state', '$ionicLoading', '$ionicHistory','popupFctr', '$timeout',
        function ($q, $http, $rootScope, errorFctr, localStorageService, $base64, $location, $state, $ionicLoading, $ionicHistory,popupFctr, $timeout) {
            var self = this;
            // Checks if user is logged in *actTime = last Active Time
            self.isLogged = function (actTime) {
                var user = localStorageService.get($f.CONSTANT.USER_INFO);
                $f.isLogged = (!(angular.isUndefined(user) || _.isEmpty(user)));
                // If actTime is not defined then set to 0 so it doesn't break the code
                actTime = actTime || 0;
                // Check for user activity only if one is logged in and defined
                if($f.isLogged &&(!angular.isUndefined(user) && !_.isEmpty(user))){
                    if(actTime !== 0){
                        // $f.actTime = $f.actTime || new Date();
                        // var actTimeLimit = new Date($f.actTime.setMinutes($f.actTime.getMinutes() + $f.timeOut ));
                        // $f.actTime = actTime;
                        // If lastest action passes the timeout then logout
                        // if($f.actTime > actTimeLimit){
                        //     $ionicLoading.show({
                        //         template: 'This session has timed out, please re-log in!'
                        //     });
                        //     $timeout(function(){self.logout()}, 2000);
                        // } else {
                        // Else try to update the latest action time in the database
                            self.update(user.config.headers.CompanyKey).then(function (result) {
                                // If update fails then the session has timed out
                                if (result.status === 204) {
                                    $ionicLoading.show({
                                        template: 'This session has timed out, please re-log in!'
                                    });
                                    $timeout(function () {
                                        self.logout(true)
                                    }, 2000);
                                } else {
                                    $f.Login(user.data);
                                }
                            });
                        // }
                    }
                }
                return $f.isLogged;
            };

            self.isLoggedAsync = function () {
                var def = $q.defer();
                var user = localStorageService.get($f.CONSTANT.USER_INFO);
                // noinspection NodeModulesDependencies,ES6ModulesDependencies
                $f.isLogged = $f.isLogged || (!(angular.isUndefined(user) || _.isEmpty(user)));
                if($f.isLogged) {
                    self.update(user.config.headers.CompanyKey).then(function (result) {
                        // If update fails then the session has timed out
                        if (result.status === 204) {
                            def.reject();
                        } else {
                            def.resolve();
                        }
                    });
                } else {
                    def.reject();
                }
                return def.promise;
            };

            var goToDefault = function () {
                $ionicHistory.clearHistory();

                $ionicHistory.nextViewOptions({
                    historyRoot: true
                });
                $location.path('/the_otherwise_state'); // state with this URL doesn't exist
                $location.replace();

            };


            $rootScope.$watch(function () {
                return localStorageService.get($f.CONSTANT.APP_INFO);
            }, function watchCallback(newValue, oldValue) {
                if (newValue != oldValue && self.isLogged) {
                    self.logout();
                }
            });

            var _keysfunction = {

                $get: function () {
                    var def = $q.defer();
                    try {
                        var auth = localStorageService.get($f.CONSTANT.LS_KEY);
                        if (!_.isEmpty(auth)) {
                            auth = JSON.parse($base64.decode(auth));
                        } else {
                            auth = {name: '', key: ''};
                        }

                        def.resolve(auth);

                    } catch (e) {
                        def.reject(e);
                    }

                    return def.promise;
                },

                $set: function (value) {
                    var def = $q.defer();
                    var auth = $base64.encode(JSON.stringify(value))
                    localStorageService.set($f.CONSTANT.LS_KEY, auth);
                    this.$get().then(function (result) {
                        def.resolve(result);
                    });
                    return def.promise;
                },

                $reset: function () {
                    var def = $q.defer();
                    var res = false;
                    try {
                        self.logout().then(function (res) {
                            res = localStorageService.remove($f.CONSTANT.LS_KEY);
                            $ionicHistory.clearCache();
                            $rootScope.$broadcast('keyreset');
                            def.resolve(res);
                        }, function (err) {
                            def.reject(err);
                        })

                    } catch (e) {
                        def.reject(res);
                    }

                    return def.promise;
                }
            };

            self.update = function (authkey){
                    var url = $f.serviceUrl + "login/update";
                    var req = {
                        method: 'GET',
                        url: url,
                        headers: {}
                    };
                    req.headers["CompanyKey"] = authkey;
                    req.headers["token"] = $f.sessionTkn.retrieve(true);
                    return $http(req);

            };

            self.login = function (authkey, username, password, forceLoad) {
                var deferred = $q.defer();

                // To satisfy the login
                var compname = '1';
                //debugger;

                var reject = function (data) {
                    deferred.reject(data);
                };

                var _addConnection = function (authkey, compname) {
                    var url = $f.serviceUrl + "login/Add";
                    var req = {
                        method: 'GET',
                        url: url,
                        headers: {}
                    };
                    req.headers["uslg"] = $base64.encode(username + ":" + password);
                    req.headers["CompanyKey"] = authkey;
                    req.headers["CompanyName"] = compname;
                    req.headers["user"] = username;
                    req.headers["token"] = $f.sessionTkn.retrieve(true);
                    return $http(req);
                };

                var _parseBosOptions = function(bosOptions = null) {
                    try{
                        if (bosOptions == null || bosOptions.length !== 8) return null;
                        let toReturn = {};
                        let index = parseInt("0x0000000" + bosOptions.substr(-1,1));
                        if (isNaN(index)) return null;
                        toReturn.inUse = index - 8 >= 0; // true if In Use is set in BOS
                        if (toReturn.inUse) index = index - 8; // decrement if true
                        toReturn.Pos = index - 4 >= 0; // true if POS is set in BOS
                        if (toReturn.Pos) index = index - 4; // decrement if true
                        toReturn.Advanced = index - 2 >= 0; // true if Advanced is set in BOS
                        if (toReturn.Advanced) index = index - 2; // decrement if true
                        toReturn.Basic = index - 1 >= 0; // true if Basic is set in BOS
                        return toReturn;
                    } catch (e) {
                        console.error(e);
                        return null;
                    }
                };

                _addConnection(authkey, compname)
                    //.then(executelogin)
                    .then(function (data) {
                        data.Date = new Date();
                        data.data.BosOptions = _parseBosOptions(base64toHex(data.data.BosOptions));
                        //console.log(data.data.BosOptions);
                        if (data.data.BosOptions == null || !(data.data.BosOptions.Basic ||
                            data.data.BosOptions.Advanced  || data.data.BosOptions.Pos)) {
                            // ^ Should never evaluate to true since it's caught in the API but I included it anyways for redundancy.
                            let error = new Error("You are not authorized to login to the mobile system.");
                            error.doNotRethrow = true;
                            throw error;
                        }
                        $f.Login(data.data);                            
                        /*set name and company on ls*/
                        _keysfunction.$set({
                            name: compname,
                            key: authkey
                        });
                        /*communicate that the user is logged in*/
                        $rootScope.$broadcast('loggedin', {k: authkey, n: compname, user: data});
                        deferred.resolve(data);
                    })
                    .catch(reject);

                return deferred.promise;
            };

            self.logout = function (quite = false) {
                var deferred = $q.defer();
                try {
                    if (!quite) {
                        $ionicLoading.show({
                            template: 'Logout...'
                        });
                    }

                    /*Remove sessions info from the server*/
                    var executeLogout = function (name, key, tkn) {
                        var url = $f.serviceUrl + "login/Logout";
                        var req = {
                            method: 'get',
                            url: url,
                            headers: {}
                        };

                        req.headers["CompanyKey"] = name;
                        req.headers["CompanyName"] = key;
                        req.headers["token"] = tkn;
                        return errorFctr.specificallyHandled(function () {
                            $http(req);
                        });
                    };

                    self.keys.$get().then(function (aut) {
                        try {
                            executeLogout(aut.name, aut.key, $f.sessionTkn.retrieve(false));
                        } catch (e) {
                        }

                        $f.Logout();

                        $ionicHistory.clearHistory();
                        $rootScope.$broadcast('signout');
                        deferred.resolve(true);
                    });

                } catch (e) {
                    $ionicLoading.hide();
                    deferred.reject(false);
                }
                return deferred.promise;
            };
            
            self.keys = _keysfunction;

            $rootScope.$on('loggedin', function (event, args) {
                localStorageService.set($f.CONSTANT.USER_INFO, args.user);
                $ionicLoading.hide();
                goToDefault();
                //Before Showing Dashboard ,Show Popup asking user to Confirm Date&Time
                // popupFctr.confirm('Date and Time Confirmation','Please make sure that System date and time is in Sync?').then(function (val) {
                //     if (val == true) {
                //          goToDefault();
                //     }
                //     else{
                //         popupFctr.alert('Not Allowed', 'Date and Time Needs To Be Confirmed!');
                //         goToDefault();
                //         $state.go('signin');
                //     }
                // });

            });

            $rootScope.$on('signout', function () {
                $ionicLoading.hide();
                goToDefault();
                $state.go('signin');
            });

            return self;
        }]);

    module.controller('SignInCtrl', ['$scope', '$location', 'accountFctr', '$rootScope', 'popupFctr', 'errorFctr', '$ionicLoading', '$ionicModal', function ($scope, $location, accountFctr, $rootScope, popupFctr, errorFctr, $ionicLoading, $ionicModal) {
        init();

        function init() {
            $scope.user = {};
            $scope.KeyMissing = false;

            accountFctr.keys.$get().then(function (aut) {
                $scope.user.key = aut.key;
                $scope.KeyMissing = ( $scope.user.key.trim() == '');
            });
        }

        $scope.getNextControl = function (user) {
            var isValidLogin = $scope.invalidLogin(user);
            var elName = null;

            if (!isValidLogin) {
                //user.key, user.name, user.username, user.password  // What's the intent here?

                if (_.isEmpty(user.username)) {
                    elName = "usrtxt";
                } else if (_.isEmpty(user.password)) {
                    elName = "pwdtxt";
                } else if (_.isEmpty(user.key)) {
                    elName = "pktxt";
                }
            }
            if (elName != null) {
                //var el = angular.element(document.querySelector(elName));
                var el = document.getElementById(elName);
              if (!_.isNull(el)) {
                   /*if (!_.isArray(el)) {
                        el = [el];
                    }*/

                    el.focus();
             }
            } else {
                $scope.signIn(user);
            }
        };

        $scope.invalidLogin = function (user) {
            return ((user.key || '').trim() != '' && (user.username || '').trim() != '' && (user.password || '').trim() != '');
        };

        $scope.signIn = function (user) {
            //THis is for Setting up Notification Sound
            popupFctr.notificationSound = null;
            popupFctr.playNotificationSound();
            errorFctr.specificallyHandled(function () {
                $ionicLoading.show({
                    template: 'Login...'
                });

            var timer = setTimeout( $ionicLoading.show({
                    template: 'Establishing Cloud connection, please wait...'
            }), 3000);

                accountFctr.login(user.key, user.username, user.password)
                    .then(function () {
                        $ionicLoading.hide();
                        clearTimeout(timer);
                        init();
                    }, function (error) {                       
                        error = error || {};
                        $ionicLoading.hide();
                        clearTimeout(timer);
                        if(error.data != null && error.data.constructor === Array){
                            $ionicLoading.hide();
                            showActiveUserModal(error.data);
                        }else{
                            if (!error.doNotRethrow){
                                var defaultError = 'Connection to the cloud has failed, Please try again!';
                                error.data = error.data || {};
                                error.data = error.data.Message || error.data.message || defaultError;
                                let message = error.ExceptionMessage || error.Message || error.data;
                                let newError = new Error(message);
                                newError.title = (message !== defaultError)?"Login Failed":"Cloud Connection Failed";
                                newError.useInner = true;
                                throw newError;
                            }
                            // popupFctr.alert('Login Error', message);
                        }            
                    });
            });
        };

        $scope.logOut = function () {
            accountFctr.logout().then(function () {
                init();
            });
        };

        function showActiveUserModal(data){
                //Show Popup To Select A Store
                $scope.users = data;
               
                $ionicModal.fromTemplateUrl('modules/login/templates/activeUser-list.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    $scope.activeUserModal = modal;
                    $scope.activeUserModal.show();
                });


                function closeModal(){
                     $scope.activeUserModal.remove();
                };

                $scope.$on('$destroy', function () {
                    $scope.activeUserModal.remove();
                });
                $scope.Ok = function () {
                    closeModal();
                }
                $scope.Cancel = function () {
                    closeModal();
                }
            }

        $rootScope.$on('keyreset', function (event, args) {
            init();
        });
    }]);

    module.factory('httpLoginRequestInterceptor', function () {
        return {
            error: function (response) {
                if (response.status === 401) {
                    $location.path('/login');
                    return $q.reject(response);
                } else {
                    return $q.reject(response);
                }
            }
        };
    });

})();
