(function () {
    
	var module = angular.module('aralco.pointsplan',['ionic']);
	
	module.factory('pointsPlanFactory', function($filter) {

        var elementId = 6;
        
		var pointsPlans = [
			{
                ID: 1,
				name: "Grocery",
                desc: "Grocery",
                point: 0  
			},
			{
                ID: 2,
				name: "Apparel",
				desc: "Apparel",
                point: 0  
			},
			{
                ID: 3,
				name: "Footwear",
				desc: "Footwear",
                point: 0  
			},
			{
                ID: 4,
				name: "Landscaping",
				desc: "Landscaping",
                point: 0  
			},
			{
                ID: 5,
				name: "Furniture",
				desc: "Furniture",
                point: 0  
			}
		];
        
		return {
			getPointsPlans : function(searchText) {
				return $filter('filter')(pointsPlans, {name: searchText})
			},
			addPointsPlan : function(pointsPlan) {
                var temp = {
                    ID: elementId++,
					name: pointsPlan.name,
                    desc: pointsPlan.desc,
                    point: pointsPlan.point
				}

				pointsPlans.push(temp);
			},
			deletePointsPlan: function(item) {
                var index = pointsPlans.findIndex(pointsPlan => pointsPlan.ID == item.ID);
                pointsPlans.splice(index, 1);
            },
			savePointsPlan: function(item,pointsPlan) {
                var index = pointsPlans.findIndex(pointsPlan => pointsPlan.ID == item.ID);
				pointsPlans[index].name = pointsPlan.name;
                pointsPlans[index].desc = pointsPlan.desc;
                pointsPlans[index].point = pointsPlan.point;
			},
			getPointsPlanByIndex : function(item) {
                return pointsPlans.filter(pointsPlan => pointsPlan.ID == item.ID)[0];
            }
		};
	});
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
    
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.pointsplan', {
			url: '/pointsplan',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/points_plan/templates/points-plan.html',
					controller: 'PointsPlanController'
				}
			}
		})
		.state('tab.editpointsplans', {
			url: '/editpointsplan/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/points_plan/templates/points-plan-edit.html',
                    controller: 'EditPointsPlanController'
				}
			}
		})
		.state('tab.addpointsplans', {
			url: '/editpointsplan/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/points_plan/templates/points-plan-edit.html',
                    controller: 'AddPointsPlanController'
				}
			}
		})
	}]);

    module.controller('PointsPlanController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,pointsPlanFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editPointsPlan' && $scope.selectedItem != null){
                $state.go('tab.editpointsplans',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addPointsPlan'){
                $state.go('tab.addpointsplans',{name: 'addPointsPlan'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deletePointsPlan = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        pointsPlanFactory.deletePointsPlan($scope.selectedItem);
                        $rootScope.$emit('updatePointsPlans', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(pointsPlanFactory.getPointsPlans($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updatePointsPlans', function(event, arg) {
            $scope.entries = angular.copy(pointsPlanFactory.getPointsPlans($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditPointsPlanController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,pointsPlanFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.pointsPlan = angular.copy(pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.pointsPlan.name;
        
        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.pointsPlan.desc.length == 0) {
                $scope.pointsPlan.desc = $scope.pointsPlan.name;
            }
        }
        
        $scope.goBack = function() {
            if(!angular.equals($scope.pointsPlan, pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePointsPlan(); 
                        if(angular.isDefined($scope.pointsPlan.point)) {
                            $ionicHistory.goBack();
                        }
                    }
                    else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.savePointsPlan = function() {
            if(angular.isDefined($scope.pointsPlan.point)) {
                pointsPlanFactory.savePointsPlan($scope.selectedItem,$scope.pointsPlan);
                $rootScope.$emit('updatePointsPlans', {
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            }
            else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input',
                    subTitle: ''
                })
            }
        }

        $scope.clearPointsPlan = function() {
            if(!angular.equals($scope.pointsPlan, pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePointsPlan(); 
                    }
                    else{
                        $scope.pointsPlan = angular.copy(pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deletePointsPlan = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    pointsPlanFactory.deletePointsPlan($scope.selectedItem);
                    $rootScope.$emit('updatePointsPlans', {
                        editType: "Deleted"
                    });
                    
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.pointsPlan, pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.pointsPlan = angular.copy(pointsPlanFactory.getPointsPlanByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddPointsPlanController', function($scope,$ionicPopup,$ionicHistory,$rootScope,pointsPlanFactory){
        $scope.showSearchbar = true;
        $scope.pointsPlan = {
            name : "",
            desc : "",
            point: 0
        }
        var oriPointsPlan = angular.copy($scope.pointsPlan);

        $scope.autoFillDescription = function() {
            if($scope.pointsPlan.desc.length == 0) {
                $scope.pointsPlan.desc = $scope.pointsPlan.name;
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.pointsPlan, oriPointsPlan)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePointsPlan();
                        if(angular.isDefined($scope.pointsPlan.point)) {
                            $ionicHistory.goBack();
                        } 
                    }
                    else {
                        $ionicHistory.goBack();
                    }
                    
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.savePointsPlan = function() {
            if(!angular.equals($scope.pointsPlan, oriPointsPlan)) {
                if(angular.isDefined($scope.pointsPlan.point)) {
                    pointsPlanFactory.addPointsPlan($scope.pointsPlan);
                    $rootScope.$emit('updatePointsPlans', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.pointsPlan = angular.copy(oriPointsPlan);
                    })
                }
                else {
                    var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                    })
                }
            }
        }

        $scope.addPointsPlan = function() {
            $scope.clearPointsPlan();
        }

        $scope.clearPointsPlan = function() {
            if(!angular.equals($scope.pointsPlan, oriPointsPlan)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePointsPlan();
                        if(angular.isDefined($scope.pointsPlan.point)) {
                            $scope.pointsPlan = angular.copy(oriPointsPlan);
                        } 
                    }
                    else {
                        $scope.pointsPlan = angular.copy(oriPointsPlan);
                    }
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.pointsPlan, oriPointsPlan)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.pointsPlan = angular.copy(oriPointsPlan); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();