﻿/// <reference path="../../Scripts/underscore.js" />
(function () {

    'use strict';

    var module = angular.module('aralco.pos');

    module.run(['$ionicPlatform', '$cordovaSQLite', function ($ionicPlatform, $cordovaSQLite) {
        $ionicPlatform.ready(function () {
            /*Create TENDKEYS table if not exist*/

            $cordovaSQLite.execute(db, "CREATE TABLE IF NOT EXISTS TENDKEY (id integer primary key, number text, json text)").then(function (val) {
                console.log('TABLE TENDKEY CREATED')
            }, function (err) {
                console.log(err.message);
            });
        });
    }]);

    module.factory('tendKeyFctr', ['$http', '$rootScope', '$q', '$cordovaSQLite',
        function ($http, $rootScope, $q, $cordovaSQLite) {
            var self = this;

            function key() {
                this.Position = 1;
                this.Number = '-';
                this.Description = '';
                this.AllowChange = false;
                this.RefDescription = '';
                this.Symbol = '';
                this.IsCard = false,
                this.CashType = false;
                this.lastUdpdate = null;
            }

            var _getRemoteKeys = function (id, forceLoad) {

                /// <summary>
                /// Return the required TendKeys
                /// </summary>
                /// <param name="id"></param>
                /// <param name="page"></param>
                /// <returns type=""></returns>
                var def = $q.defer();
                if ($f.isLogged) {

                    id = id || '';
                    forceLoad = forceLoad || $f.ForceLoad;
                    var url = "/TendKey/Get/{ID}?ForceLoad={ForceLoad}";

                    url = url.replace("{ID}", id || '').replace("{ForceLoad}", forceLoad);

                    url = $f.serviceUrl + url;

                    var httpreq = {
                        method: 'get',
                        url: url
                    }

                    $http(httpreq).success(
                        function (data, status, headers, config) {
                            var retval = null;
                            if (data != null) {
                                _.forEach(data, function (k) {
                                    var item = new key();
                                    retval = retval || [];
                                    _.extend(item, k);
                                    retval.push(item);
                                });
                            }

                            def.resolve(retval);

                        }).error(
                    function (data, status, headers, config) {
                        def.resolve(null);
                    });
                }
                else {
                    def.resolve(null);
                }

                return def.promise;
            }

            var _getFromDb = function () {
                /*get all the keys from the database*/
                var def = $q.defer();
                $cordovaSQLite.execute(db, "SELECT json FROM TENDKEY").then(
                    function (data) {


                        if (data != null && data.rows != null && data.rows.length > 0) {
                            var tks = [];
                            for (var i = 0; i < data.rows.length; i++) {
                                tks.push(JSON.parse(data.rows.item(i).json))
                            }
                            data = tks;
                        } else {
                            data = null;
                        }


                        if (data == null || _.isEmpty(data)) {
                            _getRemoteKeys().then(function (res) {
                                def.resolve(res);
                            });
                        }
                        else {
                            def.resolve(data);
                        }

                    }, function (ex) {
                        var msg = ex.message;
                        console.log(msg);
                        def.reject(msg);
                    });

                return def.promise;
            }

            var _saveOnDb = function (keys) {
                /*save the keys on the database*/
                var def = $q.defer();

                if (keys) {
                    /*if it's not an array, then I will transform to it*/
                    if (!_.isArray(keys))
                        keys = [keys];
                    var promises = [];
                    promises.push($cordovaSQLite.execute(db, "DELETE FROM TENDKEY"));//remove all the previous tend keys
                    _.each(keys, function (k) {
                        promises.push($cordovaSQLite.execute(db, "INSERT INTO TENDKEY (number, json) VALUES('" + k.Number + "','" + JSON.stringify(k).replace(/'/g, "''") + "')"));
                        $q.all(promises).then(function () {
                            def.resolve();
                        }, function (ex) {
                            var msg = ex.message
                            console.log(msg);
                            def.reject(msg);
                        })
                    });
                }
                else {
                    def.reject();
                }

                return def.promise;
            }

            var _remove = function (key) {
                /// <summary>
                /// Remove the records from the database
                /// </summary>
                /// <param name="keys"></param>
                /// <returns type=""></returns>
                var def = $q.defer();
                key = key || null;
                $cordovaSQLite.execute(db, "DELETE FROM TENDKEY WHERE Number = '" + key + "'");

            }


            var _refresh = function () {
                var def = $q.defer();

                _getRemoteKeys().then(function (keys) {
                    _saveOnDb(keys).then(function () {
                        _getFromDb().then(function (dbk) {
                            def.resolve(dbk);
                        });
                    });
                })


                return def.promise;
            }


            var _get = function (mode) {
                /*Modes:
                 * 0 => remote + local (refresh and return)
                 * 1 => just remote (no refreshing)
                 * 2 => local (if nothing present, get from remote, than return from local)
                 */


                mode = mode || 2;

                switch (mode) {

                    case 0:
                    default:
                        return _refresh();
                        break;
                    case 1:
                        return _getRemoteKeys();
                        break;
                    case 2:
                        return _getFromDb();
                        break;

                }


            };

            self.$get = _get;

            self.$refresh = _refresh;

            self.$save = _saveOnDb;

            self.$delete = _remove;
            return self;

        }]);

}

)();