angular.module('aralco.pos.services').factory('sessionFctr', 
['$q', '$http', 
function ($q, $http) {

        this.Get = function (storeId, registerCode, lockedBy) {
            /// <summary>
            /// Load list of registers
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/Get?StoreID='+storeId+'&RegisterCode='+registerCode+'&LockedBy='+lockedBy;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.IsSession = function (sessionId, posSystem){
            /// <summary>
            /// Get Recorded Tender Keys related to this session
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/IsSession?SessionID=' + sessionId + '&POSSystem=' + posSystem;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.IsTransaction = function (posSystem){
            /// <summary>
            /// Checks for any pending transactions for this register
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/IsTransaction?POSSystem=' + posSystem;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.GetNextTransNo = function (storeId, registerCode, transType){
            /// <summary>
            /// Checks for any pending transactions for this register
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/GetNextTransNo?StoreID=' + storeId + '&registerCode=' + registerCode + '&transtype=' + transType;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.StartOfDay = function (session){
            var exchangeItems = [];
            if (session.Exchanges.length > 0){
                for(var i=0;i<session.Exchanges.length;i++){
                    var exCh = {
                        "TenderCode": session.Exchanges[i].Code,
                        "ExchangeRate": session.Exchanges[i].ExchangeRate,
                    }
                    exchangeItems.push(exCh);
                }   
            }

            /// <summary>
            /// Start Session
            /// </summary>
            var deferred = $q.defer();
            var paramsValues =  {
                "StoreID": session.store.ID,
                "RegisterID": session.register.RegisterID,
                "ClerkID": $f.UserInfo.EmployeeID,
                "SODFloat": session.sodFloat,
                "POSSystem": session.store.Code + '_' + session.register.RegisterCode + '_' + $f.UserInfo.EmployeeID,
                "LockedBy": $f.UserInfo.EmployeeID,
                "SessionExchange": exchangeItems
            }

            var url = $f.serviceUrl + "POS/StartOfDay";
            var req = {
                method: 'post',
                url: url,
                data:paramsValues
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.EndOfDay = function (session){
            /// <summary>
            /// Start Session
            /// </summary>
            var deferred = $q.defer();
            
            var sessionTenders = [];

            for(var i=0;i<session.countedTendKeys.length;i++){
                var tender = {
                    "TenderCode": session.countedTendKeys[i].Code,
                    "Recorded": session.countedTendKeys[i].Recorded,
                    "Counted": session.countedTendKeys[i].Counted,
                    "ShortOver": session.countedTendKeys[i].ShortOver 
                }
                sessionTenders.push(tender);
            }
            
            var paramsValues =  {
                "StoreID": session.store.ID,
                "RegisterID": session.register.RegisterID,
                "ClerkID": $f.UserInfo.EmployeeID,
                "EODFloat": session.eodFloat,
                "BankDeposit": session.bankDeposit,
                "DepositReference": null,
                "WalkIns": 0,
                "GrossSales": session.payments.total,
                "Tax1": session.payments.tax1,
                "Tax2": session.payments.tax2,
                "LayDeposits": 0,
                "LayPrevDeposits": 0,
                "MoneyReceived": 0,
                "MoneyPaidOut": 0,
                "GiftCertIssued": 0,
                "GiftCertRedeemed": 0,
                "CreditNoteIssued": 0,
                "CreditRedeemed": 0,
                "GiftCardSold": 0,
                "GiftCardUsed": 0,
                "TotalShortOver": session.ShortOver,
                "ShortOverReason": session.ShortOverReason,
                "SessionTender": sessionTenders,
                "Receipt": session.receipt
            }

            var url = $f.serviceUrl + "POS/EndOfDay";
            var req = {
                method: 'post',
                url: url,
                data:paramsValues
            }

            $http(req).
              success(function (data, status, headers, config) {
                deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.GetRecordedTenders = function (sessionId, posSystem){
            /// <summary>
            /// Get Recorded Tender Keys related to this session
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/GetRecordedTenders?SessionID=' + sessionId + '&POSSystem=' + posSystem;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.GetPaymentTotals = function (sessionId, posSystem){
            /// <summary>
            /// Get Recorded Tender Keys related to this session
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/GetPaymentTotals?SessionID=' + sessionId + '&POSSystem=' + posSystem;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.GetExchangeRates = function (sessionId, posSystem){
            /// <summary>
            /// Get Exchange Rates related to this session
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();

            var url = $f.serviceUrl + 'pos/GetExchangeRates?SessionID=' + sessionId + '&POSSystem=' + posSystem;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }
        return this;
    }]);