(function () {
    
	var module = angular.module('aralco.possalutations',['ionic']);
	
	module.factory('salutationFactory', function($filter) {

        var elementId = 8;

		var salutations = [
			{
                ID: 1,                
				name: "Ms",
				desc: "Miss"  
			},
			{
                ID: 2,
				name: "Mrs.",
				desc: "Misses"
			},
			{
                ID: 3,
				name: "Miss",
				desc: "Miss"
			},
			{
                ID: 4,
				name: "Mr.",
				desc: "Mister"
			},
			{
                ID: 5,
				name: "DR.",
				desc: "Doctor"
			},
			{
                ID: 6,
				name: "Rev.",
				desc: "Rev."
			},
			{
                ID: 7,
				name: "Prof.",
				desc: "Professor"
			}
        ];
        
		return {
			getSalutations : function(searchText) {
                return $filter('filter')(salutations, {name: searchText})
			},
			addSalutation : function(salutation) {
				var temp = {
                    ID: elementId++,
					name: salutation.name,
					desc: salutation.desc
				}

				salutations.push(temp);
			},
			deleteSalutation: function(item) {
                var index = salutations.findIndex(salutation => salutation.ID == item.ID);
                salutations.splice(index, 1);
            },
            
            saveSalutation: function(item,salutation) {
                var index = salutations.findIndex(salutation => salutation.ID == item.ID);
                salutations[index].name = salutation.name;
                salutations[index].desc = salutation.desc;
            },
            
            getSalutationByIndex : function(item) {
                return salutations.filter(salutation => salutation.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.possalutations', {
			url: '/possalutations',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/pos_salutations/templates/salutations.html',
					controller: 'PosSalutationController'
				}
			}
		})
		.state('tab.editpossalutations', {
			url: '/editpossalutation/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/pos_salutations/templates/salutations-edit.html',
                    controller: 'EditPosSalutationController'
				}
			}
		})
		.state('tab.addpossalutations', {
			url: '/editpossalutation/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/pos_salutations/templates/salutations-edit.html',
                    controller: 'AddPosSalutationController'
				}
			}
		})
	}]);

    module.controller('PosSalutationController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,salutationFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editSalutation' && $scope.selectedItem != null){
                $state.go('tab.editpossalutations',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addSalutation'){
                $state.go('tab.addpossalutations',{name: 'addSalutation'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteSalutation = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        salutationFactory.deleteSalutation($scope.selectedItem);
                        $rootScope.$emit('updateSalutations', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(salutationFactory.getSalutations($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateSalutations', function(event, arg) {
            $scope.entries = angular.copy(salutationFactory.getSalutations($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditPosSalutationController', function($scope,$state,$stateParams,$ionicHistory,$ionicPopup,$rootScope,salutationFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.salutation = angular.copy(salutationFactory.getSalutationByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.salutation.name;
        
        
       

        
            
            {
        }
        
        $scope.autoFillDescription = function() {
            if($scope.salutation.desc.length == 0) {
                $scope.salutation.desc = $scope.salutation.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.salutation, salutationFactory.getSalutationByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveSalutation(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveSalutation = function() {
            salutationFactory.saveSalutation($scope.selectedItem,$scope.salutation);
            $rootScope.$emit('updateSalutations', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            }).then(function() {
                oriSalutation = angular.copy($scope.salutation);
            })
        }

        $scope.clearSalutation = function() {
            if(!angular.equals($scope.salutation, salutationFactory.getSalutationByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveSalutation(); 
                    }
                    else{
                        $scope.salutation = angular.copy(salutationFactory.getSalutationByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteSalutation = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    salutationFactory.deleteSalutation($scope.selectedItem);
                    $rootScope.$emit('updateSalutations', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.salutation, salutationFactory.getSalutationByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.salutation = angular.copy(salutationFactory.getSalutationByIndex($scope.selectedItem)); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddPosSalutationController', function($scope,$ionicPopup,$ionicHistory,$rootScope,salutationFactory){
        $scope.showSearchbar = true;
        $scope.salutation = {
            name : "",
            desc : ""
        }
        var oriSalutation = angular.copy($scope.salutation);

        $scope.autoFillDescription = function() {
            if($scope.salutation.desc.length == 0) {
                $scope.salutation.desc = $scope.salutation.name;
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.salutation, oriSalutation)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveSalutation(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveSalutation = function() {
            if(!angular.equals($scope.salutation, oriSalutation)) {
                salutationFactory.addSalutation($scope.salutation);
                $rootScope.$emit('updateSalutations', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.salutation = angular.copy(oriSalutation);
                })
            }
        }

        $scope.addSalutation = function() {
            $scope.clearSalutation();
        }

        $scope.clearSalutation = function() {
            if(!angular.equals($scope.salutation, oriSalutation)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveSalutation(); 
                    }
                    $scope.salutation = angular.copy(oriSalutation);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.salutation, oriSalutation)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.salutation = angular.copy(oriSalutation); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();