(function () {
    
	var module = angular.module('aralco.pricerounding',['ionic']);
	
	module.factory('priceRoundingFactory', function($filter) {
        
        var elementId = 5;

		var priceRoundings = [
			{
                ID: 1,
                fromPrice: 0,
                toPrice: 0.99,
                roundToNearest: 0,
                reduceBy: 0,
                name: "0 - 0.99"
            },
            {
                ID: 2,
                fromPrice: 1,
                toPrice: 4.99,
                roundToNearest: 0,
                reduceBy: 0,
                name: "1 - 4.99"
            },
            {
                ID: 3,
                fromPrice: 5,
                toPrice: 9.99,
                roundToNearest: 0,
                reduceBy: 0,
                name: "5 - 9.99"
            },
            {
                ID: 4,
                fromPrice: 10,
                toPrice: 49.99,
                roundToNearest: 0,
                reduceBy: 0,
                name: "10 - 49.99"
            }
		];

		return {
			getPriceRoundings : function(searchText) {
				return $filter('filter')(priceRoundings, {name: searchText})
            },
            addPriceRounding : function(priceRounding) {
                var temp = {
                    ID: elementId++,
                    fromPrice: priceRounding.fromPrice,
                    toPrice: priceRounding.toPrice,
                    roundToNearest: priceRounding.roundToNearest,
                    reduceBy: priceRounding.reduceBy,
                    name: priceRounding.fromPrice.toString() + " - " + priceRounding.toPrice.toString()
                }

                priceRoundings.push(temp);
            },
            deletePriceRounding: function(item) {
                var index = priceRoundings.findIndex(priceRounding => priceRounding.ID == item.ID);
                priceRoundings.splice(index, 1);
            },
            savePriceRounding: function(item,priceRounding) {
                var index = priceRoundings.findIndex(priceRounding => priceRounding.ID == item.ID);
                priceRoundings[index].fromPrice = (priceRounding.fromPrice != undefined? priceRounding.fromPrice: 0);
                priceRoundings[index].toPrice = (priceRounding.toPrice != undefined? priceRounding.toPrice: 0);
                priceRoundings[index].roundToNearest = (priceRounding.roundToNearest != undefined? priceRounding.roundToNearest: 0);
                priceRoundings[index].reduceBy = (priceRounding.reduceBy != undefined? priceRounding.reduceBy: 0);
                priceRoundings[index].name = priceRoundings[i].fromPrice.toString() + " - " + priceRoundings[i].toPrice.toString()
			},
			getPriceRoundingByIndex : function(item) {
                return priceRoundings.filter(priceRounding => priceRounding.ID == item.ID)[0];
            }
		};
    });
    
    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.priceroundings', {
			url: '/priceroundings',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'PriceRoundingController'
				}
			}
		})
		.state('tab.editpriceroundings', {
			url: '/editpricerounding/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/price_rounding/templates/price-rounding-edit.html',
                    controller: 'EditPriceRoundingController'
				}
			}
		})
		.state('tab.addpriceroundings', {
			url: '/editpricerounding/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/price_rounding/templates/price-rounding-edit.html',
                    controller: 'AddPriceRoundingController'
				}
			}	
		})
	}]);

    module.controller('PriceRoundingController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,priceRoundingFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Manage Price Rounding";
        $scope.searchTitle = "Price Roundings"

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editpriceroundings',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addpriceroundings',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        priceRoundingFactory.deletePriceRounding($scope.selectedItem);
                        $rootScope.$emit('updatePriceRoundings', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(priceRoundingFactory.getPriceRoundings($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updatePriceRoundings', function(event, arg) {
            $scope.entries = angular.copy(priceRoundingFactory.getPriceRoundings($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditPriceRoundingController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,priceRoundingFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.priceRounding = angular.copy(priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.priceRounding.name;
        $scope.title = "Edit Price Rounding";

        
       

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.priceRounding, priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            priceRoundingFactory.savePriceRounding($scope.selectedItem,$scope.priceRounding);
                            $rootScope.$emit('updatePriceRoundings', {
                                editType: "Saved"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.savePriceRounding = function() {
            var errorCheck = document.getElementsByClassName('error-message');
            var validity = true;
            for(var i = 0; i < errorCheck.length; i++) {
                if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                    validity = false;
                }
            }

            if(validity) {
                priceRoundingFactory.savePriceRounding($scope.selectedItem,$scope.priceRounding);
                $rootScope.$emit('updatePriceRoundings', {
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            } else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                })
            }
        }

        $scope.clearPriceRounding = function() {
            if(!angular.equals($scope.priceRounding, priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePriceRounding(); 
                    }
                    else{
                        $scope.priceRounding = angular.copy(priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deletePriceRounding = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    priceRoundingFactory.deletePriceRounding($scope.selectedItem);
                    $rootScope.$emit('updatePriceRoundings', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.priceRounding, priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.priceRounding = angular.copy(priceRoundingFactory.getPriceRoundingByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddPriceRoundingController', function($scope,$ionicPopup,$ionicHistory,$rootScope,priceRoundingFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Price Rounding";

        $scope.priceRounding = {
            name : "",
            toPrice: 0,
            fromPrice: 0,
            roundToNearest: 0,
            reduceBy: 0
        }
        var oriPriceRounding = angular.copy($scope.priceRounding);

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.priceRounding, oriPriceRounding)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            priceRoundingFactory.addPriceRounding($scope.priceRounding);
                            $rootScope.$emit('updatePriceRoundings', {
                                editType: "Added"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            }).then(function() {
                                $scope.priceRounding = angular.copy(oriPriceRounding);
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        } 
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.savePriceRounding = function() {
            if(!angular.equals($scope.priceRounding, oriPriceRounding)) {
                var errorCheck = document.getElementsByClassName('error-message');
                var validity = true;
                for(var i = 0; i < errorCheck.length; i++) {
                    if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                        validity = false;
                    }
                }
    
                if(validity) {
                    priceRoundingFactory.addPriceRounding($scope.priceRounding);
                    $rootScope.$emit('updatePriceRoundings', {
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.priceRounding = angular.copy(oriPriceRounding);
                    })
                } else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
            }
        }

        $scope.addPriceRounding = function() {
            $scope.clearPriceRounding();
        }

        $scope.clearPriceRounding = function() {
            if(!angular.equals($scope.priceRounding, oriPriceRounding)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.savePriceRounding(); 
                    }
                    $scope.priceRounding = angular.copy(oriPriceRounding);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.priceRounding, oriPriceRounding)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.priceRounding = angular.copy(oriPriceRounding); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();