angular.module('aralco.product.services').factory('prodFctr', ['$q', '$http', 'ImgService', '$ionicLoading',
function($q, $http, ImgService, $ionicLoading) {
    function hasGrid(prod) {
        return prod && prod.Matrix &&
            (!_.isEmpty(prod.Matrix.Dimension1) ||
                !_.isEmpty(prod.Matrix.Dimension2) ||
                !_.isEmpty(prod.Matrix.Dimension3) ||
                !_.isEmpty(prod.Matrix.Dimension4));
    }

    var productPictures = function(id, Grid1, Grid2, Grid3, Grid4, type) {
        /// <summary>
        /// Get the main product picture
        /// </summary>
        /// <param name="id"></param>
        /// <returns type=""></returns>
        type = type || 1; //default is product

        var req = ImgService.SearchParam;
        req.input = id;

        req.grids.grid1 = Grid1;
        req.grids.grid2 = Grid2;
        req.grids.grid3 = Grid3;
        req.grids.grid4 = Grid4;
        req.Type = type;

        return ImgService.Search(req);
    };

    this.getProductQuantityDiscounts = function(productId, qty) {
        /// <summary>
        /// retrieve a list of product quantiy discounts
        /// </summary>
        /// <param name="productId"></param>
        /// <returns type=""></returns>
        var url = $f.serviceUrl + "Discount/GetProductQuantityDiscounts/{productId}?qty={qty}&forceLoad={forceLoad}";
        url = url.replace("{productId}", productId)
            .replace("{qty}", qty)
            .replace("{forceLoad}", $f.ForceLoad || "false");

        var req = {
            method: 'get',
            url: url
        };

        return $http(req).then(function(response) {
            return response.data;
        });
    };

    var SerialNumber = function(id, forceLoad) {
        var self = this;
        forceLoad = forceLoad || $f.ForceLoad;

        function _retrieveFromLocal() {
            /// <summary>
            /// Retrieve data from the database (if forceLoad is not required)
            /// </summary>
            /// <returns type=""></returns>
            var deferred = $q.defer();
            var RetVal = [];
            if (!forceLoad) {
                /*Load from database*/
                deferred.resolve(RetVal);
            } else {
                deferred.resolve(RetVal);
            }
            return deferred.promise;
        }

        function _retrieveFromRemote(onlyactive) {
            /// <summary>
            /// retrieve a list of serial numbers from remote
            /// </summary>
            /// <returns type=""></returns>
            var url = $f.serviceUrl + "Product/Serial/{id}?ForceLoad={forceLoad}&ExcludeDeactivated={ExcludeDeactivated}";
            url = url.replace("{id}", id)
                .replace("{forceLoad}", forceLoad)
                .replace("{ExcludeDeactivated}", onlyactive);
            var req = {
                method: 'get',
                url: url
            };

            return $http(req)
                .then(function(response) {
                    return response.data;
                });
        }

        /**
         * The following should be fixed. The process of "saving"
         * is done through a "get" to the API... this should definitely
         * be a post or put instead (depending on whether we are
         * creating or updating.
         *
         * Secondly, a promise is returned here that is only resolved
         * if the API responds with non-empty data. What happens if
         * the response.data is empty (promise will go on unresolved
         * forever).
         */
        self.save = function() {
            /// <summary>
            /// Save
            /// </summary>
            var url = $f.serviceUrl + "Product/Serial/{id}?ForceLoad={forceLoad}";
            url = url.replace("{id}", id).replace("{forceLoad}", forceLoad);

            var req = {
                method: 'get',
                url: url
            };

            return $http(req);
        };

        self.get = function(onlyactive) {
            onlyactive = onlyactive || true;

            return _retrieveFromLocal()
                .then(function(result) {

                    if (!_.isEmpty(result)) {
                        return result;
                    }

                    return _retrieveFromRemote(onlyactive);
                });
        };

        return self;
    };

    this.MainPicture = productPictures;
    this.settings = {
        $get: function() {
            var def = $q.defer();
            var RetVal = {
                maxItems: $f.moduleSetting.Product.maxItems,
                forceLoad: $f.ForceLoad
            };
            def.resolve(RetVal);

        return def.promise;
        }
    };

    this.Retrieve = {
        SearchParam: {
            input: "",
            grids: {
                grid1: null,
                grid2: null,
                grid3: null,
                grid4: null
            },
            price_range: {
                min: null,
                max: null
            },
            mode: 0,
            page: -1,
            maxitems: $f.moduleSetting.Product.maxItems,
            sort: 2,
            includePictures: false,
            forceLoad: $f.ForceLoad,
            excludeDeactivated: true,
            store: $f.moduleSetting.Store.ID
        },

        $search: function(req) {
            /// <summary>
            /// Search the product
            /// </summary>
            /// <param name="req"></param>
            /// <returns type=""></returns>
            req = req || this.SearchParam;

            //if req is not an object, assuming is a string
            if (!_.isObject(req)) {
                var input = req;
                req = this.SearchParam;
                req.input = input;
            }

            req = _.defaults(req, this.SearchParam);

            var url = $f.serviceUrl + "Product/Search/{input}/{mode}";
            url = url.replace('{input}', req.input);

            if (!_.isNumber(req.mode)) {
                req.mode = 0;
            }

            url = url.replace('{mode}', req.mode);

            if (!_.isEmpty(req.grids.grid1)) {
                url = url + '/' + req.grids.grid1;
                if (!_.isEmpty(req.grids.grid2)) {
                    url = url + '/' + req.grids.grid2;
                    if (!_.isEmpty(req.grids.grid3)) {
                        url = url + '/' + req.grids.grid3;
                        if (!_.isEmpty(req.grids.grid4))
                            url = url + '/' + req.grids.grid4;
                    }
                }
            }
            var options = "store={store}&sort={sort}&maxitems={maxitems}&page={page}&ForceLoad={ForceLoad}&ExcludeDeactivated={ExcludeDeactivated}";
            options = options.replace('{sort}', req.sort)
                .replace('{maxitems}', req.maxitems)
                .replace("{page}", req.page)
                .replace("{ForceLoad}", req.forceLoad)
                .replace("{ExcludeDeactivated}", req.ExcludeDeactivated)
                .replace("{store}", req.store);

            if (req.price_range.min !== null && req.price_range.min !== '') {
                options = options + "&minPrice={minPrice}".replace("{minPrice}", req.price_range.min);
            }

            if (req.price_range.max !== null && req.price_range.max !== '') {
                options = options + "&maxPrice={maxPrice}".replace("{maxPrice}", req.price_range.max);
            }

            if (req.CustomerID != undefined && req.CustomerID != null && req.CustomerID != '')
                options = options + "&Customerid={customerID}".replace("{customerID}", req.CustomerID);

            //Sorting
            url = url + '?' + options;
            var httpreq = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(httpreq)
                .then(function(response) {
                    var data = response.data;
                    req.includePictures = req.includePictures || false;

                    //TO-DO Check Purpose of this
                    if (data != '' && data.Result != null) {
                        if (!data.Result) {
                            data.Result = [data];
                        }
                    }
                    var imagePromises = [];
                    _.each(data.Result, function(p) {
                        p.hasGrid = hasGrid(p);

                        //Cache the serial number for the product
                        var sn = new SerialNumber(p.ID, req.forceLoad).save();
                        p.images = [];
                        if (req.includePictures) {
                            var grids = {
                                grid1: _.isEmpty(p.Grid1) ? null : p.Grid1.ID,
                                grid2: _.isEmpty(p.Grid2) ? null : p.Grid2.ID,
                                grid3: _.isEmpty(p.Grid3) ? null : p.Grid3.ID,
                                grid4: _.isEmpty(p.Grid4) ? null : p.Grid4.ID
                            };
                            imagePromises.push(
                                productPictures(p.ID, grids.grid1, grids.grid2, grids.grid3, grids.grid4)
                                .then(function(pics) {
                                    //If No Picture is Found
                                    //Try Retrieving Main Picture,without Grids
                                    /*if(pics[0].value ==='./img/picture-not-available.jpg'){
                                        productPictures(p.ID,0,0,0,0).then(function(images){
                                                if (!_.isArray(images)) {
                                                    images = [images];
                                                }
                                                p.images = images;
                                        })
         
                                    }*/
                                    // else{
                                    if (!_.isArray(pics)) {
                                        pics = [pics];
                                    }
                                    p.images = pics;
                                    // }

                                })
                            );
                        }
                    });

                    return $q.all(imagePromises)
                        .then(function(result) {
                                if (data.Result != null && data.Result.length > 0 &&
                                    data.Result[0].images != null && data.Result[0].images.length > 0 && data.Result[0].images[0].value === $f.PhotoNotAvail) {
                                    return productPictures(data.Result[0].ID, 0, 0, 0, 0).then(function(images) {
                                        if (!_.isArray(images)) {
                                            images = [images];
                                        }
                                        data.Result[0].images = images;
                                        return data;
                                    });
                                }
                                return data;
                            }
                            /*.then(function () {

                            return data;
                            }*/
                            ,
                            function(error) {
                                return $q.reject(error);
                            });
                })
                .then(null, function(error) {
                    return $q.reject(error);
                });
        },

        $getByBarcode: function(barcode, forceload, storeID, customerID) {
            /// <summary>
            /// Load the specific product
            /// </summary>
            /// <param name="id"></param>
            var forceLoad = forceLoad || $f.ForceLoad;
            //This code is invoked from functions other than POS also,so
            // $f.store may not be set yet.

            var selectedStore = storeID || $f.moduleSetting.Store.ID;


            var url = $f.serviceUrl + "Product/Detail/" + barcode + '/Barcode?store=' + selectedStore + '&ForceLoad=' + forceLoad;
            if (customerID != undefined && customerID != null)
                url = url + '&Customerid=' + customerID
            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req)
                .then(function(response) {
                    var data = response.data;
                    if (_.isEmpty(data)) {
                        return $q.reject();
                    }

                    data.hasGrid = hasGrid(data);
                    data.images = {
                        value: null
                    };
                    var imagePromises = [];
                    //Main picture
                    imagePromises.push(
                        productPictures(data.ID)
                        .then(function(img) {
                            if (!_.isEmpty(img)) {
                                data.images = img;
                                if (_.isArray(data.image)) {
                                    data.images = data.image[0];
                                }
                            }
                        })
                    );

                    //Picture based on the grids
                    if (data.hasGrid) {
                        var grid1 = _.isEmpty(data.Grid1) ? null : data.Grid1.ID;
                        var grid2 = _.isEmpty(data.Grid2) ? null : data.Grid2.ID;
                        var grid3 = _.isEmpty(data.Grid3) ? null : data.Grid3.ID;
                        var grid4 = _.isEmpty(data.Grid4) ? null : data.Grid4.ID;

                        imagePromises.push(
                            productPictures(data.ID, grid1, grid2, grid3, grid4).then(function(imgs) {
                                data.barcodeImages = imgs;
                            })
                        );
                    }

                    //return data;
                    return $q.all(imagePromises)
                        .then(function(result) {
                            return data;
                        });
                })
                .then(null, function(error) {
                    return $q.reject(error);
                });
        },

        $barcode: function(id, grid1, grid2, grid3, grid4, forceload) {
            var url = "Product/RetrieveBarcode/{id}?store={storeID}&GridID1={grid1}&GridID2={grid2}&GridID3={grid3}&GridID4={grid4}&ForceLoad={ForceLoad}";
            url = url.replace('{id}', id);
            url = url.replace('{grid1}', grid1 || '');
            url = url.replace('{grid2}', grid2 || '');
            url = url.replace('{grid3}', grid3 || '');
            url = url.replace('{grid4}', grid4 || '');
            url = url.replace('{storeID}', $f.moduleSetting.Store.ID);
            url = url.replace('{ForceLoad}', forceload || $f.ForceLoad);

            var url = $f.serviceUrl + url;
            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req)
                .then(function(response) {
                    return response.data;
                });
        },

        $load: function(id, forceLoad) {
            /// <summary>
            /// Load the specific product
            /// </summary>
            /// <param name="id"></param>
            forceLoad = forceLoad || $f.ForceLoad;
            var url = $f.serviceUrl + "Product/Detail/" + id + '?Store={storeID}&ForceLoad=' + forceLoad;
            url = url.replace('{storeID}', $f.moduleSetting.Store.ID);
            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req)
                .then(function(response) {
                    var data = response.data;
                    if (_.isEmpty(data)) {
                        return data;
                    }

                    data.hasGrid = hasGrid(data);

                    // Parse out ints for proper ordering :: NOTE: That this affects GetValues
                    if (!_.isEmpty(response.data.Matrix.Dimension1)) {
                        response.data.Matrix.Dimension1.Grids.forEach(function(grid) {
                            grid.Value = parseFloat(grid.Value) || grid.Value;
                        })
                    }
                    if (!_.isEmpty(response.data.Matrix.Dimension2)) {
                        response.data.Matrix.Dimension2.Grids.forEach(function(grid) {
                            grid.Value = parseFloat(grid.Value) || grid.Value;
                        })
                    }
                    if (!_.isEmpty(response.data.Matrix.Dimension3)) {
                        response.data.Matrix.Dimension3.Grids.forEach(function(grid) {
                            grid.Value = parseFloat(grid.Value) || grid.Value;
                        })
                    }
                    if (!_.isEmpty(response.data.Matrix.Dimension4)) {
                        response.data.Matrix.Dimension4.Grids.forEach(function(grid) {
                            grid.Value = parseFloat(grid.Value) || grid.Value;
                        })
                    }


                    //Cache the serial number for the product
                    var sn = new SerialNumber(id, forceLoad).save();

                    return productPictures(data.ID)
                        .then(function(img) {
                            if (!_.isEmpty(img) && _.isArray(img)) {
                                data.images = img[0];
                            }
                            return data;
                        });
                });
        },

        $serialNumbers: function(id, forceLoad) {
            return new SerialNumber(id, forceLoad).get();
        }
    };

    this.inventory = {
        param: {
            prodID: "",
            grids: {
                grid1: null,
                grid2: null,
                grid3: null,
                grid4: null
            },
            forceLoad: $f.ForceLoad
        },

        $get: function(parameter) {
            parameter = parameter || this.param;
            var url = $f.serviceUrl + 'Product/Inventory/{id}?Store={storeID}&forceLoad={forceLoad}';
            if (parameter.skipStore === true)
                url = $f.serviceUrl + 'Product/Inventory/{id}?forceLoad={forceLoad}';
            else if (_.isEmpty(parameter.getInventoryForThisStore)) {
                url = url.replace('{storeID}', parameter.getInventoryForThisStore);
            }

            url = url.replace('{id}', parameter.prodID)
                .replace("{forceLoad}", parameter.forceLoad || $f.ForceLoad);

            if (parameter.grids) {
                if (_.isNumber(parameter.grids.grid1)) {
                    url = url + "&GridId1=" + parameter.grids.grid1;
                }

                if (_.isNumber(parameter.grids.grid2)) {
                    url = url + "&GridId2=" + parameter.grids.grid2;
                }

                if (_.isNumber(parameter.grids.grid3)) {
                    url = url + "&GridId3=" + parameter.grids.grid3;
                }

                if (_.isNumber(parameter.grids.grid4)) {
                    url = url + "&GridId4=" + parameter.grids.grid4;
                }
            }

            var req = {
                method: 'get',
                //headers: h,
                url: url
            };

            return $http(req)
                .then(function(response) {
                    return response.data;
                });
        }
    };
    return this;
}
]);