angular.module('aralco.product.services').factory('prodSearchFctr', ['$http', '$rootScope', '$q', '$ionicModal', '$ionicLoading', 'prodFctr', '$filter',
    function ($http, $rootScope, $q, $ionicModal, $ionicLoading, prodFctr, $filter) {
        var self = this;

        function _scanProduct(input,storeID = null, customerID = null, mode = 0) {
            $ionicLoading.show({
                template: 'wait...'
            });
            return _barcodeSearch(input,storeID,customerID)
            .then(null, function (error) {
                // if failed on barcode lookup, perform generic search
                return _genericSearch(input, storeID, customerID,  mode);
            });
        }

        var _selectProductFromFileProductDetails = function (products) {
            /// <summary>
            /// If the search result return multiple items,
            /// this method shows a modal dialog to select the right product
            /// </summary>
            /// <param name="product"></param>
            /// <returns type=""></returns>
            var def = $q.defer();

            if (products != null) {
                $scope = $rootScope.$new();
                $scope.products = products.Result;
                $scope.selectedProduct = null;

                $ionicModal.fromTemplateUrl('modules/pos/templates/pos-scan-selectprod.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    $scope.modal = modal;
                    $scope.modal.show();
                });
                $scope.selected = function (prod) {
                    $scope.selectedProduct = ($scope.selectedProduct == prod) ? null : prod;
                };
                $scope.okToGo = function () {
                    return !_.isEmpty($scope.selectedProduct);
                };
                $scope.next = function () {
                    $scope.closeModal();
                    def.resolve($scope.selectedProduct);
                };
                $scope.prev = function () {
                    $scope.selectedProduct = null;
                    $scope.closeModal();
                };
                $scope.closeModal = function () {
                   $scope.modal.hide();
                };
                $scope.$on('$destroy', function () {
                    $scope.modal.remove();
                });
            } else {
                def.resolve(products);
            }
            return def.promise;
        };

        var _selectProduct = function (products) {
            /// <summary>
            /// If the search result return multiple items,
            /// this method shows a modal dialog to select the right product
            /// </summary>
            /// <param name="product"></param>
            /// <returns type=""></returns>
            var def = $q.defer();

            if (products != null) {
                $scope = $rootScope.$new();
                $scope.products = products.Result;
                $scope.selectedProduct = null;

                /*if (($scope.products || []).length == 1) {
                    $scope.selectedProduct = products.Result[0];
                    def.resolve($scope.selectedProduct);
                } else {*/
                    $ionicModal.fromTemplateUrl('modules/pos/templates/pos-scan-selectprod.html', {
                        scope: $scope,
                        animation: 'slide-in-up'
                    }).then(function (modal) {
                        $scope.modal = modal;
                        $scope.modal.show();
                    });

                    $scope.selected = function (prod) {
                        $scope.selectedProduct = ($scope.selectedProduct == prod) ? null : prod;
                    };

                    $scope.okToGo = function () {
                        return !_.isEmpty($scope.selectedProduct);
                    };

                    $scope.next = function () {
                        $scope.closeModal();
                        $ionicLoading.show({
                            template:'wait...'
                        });
                        // To allow previous modal to close
                         setTimeout(function(){def.resolve($scope.selectedProduct)}, 500);
                    };


                    $scope.prev = function () {
                        $scope.selectedProduct = null;
                        $scope.closeModal();
                    };

                    $scope.closeModal = function () {
                       $scope.modal.hide();
                    };

                    $scope.$on('$destroy', function () {
                        $scope.modal.remove();
                    });
               // }
            } else {
                def.resolve(products);
            }
            return def.promise;
        };

        var _selectProductSerialNumber = function (product) {
            /// <summary>
            /// If the product has a Serial #,
            /// this method shows a modal dialog to select the right one
            /// </summary>
            /// <param name="product"></param>
            /// <returns type=""></returns>
            var def = $q.defer();
            $scope = $rootScope.$new();

            if (product == null || !(product.TypeInfo || {SerialNumber: false}).SerialNumber) {
                if (product != null) {
                    product.SerialNumber = null;
                }

                def.resolve(product);
            } else {
                /*Require serial number*/
                $ionicModal.fromTemplateUrl('modules/pos/templates/pos-scan-selectserialnumber.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    $scope.modal = modal;
                    prodFctr.Retrieve.$serialNumbers(product.ID).then(function (sns) {
                        $scope.serialnumbers = sns;
                        $scope.modal.show();
                    });
                });

                $scope.SelectedSerialNumber = null;

                $scope.selected = function (sn) {
                    $scope.SelectedSerialNumber = ($scope.SelectedSerialNumber == sn.Value) ? null : sn.Value;
                };

                $scope.okToGo = function () {
                    return !_.isEmpty($scope.SelectedSerialNumber);
                };

                $scope.next = function () {
                    product.SerialNumber = $scope.SelectedSerialNumber;
                    $scope.closeModal();
                    def.resolve(product);
                };

                $scope.prev = function () {
                    $scope.SelectedSerialNumber = null;
                    $scope.closeModal();
                };

                $scope.closeModal = function () {
                    $scope.modal.hide();
                };

                $scope.$on('$destroy', function () {
                    $scope.modal.remove();
                });
            }
            return def.promise;
        };

        /*search as a barcode (99% it should be a barcode)*/
        var _barcodeSearch = function (bc,storeID,customerID) {
            return prodFctr.Retrieve.$getByBarcode(bc,undefined,storeID,customerID)
                .then(function (p) {
                    //For POS also we have skipped ProductSerial# prompt here
                   // if(typeOfScan != undefined ){
                   //     return p;
                   // }else{
                        $ionicLoading.hide();
                        return _selectProductSerialNumber(p);
                   // }

                });
        };
        /*search method by generic input*/

        var _genericSearchFromFileProductDetails = function (value, storeID, customerID) {
            var store_ = storeID;
            return prodFctr.Retrieve.$search({
                input: value,
                store: store_,
                MoreAvailable: false,
                mode: 0,
                TotalFound: null,
                page: 0,
                ExcludeDeactivated: true,
                includePictures:true,
                CustomerID:customerID
            })
            .then(function (prods) {
                $ionicLoading.hide();
                if (prods==null || prods.Result===undefined || prods.Result==null || prods.length<1) {
                    return $q.reject('No products found');
                }
                return _selectProductFromFileProductDetails(prods);
            });
        };

        var _genericSearch = function (value, storeID = null, customerID = null, mode = 0) {
            var store_ = storeID;
            return prodFctr.Retrieve.$search({
                input: value,
                store: store_,
                MoreAvailable: false,
                mode: mode,
                TotalFound: null,
                page: 0,
                ExcludeDeactivated: true,
                includePictures:true,
                CustomerID:customerID
            })
            .then(function (prods) {
                $ionicLoading.hide();
                if (prods==null || prods.Result===undefined || prods.Result==null || prods.length<1) {
                    return $q.reject('No products found');
                }
                return _selectProduct(prods);
            })
            .then(function (p) {
                if (!p) {
                    return $q.reject('No product selected');
                }
                return _selectProductGrids(p);
            })
            .then(function (sbc) {
                if (!(sbc)) {
                    return $q.reject('No product grid selected');
                }
                return _barcodeSearch(sbc, storeID, customerID);

            }, function (error) {
                return $q.reject(error);
            });
        };

        var _selectProductGrids = function (product) {
            /// <summary>
            /// If the product has multiple grids,
            /// this method shows a modal dialog to select the right combination
            /// </summary>
            /// <param name="product"></param>
            // / <returns type=""></returns>
            var def = $q.defer();
            $scope = $rootScope.$new();
            prodFctr.Retrieve.$load(product.ID).then(function (prodDetail) {

                $scope.product = prodDetail;

                var _retrieveGrids = function () {
                    var dimCalls = [];
                    if (!_.isEmpty(product.Matrix.Dimension1)) {
                         dimCalls.push(product.Matrix.Dimension1);
                    }

                    if (!_.isEmpty(product.Matrix.Dimension2)) {
                        dimCalls.push(product.Matrix.Dimension2);
                    }

                    if (!_.isEmpty(product.Matrix.Dimension3)) {
                       dimCalls.push(product.Matrix.Dimension3);
                    }

                    if (!_.isEmpty(product.Matrix.Dimension4)) {
                        dimCalls.push(product.Matrix.Dimension4);
                    }

                    return $q.all(dimCalls);

                };
                var modalPromise = $ionicModal.fromTemplateUrl('modules/pos/templates/pos-scan-selectdimension.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                });
                if (product != null && product.hasGrid) {
                    $ionicLoading.show({
                        template: 'wait...'
                    });

                    var calls = [modalPromise, _retrieveGrids()];

                    $q.all(calls).then(function (res) {
                        $scope.modal = res[0];

                        $scope.selectedgrids = [];
                        $scope.dimensions = res[1];
                        $scope.selectedgrids.length = $scope.dimensions.length;

                        $ionicLoading.hide();
                        $scope.modal.show();
                    });

                    $scope.okToGo = function () {
                        return !(_.indexOf($scope.selectedgrids, undefined) != -1) || (_.indexOf($scope.selectedgrids, null) != -1);
                    };

                    $scope.next = function () {
                    $ionicLoading.show({
                        template: 'wait...'
                    });
                    $scope.closeModal();
                    /*todo: Select the right barcode*/
                    var grid1 = ($scope.selectedgrids[0] || {}).ID || '';
                    var grid2 = ($scope.selectedgrids[1] || {}).ID || '';
                    var grid3 = ($scope.selectedgrids[2] || {}).ID || '';
                    var grid4 = ($scope.selectedgrids[3] || {}).ID || '';

                    prodFctr.Retrieve.$barcode(product.ID, grid1, grid2, grid3, grid4)
                        .then(function (result) {
                            //$ionicLoading.hide();
                            if (!result) {
                                def.reject('Product barcode could not be retrieved');
                            }
                            setTimeout(function(){def.resolve(result.Barcode)}, 500);

                        }, function (error) {
                            $ionicLoading.hide();
                            def.reject(error);
                        });
                    };

                    $scope.prev = function () {
                    $scope.closeModal();
                    def.resolve(null);
                    };

                    $scope.toggleGroup = function (group) {
                    if ($scope.isGroupShown(group)) {
                        $scope.shownGroup = null;
                    } else {
                        $scope.shownGroup = group;
                    }
                    };

                    $scope.SelectedGrid = {
                    Grid1: null,
                    Grid2: null,
                    Grid3: null,
                    Grid4: null,
                    GetText: function (number) {
                        if ($scope.product == null || $scope.product.Matrix == null || !$scope.product.hasGrid) {
                            return '';
                        }

                        var mtx = $scope.product.Matrix;
                        var _text = function (dim, id) {
                            var RetVal = '';

                            if (dim != null) {
                                RetVal = $filter('translate')('ALL');
                            }

                            if (dim != null && id != null) {
                                var reqID = _.findWhere(dim.Grids, { ID: id });
                                if (reqID != null) {
                                    RetVal = reqID.Value;
                                }
                            }

                            return RetVal;
                        };

                        return _text(mtx["Dimension" + number], this["Grid" + number]);
                    },
                    SetValue: function (value, number, noToggle) {

                        this["Grid" + number] = this["Grid" + number] == value ? null : value;
                        if (!noToggle) {
                           // number = number-1;
                            $scope.toggleGroup(number);
                        }
                        //LoadInventory();
                    }

                    };

                    $scope.SetGrid = function (gridVal, number, noToggle) {
                         noToggle = !!noToggle;
                        $scope.SelectedGrid.SetValue(gridVal.ID, number, noToggle);
                        //number= number -1;
                        var currentVal = $scope.selectedgrids[number];
                        $scope.selectedgrids[number-1]=  (currentVal == gridVal) ? null : gridVal;
                        //$scope.toggleGroup(number);
                    };

                    $scope.isGroupShown = function (group) {
                        return $scope.shownGroup === group;
                    };

                    $scope.selected = function (prod) {
                        $scope.selectedProduct = prod;
                        $scope.closeModal();
                    };

                    $scope.closeModal = function () {
                        $scope.modal.hide();
                    };

                    $scope.$on('$destroy', function () {
                        $scope.modal.remove();
                    });

                } else {
                    if (product != null) {
                        $ionicLoading.show({
                                template: 'wait...'
                        });
                        //Check if the Product at this Stage already has a Barcode,
                        //If So,return the barcode from here itself.
                        if(product.Barcode!=null && product.Barcode!= undefined){
                            def.resolve(product.Barcode);
                        }
                        else{
                            //Barcode is still not available,we need to do
                            //call API to  retreive it based on Product ID
                            prodFctr.Retrieve.$barcode(product.ID).then(function (bc) {
                                def.resolve(bc.Barcode);
                            });
                        }
                    } else
                    {
                    def.resolve(product);
                    }
                }
            });
            return def.promise;
        };

        self.$scan = _scanProduct;
        self.$selectProductGrids = _selectProductGrids;
        self.$genericSearch = _genericSearch;
        self.$genericSearchFromFileProductDetails = _genericSearchFromFileProductDetails;

        return self;
}]);