(function () {
    
	var module = angular.module('aralco.province',['ionic']);
	
	module.factory('provinceFactory', function($filter) {

        var elementId = 10;

		var provinces = [
			{
                ID: 1,
				name: "BC",
				desc: "BC"  
			},
			{
                ID: 2,
				name: "AB",
				desc: "AB"
			},
			{
                ID: 3,
				name: "SK",
				desc: "SK"
			},
			{
                ID: 4,
				name: "ON",
				desc: "ON"
			},
			{
                ID: 5,
				name: "MN",
				desc: "MN"
			},
			{
                ID: 6,
				name: "QC",
				desc: "QC"
			},
			{
                ID: 7,
				name: "NS",
				desc: "NS"
			},
			{
                ID: 8,
				name: "PE",
				desc: "PE"
            },
			{
                ID: 9,
				name: "YU",
				desc: "YU"
			}
		];

		return {
			getProvinces : function(searchText) {
                return $filter('filter')(provinces, {name: searchText})
			},
			addProvince : function(province) {
				var temp = {
                    ID: elementId++,
					name: province.name,
					desc: province.desc
				}

				provinces.push(temp);
			},
			deleteProvince: function(item) {
                var index = provinces.findIndex(province => province.ID == item.ID);
                provinces.splice(index, 1);
            },
			saveProvince: function(item,province) {
                var index = provinces.findIndex(province => province.ID == item.ID);
                provinces[index].name = province.name;
                provinces[index].desc = province.desc;
            },
            
            getProvinceByIndex : function(item) {
                return provinces.filter(province => province.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.province', {
			url: '/province',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'ProvinceController'
				}
			}
		})
		.state('tab.editprovince', {
			url: '/editprovince/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'EditProvinceController'
				}
			}
		})
		.state('tab.addprovince', {
			url: '/editprovince/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'AddProvinceController'
				}
			}	
		})
	}]);

    module.controller('ProvinceController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,provinceFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Province/State";
        $scope.searchTitle = "Province/State"

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editprovince',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addprovince',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        provinceFactory.deleteProvince($scope.selectedItem);
                        $rootScope.$emit('updateProvinces', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(provinceFactory.getProvinces($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateProvinces', function(event, arg) {
            $scope.entries = angular.copy(provinceFactory.getProvinces($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditProvinceController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,provinceFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.item = angular.copy(provinceFactory.getProvinceByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.item.name;
        $scope.title = "Edit Province/State";
        $scope.param = "Province";

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = $scope.item.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, provinceFactory.getProvinceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveItem = function() {
            provinceFactory.saveProvince($scope.selectedItem,$scope.item);
            $rootScope.$emit('updateProvinces', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, provinceFactory.getProvinceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    else{
                        $scope.item = angular.copy(provinceFactory.getProvinceByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteItem = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    provinceFactory.deleteProvince($scope.selectedItem);
                    $rootScope.$emit('updateProvinces', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, provinceFactory.getProvinceByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(provinceFactory.getProvinceByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddProvinceController', function($scope,$ionicPopup,$ionicHistory,$rootScope,provinceFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Province/State";
        $scope.param = "Province";
        $scope.item = {
            name : "",
            desc : ""
        }
        var oriProvince = angular.copy($scope.item);

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = angular.copy($scope.item.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, oriProvince)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveItem = function() {
            if(!angular.equals($scope.item, oriProvince)) {
                provinceFactory.addProvince($scope.item);
                $rootScope.$emit('updateProvinces', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.item = angular.copy(oriProvince);
                })
            }
        }

        $scope.addProvince = function() {
            $scope.clearItem();
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, oriProvince)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $scope.item = angular.copy(oriProvince);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, oriProvince)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(oriProvince); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();