/// <reference path="../../Scripts/underscore.js" />
(function () {

    'use strict';

    var module = angular.module('aralco.register', ['aralco.map']);


    module.config(['$stateProvider', '$urlRouterProvider', function ($stateProvider, $urlRouterProvider) {
        // Each tab has its own nav history stack:
        $stateProvider

        .state('tab.registers', {
            url: '/Registers',
            views: {
                'tab-view': {
                    templateUrl: 'modules/register/templates/tab-registers.html',
                    controller: 'registerCtr'
                }
            }
        })

    }]);


    module.directive('registerList', [
       function () {
            return {
                restrict: "A",
                transclude: true,
                scope: {},
                templateUrl: 'modules/register/templates/register-list.html',
                controller: ['$scope', '$rootScope', '$ionicLoading', '$filter', 'registerFctr','sessionFctr', 
            function ($scope, $rootScope,$ionicLoading, $filter, registerFctr, sessionFctr) {
                $scope.Registers = [];

                $ionicLoading.show({
                    template: 'Wait please...'
                });

                registerFctr.Get().then(function (data) {
                    _.each(data, function (item) {
                    sessionFctr.Get(item.StoreID, item.RegisterCode, 0).then(function(session){
                        item.SessionID = session.SessionID;
                        item.SessionGUID = session.SessionGUID;
                        item.POSSessionID = session.POSSessionID
                        item.Available = (typeof item.SessionID !== 'undefined') ? false : true;
                        item.RegisterCode = item.RegisterCode;
                        item.RegisterID = item.RegisterID;
                        item.StoreID = item.StoreID;
                        item.Options = item.Options || '';
                        });
                    });
                    $ionicLoading.hide();
                    $scope.Registers =  data.filter(function (r) {
                        return (r.RegisterCode != 'DM');
                    });
               }, function () {
                   $ionicLoading.hide();

               });
           }]

           }
       }]);



    module.factory('registerFctr', ['$q', '$http', function ($q, $http) {

        this.Get = function (id, forceLoad) {
            /// <summary>
            /// Load list of registers
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();
            forceLoad = forceLoad || $f.ForceLoad;
            id = id || '';
            var url = $f.serviceUrl + "Register/Get/" + id + '?ForceLoad=' + forceLoad;
            var req = {
                method: 'get',
                //headers: h,
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        this.Generate = function (register) {
            /// <summary>
            /// Generate Register or select dynamic one-
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();
            var paramsValues =  {
                "Options": register.Options + 'DR/',
                "StoreID": register.StoreID
            }

            var url = $f.serviceUrl + "register/generate";
            var req = {
                method: 'post',
                //headers: h,
                url: url,
                data:paramsValues
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        return this;
    }]);

    module.controller('registerCtr', ['$scope', '$q', '$ionicSideMenuDelegate', '$ionicLoading', 'registerFctr',
		function ($scope, $q, $ionicSideMenuDelegate, $ionicLoading, registerFctr) {
		    init();

		    function init() {

		    }

		}]
	)
})();