(function () {
    
	var module = angular.module('aralco.remarkoptions',['ionic']);
	
	module.factory('remarkOptionFactory', function($filter) {

        var elementId = 4;

		var remarkOptions = [
			{
                ID: 1,
				name: "Order Emailed",
				desc: "Order Emailed"  
			},
			{
                ID: 2,
				name: "In Transit",
				desc: "In Transit"
			},
			{
                ID: 3,
				name: "Held at Custom",
				desc: "Held at Custom"
			}
		];
        
		return {
			getRemarkOptions : function(searchText) {
                return $filter('filter')(remarkOptions, {name: searchText})
			},
			addRemarkOption : function(remarkOption) {
				var temp = {
                    ID: elementId++,
					name: remarkOption.name,
					desc: remarkOption.desc
				}

				remarkOptions.push(temp);
			},
			deleteRemarkOption: function(item) {
                var index = remarkOptions.findIndex(remarkOption => remarkOption.ID == item.ID);
                remarkOptions.splice(index, 1);
            },
            
            saveRemarkOption: function(item,remarkOption) {
                var index = remarkOptions.findIndex(remarkOption => remarkOption.ID == item.ID);
                remarkOptions[index].name = remarkOption.name;
                remarkOptions[index].desc = remarkOption.desc;
            },
            
            getRemarkOptionByIndex : function(item) {
                return remarkOptions.filter(remarkOption => remarkOption.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.remarkoptions', {
			url: '/remarkoptions',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/remark_options/templates/remark-options.html',
					controller: 'RemarkOptionController'
				}
			}
		})
		.state('tab.editremarkoptions', {
			url: '/editremarkoption/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/remark_options/templates/remark-options-edit.html',
                    controller: 'EditRemarkOptionController'
				}
			}
		})
		.state('tab.addremarkoptions', {
			url: '/editremarkoption/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/remark_options/templates/remark-options-edit.html',
                    controller: 'AddRemarkOptionController'
				}
			}
		})
	}]);

    module.controller('RemarkOptionController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,remarkOptionFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editRemarkOption' && $scope.selectedItem != null){
                $state.go('tab.editremarkoptions',{name: JSON.stringify($scope.selectedItem)});
            }            
            if(pagename == 'addRemarkOption'){
                $state.go('tab.addremarkoptions',{name: 'addRemarkOption'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteRemarkOption = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        remarkOptionFactory.deleteRemarkOption($scope.selectedItem);
                        $rootScope.$emit('updateRemarkOptions', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(remarkOptionFactory.getRemarkOptions($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateRemarkOptions', function(event, arg) {
            $scope.entries = angular.copy(remarkOptionFactory.getRemarkOptions($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditRemarkOptionController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,remarkOptionFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.remarkOption = angular.copy(remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.remarkOption.name;
        
        
       

        
            
            {
        }
        
        $scope.autoFillDescription = function() {
            if($scope.remarkOption.desc.length == 0) {
                $scope.remarkOption.desc = $scope.remarkOption.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.remarkOption, remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveRemarkOption(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveRemarkOption = function() {
            remarkOptionFactory.saveRemarkOption($scope.selectedItem,$scope.remarkOption);
            $rootScope.$emit('updateRemarkOptions', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            }).then(function() {
                oriRemarkOption = angular.copy($scope.remarkOption);
            })
        }

        $scope.clearRemarkOption = function() {
            if(!angular.equals($scope.remarkOption, remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveRemarkOption(); 
                    }
                    else{
                        $scope.remarkOption = angular.copy(remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteRemarkOption = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    remarkOptionFactory.deleteRemarkOption($scope.selectedItem);
                    $rootScope.$emit('updateRemarkOptions', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.remarkOption, remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.remarkOption = angular.copy(remarkOptionFactory.getRemarkOptionByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddRemarkOptionController', function($scope,$ionicPopup,$ionicHistory,$rootScope,remarkOptionFactory){
        $scope.showSearchbar = true;
        $scope.remarkOption = {
            name : "",
            desc : ""
        }
        var oriRemarkOption = angular.copy($scope.remarkOption);

        $scope.autoFillDescription = function() {
            if($scope.remarkOption.desc.length == 0) {
                $scope.remarkOption.desc = $scope.remarkOption.name;
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.remarkOption, oriRemarkOption)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveRemarkOption(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveRemarkOption = function() {
            if(!angular.equals($scope.remarkOption, oriRemarkOption)) {
                remarkOptionFactory.addRemarkOption($scope.remarkOption);
                $rootScope.$emit('updateRemarkOptions', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.remarkOption = angular.copy(oriRemarkOption);
                })
            }
        }

        $scope.addRemarkOption = function() {
            $scope.clearRemarkOption();
        }

        $scope.clearRemarkOption = function() {
            if(!angular.equals($scope.remarkOption, oriRemarkOption)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveRemarkOption(); 
                    }
                    $scope.remarkOption = angular.copy(oriRemarkOption);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.remarkOption, oriRemarkOption)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.remarkOption = angular.copy(oriRemarkOption); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();