(function () {
    
	var module = angular.module('aralco.returnreasons',['ionic']);
	
	module.factory('returnReasonFactory', function($filter) {

        var elementId = 4;

		var returnReasons = [
			{
                ID: 1,
				name: "N/A",
				desc: "N/A"  
			},
			{
                ID: 2,
				name: "Not a good fit",
				desc: "Not a good fit"
			},
			{
                ID: 3,
				name: "Does not work",
				desc: "Does not work"
			}
        ];
        
		return {
			getReturnReasons : function(searchText) {
                return $filter('filter')(returnReasons, {name: searchText})
			},
			addReturnReason : function(returnReason) {
				var temp = {
                    ID: elementId++,
					name: returnReason.name,
					desc: returnReason.desc
				}

				returnReasons.push(temp);
			},
			deleteReturnReason: function(item) {
                var index = returnReasons.findIndex(returnReason => returnReason.ID == item.ID);
                returnReasons.splice(index, 1);
            },
            
            saveReturnReason: function(item,returnReason) {
                var index = returnReasons.findIndex(returnReason => returnReason.ID == item.ID);
                returnReasons[index].name = returnReason.name;
                returnReasons[index].desc = returnReason.desc;
            },
            
            getReturnReasonByIndex : function(item) {
                return returnReasons.filter(returnReason => returnReason.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.returnreasons', {
			url: '/returnreasons',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/return_reasons/templates/return-reasons.html',
					controller: 'ReturnReasonController'
				}
			}
		})
		.state('tab.editreturnreasons', {
			url: '/editreturnreason/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/return_reasons/templates/return-reasons-edit.html',
                    controller: 'EditReturnReasonController'
				}
			}
		})
		.state('tab.addreturnreasons', {
			url: '/editreturnreason/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/return_reasons/templates/return-reasons-edit.html',
                    controller: 'AddReturnReasonController'
				}
			}
		})
	}]);

    module.controller('ReturnReasonController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,returnReasonFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;

        
       

        
            
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'editReturnReason' && $scope.selectedItem != null){
                $state.go('tab.editreturnreasons',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'addReturnReason'){
                $state.go('tab.addreturnreasons',{name: 'addReturnReason'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteReturnReason = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        returnReasonFactory.deleteReturnReason($scope.selectedItem);
                        $rootScope.$emit('updateReturnReasons', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(returnReasonFactory.getReturnReasons($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateReturnReasons', function(event, arg) {
            $scope.entries = angular.copy(returnReasonFactory.getReturnReasons($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditReturnReasonController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,returnReasonFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.returnReason = angular.copy(returnReasonFactory.getReturnReasonByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.returnReason.name;
        
        
       

        
            
            {
        }
        
        $scope.autoFillDescription = function() {
            if($scope.returnReason.desc.length == 0) {
                $scope.returnReason.desc = $scope.returnReason.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.returnReason, returnReasonFactory.getReturnReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveReturnReason(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveReturnReason = function() {
            returnReasonFactory.saveReturnReason($scope.selectedItem,$scope.returnReason);
            $rootScope.$emit('updateReturnReasons', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            }).then(function() {
                oriReturnReason = angular.copy($scope.returnReason);
            })
        }

        $scope.clearReturnReason = function() {
            if(!angular.equals($scope.returnReason, returnReasonFactory.getReturnReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveReturnReason(); 
                    }
                    else{
                        $scope.returnReason = angular.copy(returnReasonFactory.getReturnReasonByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteReturnReason = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    returnReasonFactory.deleteReturnReason($scope.selectedItem);
                    $rootScope.$emit('updateReturnReasons', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.returnReason, returnReasonFactory.getReturnReasonByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.returnReason = angular.copy(returnReasonFactory.getReturnReasonByIndex($scope.selectedItem)); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddReturnReasonController', function($scope,$ionicPopup,$ionicHistory,$rootScope,returnReasonFactory){
        $scope.showSearchbar = true;
        $scope.returnReason = {
            name : "",
            desc : ""
        }
        var oriReturnReason = angular.copy($scope.returnReason);
      
        $scope.autoFillDescription = function() {
            if($scope.returnReason.desc.length == 0) {
                $scope.returnReason.desc = $scope.returnReason.name;
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.returnReason, oriReturnReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveReturnReason(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveReturnReason = function() {
            if(!angular.equals($scope.returnReason, oriReturnReason)) {
                returnReasonFactory.addReturnReason($scope.returnReason);
                $rootScope.$emit('updateReturnReasons', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.returnReason = angular.copy(oriReturnReason);
                })
            }
        }

        $scope.addReturnReason = function() {
            $scope.clearReturnReason();
        }

        $scope.clearReturnReason = function() {
            if(!angular.equals($scope.returnReason, oriReturnReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveReturnReason(); 
                    }
                    $scope.returnReason = angular.copy(oriReturnReason);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.returnReason, oriReturnReason)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.returnReason = angular.copy(oriReturnReason); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();