﻿/// <reference path="../../Scripts/underscore.js" />
/// <reference path="../../js/aralco.mobile.fw/aralco.mobile.fw.js" />
(function () {
    'use strict';


    var module = angular.module('aralco.setting', ['aralco.localStorage', 'aralco.pos', 'aralco.store']);

    module.config(['$httpProvider', '$stateProvider', '$urlRouterProvider', '$provide', '$injector', function ($httpProvider, $stateProvider, $urlRouterProvider, $provide, $injector) {
        //var settingFctr = $injector.get("settingFctr");

        $stateProvider.state('setting', {
            url: '/setting/app',
            LoginRequired: false,
            templateUrl: 'modules/settings/templates/application-settings.html',
            controller: 'settingCtr'
        })
        //.state('setting-pos', {
        //        url: '/setting/pos',
        //        LoginRequired: true,
        //        templateUrl: 'modules/settings/templates/pos-settings.html',
        //        controller: 'posSettingCtr'
        //})
        .state('setting-pos-payment', {
            url: '/setting/pospayment',
            LoginRequired: true,
            templateUrl: 'modules/settings/templates/pos-payment-settings.html',
            controller: 'paymentMethodCtr'
        })
    }]);

    module.factory('settingFctr', ['$http', '$q', '$rootScope', 'localStorageService', 'ImgService', function ($http, $q, $rootScope, localStorageService, ImgService) {
        var self = this;

        var LS_CONFIG_KEY = 'aSett',
            DEF_SETTING = 'prod';


        var _dummySetting =
         {
             connection: {
                 Server: "localhost",
                 Port: null,
                 SSL: false
             },
             Product: {
                 maxItem: 20
             },
             QueryOption: {
                 ForceLoad: false
             },
             pos: {
                 customerMode: 0
             }
         };


        function getDefault(config) {

            var def = $q.defer();
            config = config || DEF_SETTING;
            var url = 'modules/settings/config/config.' + config + '.txt';

            $http.get(url).success(function (response) {
                var RetVal = _.extend(_dummySetting, response);
                def.resolve(RetVal);
            }).error(function () {
                def.resolve(_dummySetting);
            });

            return def.promise;
        }

        self.$get = function (reqConfig) {
            var reqPush = [];
            var def = $q.defer();
            
            reqPush.push(getDefault(reqConfig));
            reqPush.push(localStorageService.get(LS_CONFIG_KEY));

            $q.all(reqPush).then(function (values) {
                var result = _.extend(values[0], values[1]);
                def.resolve(result);
            }, function (data) {
                def.resolve(_dummySetting);
            });

            return def.promise;
        };

        self.$save = function (config, refresh) {
            var def = $q.defer();
            refresh = refresh || false;
            try { localStorageService.set(LS_CONFIG_KEY, config);
                if(refresh && !$f.isSoSActive){
                    $rootScope.$broadcast('setting.updated', { value: config });       
                }
                def.resolve();
            } catch (e) {
                def.reject(e);
            }
            return def.promise;
        };

        self.$getPOS = function (id, forceLoad) {
            /// <summary>
            /// Load list of registers
            /// </summary>
            /// <param name="id">Store ID</param>
            var deferred = $q.defer();
            forceLoad = forceLoad || $f.ForceLoad;
            id = id || '';
            var url = $f.serviceUrl + "Setting/GetPOS/" + id + '?ForceLoad=' + forceLoad;
            var req = {
                method: 'get',
                url: url
            }


            $http(req).
              success(function (data, status, headers, config) {
                  deferred.resolve(data)
              }, function (data, status) {
                  deferred.reject(data, status);
              });

            return deferred.promise;
        }

        self.$getLogo = function () {
            var def = $q.defer();
    
            var imgsp = ImgService.SearchParam;
            imgsp.input = 0;
            imgsp.Type = 3;
    
            ImgService.Search(imgsp).then(function (pic) {
                def.resolve(pic[0]);
            }, function () {
                def.resolve(null);
            });
    
            return def.promise;
        }

        return self;
    }]);

    module.controller('settingCtr', ['$scope','$rootScope', 'settingFctr', '$state', 'popupFctr', 'storeFctr', 'registerFctr', '$ionicLoading', '$ionicHistory', '$filter', '$ionicPopover', '$q','$location',
     function ($scope,$rootScope, settingFctr, $state, popupFctr, storeFctr, registerFctr, $ionicLoading, $ionicHistory, $filter, $ionicPopover, $q,$location) {

        init();


        // .fromTemplateUrl() method
        $ionicPopover.fromTemplateUrl('setting-mode.html', {
            scope: $scope
        }).then(function (popover) {
            $scope.popover = popover;
        });


        $scope.openPopover = function ($event) {
            $scope.popover.show($event);
        };
        $scope.closePopover = function () {
            $scope.popover.hide();
        };
        //Cleanup the popover when we're done with it!
        $scope.$on('$destroy', function () {
            $scope.popover.remove();
        });
        // Execute action on hide popover
        $scope.$on('popover.hidden', function () {
            // Execute action
        });
        // Execute action on remove popover
        $scope.$on('popover.removed', function () {
            // Execute action
        });

        $scope.$on('popover.hideme', function () {
            $scope.popover.hide();
        });

        $ionicHistory.nextViewOptions({
            disableBack: true
        });

        function init() {
            $scope.mode = 0;
            settingFctr.$get().then(function (res) {
                $scope.setting = res;
            });

            getStores($f.isLogged);
            getRegisters($f.isLogged);
            
        };

        function getStores(logged) {
            if (logged === true)
                storeFctr.Get().then(
                     function (data) {
                         $scope.stores = data;
                     });
            else
                $scope.stores = null;
        }

         function getRegisters(logged) {
            if (logged === true)
                registerFctr.Get().then(
                     function (data) {
                         $scope.registers = data;
                     });
            else
                $scope.registers = null;
        }

        $scope.$watch(function () {return $f.isLogged;},function (val) {getStores(val);});

        $scope.$watch(function () {return $f.isLogged;},function (val) {getRegisters(val);});

        $scope.setMode = function (val) {
            val = parseInt(val);

            $scope.mode = val;
        }

        $scope.IsLogged = function () {
            return $f.isLogged;
        }


         $scope.isSoSActive = function ($e) {
            if($f.isSoSActive){ 
                 init();
                $scope.setting.Store.ID = $f.moduleSetting.pos.Store.ID;
                popupFctr.alert('Active POS Shift','Please end POS shift before changing stores...');
             }
         }

        $scope.reorderItems = function (item, fromIndex, toIndex) {
            $scope.items.splice(fromIndex, 1);
            $scope.items.splice(toIndex, 0, item);
        };

        $scope.Cancel = function () {
            init();
            $ionicHistory.goBack();
        };

        $scope.Save = function () {
            // if($f.isLogged && ($scope.setting.Store.ID===undefined || $scope.setting.Store.ID===0) && $scope.mode===0 ){
            //     popupFctr.alert('Store Not Selected','Please select a store');
            //     return;
            // }
            // var selected_store = _.find($scope.stores, { ID: $scope.setting.Store.ID });
            // if(selected_store!=null && selected_store!= undefined && !$f.isSoSActive)
            //     $scope.setting.Store.Code = selected_store.Code;

            $ionicLoading.show({
                template: 'Saving...'
            });
            var refresh = !$f.isSoSActive;
            // Ture = refresh settings, should only be applied to inital setup
            settingFctr.$save($scope.setting, refresh).then(
                function () {
                    popupFctr.alert($filter("translate")("Setting Saved"));
                    init();
                    $ionicLoading.hide();
                    //When Settings is Saved..take User to Dashboard,to save from
                    //inconcistent states
                    // DOnt let user go back to Settings using BACK button
                    $ionicHistory.clearHistory();

                    $ionicHistory.nextViewOptions({
                        historyRoot: true
                    });
                    $location.path('/the_otherwise_state'); // state with this URL doesn't exist
                    $location.replace();

                   // $ionicHistory.goToHistoryRoot();
                }, function (err) {
                    popupFctr.alert($filter("translate")(err));
                }, function () {
                    $ionicLoading.hide();
                });
        };

    }]);

    module.controller('paymentMethodCtr', ['$scope', '$rootScope', 'settingFctr', '$state', 'popupFctr', 'tendKeyFctr', '$ionicLoading', '$ionicHistory', '$filter','$location', function ($scope, $rootScope, settingFctr, $state, popupFctr, tendKeyFctr, $ionicLoading, $ionicHistory, $filter,$location) {

        init();

        function init() {
            tendKeyFctr.$get().then(function (res) {
                $scope.tendKeys = _.sortBy(res, 'Position');
            });

            $scope.data = {
                showDelete: false
            };
        };


        $scope.onItemDelete = function (item) {
            $scope.tendKeys.splice($scope.tendKeys.indexOf(item), 1);
            tendKeyFctr.$delete(item.Number);
        };

        $scope.moveItem = function (item, fromIndex, toIndex) {
            $scope.tendKeys.splice(fromIndex, 1);
            $scope.tendKeys.splice(toIndex, 0, item);

        };

        $scope.Cancel = function () {
            init();
            $ionicHistory.goBack();
        };

        $scope.Save = function () {
            $ionicLoading.show({
                template: 'Saving...'
            });
            for (var i = 0; i <= $scope.tendKeys.length - 1; i++) {
                $scope.tendKeys[i].Position = i;
            };

            tendKeyFctr.$save($scope.tendKeys).then(
                function () {
                    $ionicLoading.hide();
                    popupFctr.alert($filter("translate")("Setting Saved"));
                    init();
                    //$location.path('/the_otherwise_state'); // state with this URL doesn't exist
                    //$location.replace();
                    $ionicHistory.goBack();
                });
        };

    }]);


})();
