﻿/// <reference path="../../js/indexeddb.js" />
/// <reference path="../../Scripts/underscore.js" />
(function () {
    'use strict';


    var module = angular.module('aralco.database', ['indexedDB']);

    var iDB_CONFIG = {
        name: 'amobile',
        version: 1,
        tables: [
            {
                name: 'log',
                indexes: ['severity', 'timestamp']
            },
            {
                name: 'setting',
                keypath:'module',
                indexes: ['module']
            },
            {
                name: 'product',
                keypath: 'id',
                autoincrement:false,
                indexes: ['id','Code', 'SerialNumber']
            },
            {
                name: 'serialnumber',
                indexes: ['productid', 'snumber', 'storeid']
            },
            {
                name: 'scans',
                keypath: 'ScanID',
                autoincrement:true,
                indexes: ['parentReference', 'type']
            },
            {
                name: 'tendkey',
                keypath: 'Number',
                autoincrement: false,
                indexes: ['Position', 'IsCard']
            },
            {
                name: 'transaction',
                keypath:'number',
                indexes: ['status']
            }
        ]
    };


    module.config(['$indexedDBProvider', function ($indexedDBProvider) {
        var dbProd = $indexedDBProvider.connection(iDB_CONFIG.name);

        dbProd.upgradeDatabase(iDB_CONFIG.version, function (event, db, tx) {
            var oIxOptions = { unique: false };
            var oItbOption = { autoIncrement: true };

            _.each(iDB_CONFIG.tables, function (tb) {
                
                if (_.isString(tb.keypath) && !_.isEmpty(tb.keypath)) {
                    oItbOption.keyPath = tb.keypath;
                    oItbOption.autoIncrement = tb.autoincrement || true;
                }

                var objStore = db.createObjectStore(tb.name, oItbOption);
                _.forEach(tb.indexes, function (c) {
                    objStore.createIndex(c + '_idx', c, oIxOptions);
                });
            })
        });
    }]);

})();