(function () {

    'use strict';

    var module = angular.module('aralco.staff', []);


    module.config(['$stateProvider', '$urlRouterProvider', function ($stateProvider, $urlRouterProvider) {
        // Each tab has its own nav history stack:
        $stateProvider
            .state('tab.staffs', {
                url: '/staffs',
                views: {
                    'tab-view': {
                        templateUrl: 'modules/staffs/templates/staff.html',
                        controller: 'staffCtr as vm'
                    }
                }
            });
    }]);

    module.factory('staffFct', ['$q', '$http', '$filter', function ($q, $http, $filter) {
        var self = this;
        self.formatDate = _formatDate;
        self.$post = _post;
        self.$getCustomerGroups = _getCustomerGroups;
        self.$getEmployeeGroups = _getEmployeeGroups;

        function _formatDate(date) {
            return $filter('date')(date, 'yyyy-MM-dd');
        }

        function _getCustomerGroups() {
            var def = $q.defer();
            var url = 'customer/getgroups';
            url = $f.serviceUrl + url;
            console.log(url);

            var httpreq = {
                method: 'get',
                url: url
            }

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        };

        function _getEmployeeGroups() {
            var def = $q.defer();
            var url = 'employee/getgroups';
            url = $f.serviceUrl + url;
            console.log(url);

            var httpreq = {
                method: 'get',
                url: url
            }

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        };

        function _post(staff) {
            var def = $q.defer();
            var url = "employee/post/";

            url = $f.serviceUrl + url;
            console.log('URL: ' + url);

            var httpreq = {
                method: 'post',
                url: url,
                data: staff
            };

            $http(httpreq).success(
                function (data, status, headers, config) {
                    def.resolve(data);
                }).error(
                function (data, status, headers, config) {
                    def.reject(data, status);
                });

            return def.promise;
        }
        
        self.$formatDate = _formatDate;
        self.$getCustomerGroups = _getCustomerGroups;
        self.$getEmployeeGroups = _getEmployeeGroups;
        self.$post = _post;

        return self;
    }]);

    module.controller('staffCtr', ['$scope', 'staffFct', function ($scope, staffFct) {
        $scope.staff = {};
        $scope.submitted = false;
        $scope.paybaseItems = [ 
            { item: 'Hourly' }, 
            { item: 'Weekly' }, 
            { item: 'Bi-Weekly' }, 
            { item: 'Monthly' }, 
            { item: 'Bi-Monthly' } ];
        $scope.customerGroups = null;
        $scope.employeeGroups = null;

        $scope.loadDropdown = function () {
            if ($scope.customerGroups === null || $scope.employeeGroups === null) {
                staffFct.$getCustomerGroups().then(function (data) {
                    $scope.customerGroups = data;
                });
                staffFct.$getEmployeeGroups().then(function (data) {
                    $scope.employeeGroups = data;
                });
            }
        }

        function staffTpl() {
            return {
                "info": {
                    "contact": {
                        "name": null,
                        "surname": null,
                        "Email": null,
                        "phone1": null,
                        "mobile1": null,
                        "email": null
                    },
                    "address": {
                        "address1": null,
                        "address2": null,
                        "address3": null,
                        "city": null,
                        "ProvinceState": null,
                        "zippostalcode": null,
                        "Country": null
                    }
                },
                "Store": {
                    "ID": null
                },
                "login": null,
                "name": null,
                "isBuyer": false,
                "isBOS": false,
                "isPOS": false,
                "position": null,
                "datestarted": null,
                "payrate": null,
                "paybase": null,
                "commission": null,
                "monthlyquota": null,
                "customergroupid": null,
                "reportgroupid": null,
                "remarks": null,
                "createdbyid": null,
                "deactivated": false,
                "BosOptions": null,
                "PosOptions": null
            };

        }

        $scope.submit = function (form) {
            $scope.submitted = true;
            if (form.$valid) {
                $scope.save($scope.staff);
            }
        }

        $scope.save = function (staff) {
            var tpl = new staffTpl();

            tpl.info.contact.name = staff.firstName === undefined ? null : staff.firstName;
            tpl.info.contact.surname = staff.lastName === undefined ? null : staff.lastName;
            tpl.info.contact.Email = staff.email === undefined ? null : staff.email;
            tpl.info.contact.phone1 = staff.tel === undefined ? null : staff.tel;
            tpl.info.contact.mobile1 = staff.cell === undefined ? null : staff.cell;
            tpl.info.contact.email = 'phil@aralco.com';
            tpl.info.address.address1 = staff.line1 === undefined ? null : staff.line1;
            tpl.info.address.address2 = staff.line2 === undefined ? null : staff.line2;
            tpl.info.address.city = staff.city === undefined ? null : staff.city;
            tpl.info.address.ProvinceState = staff.provState === undefined ? null : staff.provState;
            tpl.info.address.zippostalcode = staff.zip === undefined ? null : staff.zip;
            tpl.info.address.Country = staff.country === undefined ? null : staff.country;
            tpl.Store.ID = 27;
            tpl.login = staff.login === undefined ? null : staff.login;
            tpl.name = tpl.info.contact.name + ' ' + tpl.info.contact.surname;
            tpl.isBuyer = staff.buyer === undefined ? null : staff.buyer;
            tpl.isBOS = staff.POS === undefined ? false : staff.POS;
            tpl.isPOS = staff.BOS === undefined ? false : staff.BOS;
            tpl.position = staff.position === undefined ? null : staff.position;
            tpl.datestarted = staff.dateStarted === undefined ? null : staffFct.$formatDate(staff.dateStarted);
            tpl.payrate = staff.payRate === undefined ? null : staff.payRate;
            tpl.paybase = staff.payBase === undefined ? null : staff.payBase;
            tpl.commission = staff.commission === undefined ? null : staff.commission;
            tpl.customergroupid = staff.customerGroup === undefined ? null : staff.customerGroup;
            tpl.reportgroupid = staff.reportGroup === undefined ? null : staff.reportGroup;
            tpl.createdbyid = 246;
            tpl.deactivated = staff.deactivated === undefined ? false : staff.deactivated;
            tpl.BosOptions = '(12,4,8)';
            tpl.PosOptions = '(10,13)';
            tpl.monthlyquota = staff.quota === undefined ? null : staff.quota;
            tpl.remarks = staff.remarks === undefined ? null : staff.remarks;

            console.log(tpl);

            staffFct.$post(tpl).then(function (data) {
                console.log('Successfully added a new staff!');
            }, function (data) {
                console.error(JSON.stringify(data));
            })
        }

    }]);

    module.directive('staffValidate', function () {
        return {
            strict: 'A',
            require: 'ngModel',
            link: function (scope, elem, attr, ngModel) {

                function validatePhone(field) {
                    var regexObj = /^\(?([0-9]{3})\)?[-. ]?([0-9]{3})[-. ]?([0-9]{4})$/;
                    return field ? regexObj.test(field) : true;
                }

                ngModel.$parsers.unshift(function (value) {
                    var valid = true;
                    if (attr.type === 'tel') {
                        // Validation for phone number
                        valid = validatePhone(value);
                        ngModel.$setValidity('phone', valid);
                    }
                    return valid ? value : null;
                });
            }
        }
    });

})();