(function () {

    var module = angular.module('aralco.storegroups',['ionic']);

    module.factory('storeGroupFactory', function($filter, $q, $http) {
        var cachedStores = [];
        return {
            getStoreGroups : function(searchText) {
                var deferred = $q.defer();

                var url = $f.serviceUrl + 'Store/GetGroupings';
                var req = {
                    method: 'get',
                    url: url
                };

                // noinspection JSUnusedLocalSymbols
                $http(req)
                    .success(function (data, status, headers, config) {
                        cachedStores = data;
                        if (!searchText){
                            deferred.resolve(data);
                        } else {
                            deferred.resolve(
                                data.filter(
                                    storeGroup => storeGroup.Name.toLowerCase().indexOf(searchText.toLowerCase()) !== -1
                                )
                            );
                        }
                    }, function (data, status) {
                        deferred.reject(data, status);
                    });

                return deferred.promise;
            },
            insertStoreGroup : function(storeGroup) {



                var deferred = $q.defer();

                var newItem = {
                    StoreGroupingID: storeGroup.StoreGroupingID,
                    Name: storeGroup.Name,
                    Description: storeGroup.Description,
                    Position: storeGroup.Position,
                    CreatedBy: storeGroup.CreatedBy
                };

                var url = $f.serviceUrl + 'Store/CreateGrouping';
                var req = {
                    method: 'post',
                    url: url,
                    data: newItem
                };

                // noinspection JSUnusedLocalSymbols
                $http(req)
                    .success(function (data, status, headers, config) {
                        deferred.resolve(data);
                    }, function (data, status) {
                        deferred.reject(data, status);
                    });

                return deferred.promise;
            },
            updateStoreGroup: function(item,storeGroup) {
                // var index = cachedStores.findIndex(storeGroup => storeGroup.StoreGroupingID === item.StoreGroupingID);
                //
                // cachedStores[index].Name = storeGroup.Name;
                // cachedStores[index].Description = storeGroup.Description;
                // cachedStores[index].Position = 0;

                var deferred = $q.defer();

                var updatedItem = {
                    StoreGroupingID: storeGroup.StoreGroupingID,
                    Name: storeGroup.Name,
                    Description: storeGroup.Description,
                    Position: storeGroup.Position,
                    CreatedBy: storeGroup.CreatedBy
                };

                var url = $f.serviceUrl + 'Store/UpdateGrouping';
                var req = {
                    method: 'post',
                    url: url,
                    data: updatedItem
                };

                // noinspection JSUnusedLocalSymbols
                $http(req)
                    .success(function (data, status, headers, config) {
                        deferred.resolve(data);
                    }, function (data, status) {
                        deferred.reject(data, status);
                    });

                return deferred.promise;
            },
            deleteStoreGroup: function(item) {
                // var index = cachedStores.findIndex(storeGroup => storeGroup.StoreGroupingID === item.StoreGroupingID);
                //
                // cachedStores.splice(index, 1);

                var deferred = $q.defer();

                var deleteItem = {
                    StoreGroupingID: item.StoreGroupingID
                };

                var url = $f.serviceUrl + 'Store/DeleteGrouping';
                var req = {
                    method: 'post',
                    url: url,
                    data: deleteItem
                };

                // noinspection JSUnusedLocalSymbols
                $http(req)
                    .success(function (data, status, headers, config) {
                        deferred.resolve(data);
                    }, function (data, status) {
                        deferred.reject(data, status);
                    });

                return deferred.promise;
            },
            getStoreGroupByIndex : function(item) {
                return cachedStores.filter(storeGroup => storeGroup.StoreGroupingID === item.StoreGroupingID)[0];
            }
        };
    });

    // noinspection JSUnusedLocalSymbols
    module.config(['$stateProvider', '$provide', '$urlRouterProvider',
        '$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
            $stateProvider
                .state('tab.storegroups', {
                    url: '/storegroups',
                    LoginRequired: true,
                    views: {
                        'tab-view': {
                            templateUrl: 'modules/common_html/templates/view.html',
                            controller: 'StoreGroupController'
                        }
                    }
                })
                .state('tab.editstoregroups', {
                    url: '/editstoregroup/:name',
                    LoginRequired: true,
                    views: {
                        'tab-view': {
                            templateUrl: 'modules/common_html/templates/edit.html',
                            controller: 'EditStoreGroupController'
                        }
                    }
                })
                .state('tab.addstoregroups', {
                    url: '/editstoregroup/:name',
                    LoginRequired: true,
                    views: {
                        'tab-view': {
                            templateUrl: 'modules/common_html/templates/edit.html',
                            controller: 'AddStoreGroupController'
                        }
                    }
                })
        }]);

    module.controller('StoreGroupController', function($scope,$state,$filter,$rootScope,$ionicScrollDelegate,$ionicPopup,storeGroupFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.searchTitle = "Store Group";
        $scope.title = "Manage Store Groupings";

        $scope.gotoAddEditPage = function(pagename){
            if(pagename === 'edit' && $scope.selectedItem != null){
                $state.go('tab.editstoregroups',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename === 'add'){
                $state.go('tab.addstoregroups',{name: 'add'});
            }
        };

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        };

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        };

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val === true){
                        storeGroupFactory.deleteStoreGroup($scope.selectedItem).then(function(){
                            $rootScope.$emit('updateStoreGroups', {
                                editType: "Deleted"
                            });
                        });
                    }
                })
            }
        };
        $scope.searchItem = function() {
            // noinspection JSUnresolvedVariable
            storeGroupFactory.getStoreGroups($scope.searchContent).then(function(result){
                $scope.entries = result;
                $scope.showContent = true;
                $scope.clearSelectedItem();
                $scope.scrollMainToTop();
            })
        };

        // noinspection JSUnusedLocalSymbols
        $rootScope.$on('updateStoreGroups', function(event, arg) {
            $scope.searchItem();
            //$scope.entries = angular.copy(storeGroupFactory.getStoreGroups($scope.searchContent));
        });

        $scope.scrollMainToTop = function() {
            $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    });

    module.controller('EditStoreGroupController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,storeGroupFactory){
        $scope.editFields = "/modules/store_groups/partials/edit-fields.html";
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.item = angular.copy(storeGroupFactory.getStoreGroupByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.item.Name;
        $scope.title = "Edit Store Grouping";

        $scope.autoFillDescription = function() {
            if($scope.item.Description.length === 0) {
                $scope.item.Description = $scope.item.Name;
            }
        };

        $scope.goBack = function() {
            if(!angular.equals($scope.item, storeGroupFactory.getStoreGroupByIndex($scope.selectedItem))) {
                $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val === true){
                        $scope.saveItem();
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        };

        $scope.saveItem = function() {
            storeGroupFactory.updateStoreGroup($scope.selectedItem,$scope.item).then(function(){
                $rootScope.$emit('updateStoreGroups', {
                    editType: "Saved"
                });
                $ionicPopup.alert({
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function(){
                    $ionicHistory.goBack();
                });
            }, function(result, error){
                $ionicPopup.alert({
                    title: 'Error while saving record.',
                    subTitle: error
                });
            });
        };

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, storeGroupFactory.getStoreGroupByIndex($scope.selectedItem))) {
                $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val === true){
                        $scope.saveItem();
                    }
                    else{
                        $scope.item = angular.copy(storeGroupFactory.getStoreGroupByIndex($scope.selectedItem));
                    }
                })
            }
        };

        $scope.deleteItem = function() {
            $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val === true){
                    storeGroupFactory.deleteStoreGroup($scope.selectedItem).then(function(){
                        $rootScope.$emit('updateStoreGroups', {
                            editType: "Deleted"
                        });
                        $ionicHistory.goBack();
                    });
                }
            })
        };

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, storeGroupFactory.getStoreGroupByIndex($scope.selectedItem))) {
                $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val === true){
                        $scope.item = angular.copy(storeGroupFactory.getStoreGroupByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    });

    module.controller('AddStoreGroupController', function($scope,$ionicPopup,$ionicHistory,$rootScope,storeGroupFactory){
        $scope.editFields = "/modules/store_groups/partials/edit-fields.html";
        $scope.showSearchbar = true;
        $scope.title = "Add Store Grouping";
        $scope.item = {
            Checksum : null,
            CreatedBy: 183,
            CreatedDate: new Date().toISOString().slice(0, 19).replace(/:([^:]*)$/,"."+'$1') + "0", // SQL Time String
            Description : "",
            Name : "",
            Position : $scope.$$prevSibling.entries.length,
            Status: "AAE=",
            StoreGroupingID : -1,
            VersionCheck : null,
        };
        var oriStoreGroup = angular.copy($scope.item);

        $scope.autoFillDescription = function() {
            if($scope.item.Description.length === 0) {
                $scope.item.Description = angular.copy($scope.item.Name);
            }
        };

        $scope.goBack = function() {
            if(!angular.equals($scope.item, oriStoreGroup)) {
                $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val === true){
                        $scope.saveItem();
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        };

        $scope.saveItem = function() {
            if(!angular.equals($scope.item, oriStoreGroup)) {
                storeGroupFactory.insertStoreGroup($scope.item).then(function(data){
                    if(data){
                        $rootScope.$emit('updateStoreGroups', {
                            editType: "Added"
                        });
                        $ionicPopup.alert({
                            title: 'Record saved successfully.',
                            subTitle: ''
                        }).then(function(){
                            $scope.item = angular.copy(oriStoreGroup);
                        })
                    } else {
                        $ionicPopup.alert({
                            title: 'Error!',
                            subTitle: 'Their was a problem saving the record. Please insure the record does not already exist.'
                        })
                    }
                });
            }
        };

        $scope.addItem = function() {
            $scope.clearItem();
        };

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, oriStoreGroup)) {
                $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val === true){
                        $scope.saveItem();
                    }
                    $scope.item = angular.copy(oriStoreGroup);
                })
            }
        };

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, oriStoreGroup)) {
                $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val === true){
                        $scope.item = angular.copy(oriStoreGroup);
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();