(function () {
    
	var module = angular.module('aralco.storetypes',['ionic']);
	
	module.factory('storeTypeFactory', function($filter) {

        var elementId = 5;

		var storeTypes = [
			{
                ID: 1,
				name: "High Volume",
				desc: "High Volume"  
			},
			{
                ID: 2,
				name: "Low Volume",
				desc: "Low Volume"
			},
			{
                ID: 3,
				name: "Medium Volume",
				desc: "Medium Volume"
			},
			{
                ID: 4,
				name: "Warehouse",
				desc: "Warehouse"
			}
		];

		return {
		    getStoreTypes : function(searchText) {
                return $filter('filter')(storeTypes, {name: searchText})
			},
			addStoreType : function(storeType) {
				var temp = {
                    ID: elementId++,
					name: storeType.name,
					desc: storeType.desc
				}

				storeTypes.push(temp);
			},
			deleteStoreType: function(item) {
                var index = storeTypes.findIndex(storeType => storeType.ID == item.ID);
                storeTypes.splice(index, 1);
            },
            
            saveStoreType: function(item,storeType) {
                var index = storeTypes.findIndex(storeType => storeType.ID == item.ID);
                storeTypes[index].name = storeType.name;
                storeTypes[index].desc = storeType.desc;
            },
            
            getStoreTypeByIndex : function(item) {
                return storeTypes.filter(storeType => storeType.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.storetypes', {
			url: '/storetypes',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'StoreTypeController'
				}
			}
		})
		.state('tab.editstoretypes', {
			url: '/editstoretype/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'EditStoreTypeController'
				}
			}
		})
		.state('tab.addstoretypes', {
			url: '/editstoretype/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'AddStoreTypeController'
				}
			}	
		})
	}]);

    module.controller('StoreTypeController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,storeTypeFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.searchTitle = "Store Type";
        $scope.title = "Manage Store Types";


        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editstoretypes',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addstoretypes',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        storeTypeFactory.deleteStoreType($scope.selectedItem);
                        $rootScope.$emit('updateStoreTypes', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(storeTypeFactory.getStoreTypes($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateStoreTypes', function(event, arg) {
            $scope.entries = angular.copy(storeTypeFactory.getStoreTypes($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditStoreTypeController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,storeTypeFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.item = angular.copy(storeTypeFactory.getStoreTypeByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.item.name;
        $scope.title = "Edit Store Type";
        $scope.param = "Store";

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = $scope.item.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, storeTypeFactory.getStoreTypeByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveItem = function() {
            storeTypeFactory.saveStoreType($scope.selectedItem,$scope.item);
            $rootScope.$emit('updateStoreTypes', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, storeTypeFactory.getStoreTypeByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    else{
                        $scope.item = angular.copy(storeTypeFactory.getStoreTypeByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteItem = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    storeTypeFactory.deleteStoreType($scope.selectedItem);
                    $rootScope.$emit('updateStoreTypes', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, storeTypeFactory.getStoreTypeByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(storeTypeFactory.getStoreTypeByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddStoreTypeController', function($scope,$ionicPopup,$ionicHistory,$rootScope,storeTypeFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Store Type";
        $scope.param = "Store";
        $scope.item = {
            name : "",
            desc : ""
        }
        var oriStoreType = angular.copy($scope.item);

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = angular.copy($scope.item.name);
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, oriStoreType)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveItem = function() {
            if(!angular.equals($scope.item, oriStoreType)) {
                storeTypeFactory.addStoreType($scope.item);
                $rootScope.$emit('updateStoreTypes', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.item = angular.copy(oriStoreType);
                })
            }
        }

        $scope.addItem = function() {
            $scope.clearItem();
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, oriStoreType)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $scope.item = angular.copy(oriStoreType);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, oriStoreType)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(oriStoreType); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();