(function () {
    
	var module = angular.module('aralco.suppliergroups',['ionic']);
	
	module.factory('supplierGroupFactory', function($filter) {

        var elementId = 10;

		var supplierGroups = [
			{
                ID: 1,
				name: "Canadian Sup",
				desc: "Canadian Sup"  
			},
			{
                ID: 2,
				name: "European",
				desc: "European"
			},
			{
                ID: 3,
				name: "Fabric Supplier",
				desc: "Fabric Supplier"
			},
			{
                ID: 4,
				name: "Fashion Supp.",
				desc: "Fashion Supp."
			},
			{
                ID: 5,
				name: "Fishing",
				desc: "Fishing"
			},
			{
                ID: 6,
				name: "Jewelery Supp.",
				desc: "Jewelery Supp."
			},
			{
                ID: 7,
				name: "Toy Suppliers",
				desc: "Toy Suppliers"
			},
			{
                ID: 8,
				name: "U.S.Supp.",
				desc: "U.S.Supp."
			},
			{
                ID: 9,
				name: "Jewelery",
				desc: "Jewelery"
			}
		];

		return {
			getSupplierGroups : function(searchText) {
                return $filter('filter')(supplierGroups, {name: searchText})
			},
			addSupplierGroup : function(supplierGroup) {
				var temp = {
                    ID: elementId++,
					name: supplierGroup.name,
					desc: supplierGroup.desc
				}

				supplierGroups.push(temp);
			},
            deleteSupplierGroup: function(item) {
                var index = supplierGroups.findIndex(supplierGroup => supplierGroup.ID == item.ID);
                supplierGroups.splice(index, 1);
            },
            saveSupplierGroup: function(item,supplierGroup) {
                var index = supplierGroups.findIndex(supplierGroup => supplierGroup.ID == item.ID);
                supplierGroups[index].name = supplierGroup.name;
                supplierGroups[index].desc = supplierGroup.desc;
            },
            getSupplierGroupByIndex : function(item) {
                return supplierGroups.filter(supplierGroup => supplierGroup.ID == item.ID)[0];
            }
		};
	});
	
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.suppliergroups', {
			url: '/suppliergroups',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'SupplierGroupController'
				}
			}
		})
		.state('tab.editsuppliergroups', {
			url: '/editsuppliergroup/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'EditSupplierGroupController'
				}
			}
		})
		.state('tab.addsuppliergroups', {
			url: '/editsuppliergroup/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/edit.html',
                    controller: 'AddSupplierGroupController'
				}
			}	
		})
	}]);

    module.controller('SupplierGroupController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,supplierGroupFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.searchTitle = "Supplier Group";
        $scope.title = "Manage Supplier Groupings"

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editsuppliergroups',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addsuppliergroups',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        supplierGroupFactory.deleteSupplierGroup($scope.selectedItem);
                        $rootScope.$emit('updateSupplierGroups', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(supplierGroupFactory.getSupplierGroups($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateSupplierGroups', function(event, arg) {
            $scope.entries = angular.copy(supplierGroupFactory.getSupplierGroups($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditSupplierGroupController', function($scope,$state,$stateParams,$ionicPopup,$ionicHistory,$rootScope,supplierGroupFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.item = angular.copy(supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.item.name;
        $scope.title = "Edit Supplier Grouping";
        $scope.param = "Supplier";

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = $scope.item.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveItem = function() {
            supplierGroupFactory.saveSupplierGroup($scope.selectedItem,$scope.item);
            $rootScope.$emit('updateSupplierGroups', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    else{
                        $scope.item = angular.copy(supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteItem = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    supplierGroupFactory.deleteSupplierGroup($scope.selectedItem);
                    $rootScope.$emit('updateSupplierGroups', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(supplierGroupFactory.getSupplierGroupByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddSupplierGroupController', function($scope,$ionicPopup,$ionicHistory,$rootScope,supplierGroupFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Supplier Grouping";
        $scope.param = "Supplier";
        $scope.item = {
            name : "",
            desc : ""
        }
        var oriSupplierGroup = angular.copy($scope.item);

        $scope.autoFillDescription = function() {
            if($scope.item.desc.length == 0) {
                $scope.item.desc = angular.copy($scope.item.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.item, oriSupplierGroup)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveItem = function() {
            if(!angular.equals($scope.item, oriSupplierGroup)) {
                supplierGroupFactory.addSupplierGroup($scope.item);
                $rootScope.$emit('updateSupplierGroups', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.item = angular.copy(oriSupplierGroup);
                })
            }
        }

        $scope.addItem = function() {
            $scope.clearItem();
        }

        $scope.clearItem = function() {
            if(!angular.equals($scope.item, oriSupplierGroup)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveItem(); 
                    }
                    $scope.item = angular.copy(oriSupplierGroup);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.item, oriSupplierGroup)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.item = angular.copy(oriSupplierGroup); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();