﻿/// <reference path="../../../Scripts/underscore.js" />
(function () {
	'use strict';

	var PREFERRED_LANGUAGE = 'en_CA';
	var LANGUAGE_CONST = 'stdlng';

	var module = angular.module('aralco.translator', ['pascalprecht.translate', 'aralco.localStorage']);

	angular.module('pascalprecht.translate').factory('$translateStaticFilesLoader', [
	  '$q',
	  '$http',
	  function ($q, $http) {
	  	return function (options) {
	  		if (!options || (!angular.isString(options.prefix) || !angular.isString(options.suffix))) {
	  			throw new Error('Couldn\'t load static files, no prefix or suffix specified!');
	  		}
	  		var deferred = $q.defer();
	  		$http({
	  			url: [
				  options.prefix,
				  options.key,
				  options.suffix
	  			].join(''),
	  			method: 'GET',
	  			params: ''
	  		}).success(function (data) {
	  			deferred.resolve(data);
	  		}).error(function (data) {
	  			deferred.reject(options.key);
	  		});
	  		return deferred.promise;
	  	};
	  }
	]);

	module.config(['$translateProvider', '$injector', function ($translateProvider, $injector) {
		$translateProvider.useStaticFilesLoader({ prefix: 'modules/translator/translation/', suffix: '.txt' });

		$translateProvider.preferredLanguage(PREFERRED_LANGUAGE);
	}]);
	
	module.factory('translatorFctr', ['$translate', 'localStorageService',function ($translate, localStorageService)
	{
		var self = this;
		

		self.SwitchLanguage = function (i18n) {
			if (!_.isEmpty(i18n))
			{
				if (!($translate.use() === i18n))
				{
					/*ToDo: Check if the culture exist*/
					$translate.use(i18n);
					localStorageService.set(LANGUAGE_CONST, i18n);
				}
			}
		};

		self.CurrentLanguage = function () {
			var RetVal;
			RetVal = localStorageService.get(LANGUAGE_CONST);
			RetVal = RetVal || PREFERRED_LANGUAGE;
			return RetVal;
		};
		 

		return self;

	}
	]);

	module.run(['$translate', 'translatorFctr', '$ionicPlatform', 'localStorageService', function ($translate, translatorFctr, $ionicPlatform, localStorageService) {
		$ionicPlatform.ready(function () {
			var lng = localStorageService.get(LANGUAGE_CONST) || PREFERRED_LANGUAGE;
			$translate.use(lng);
		});


	}]);

	
})();