(function () {
    
	var module = angular.module('aralco.unitsofmeasures',['ionic']);
	
	module.factory('unitsofMeasureFactory', function($filter) {

        var elementId = 5;

        var unitList = [
            {
                ID: 1,
                unitSymbol: "g",
                unitDesc: "Grams",
                isEqualTo: 1.00,
                toUnit: "g"
            },
            {
                ID: 2,
                unitSymbol: "Kg",
                unitDesc: "Kilograms",
                isEqualTo: 1000.00,
                toUnit: "g"
            },
            {
                ID: 3,
                unitSymbol: "oz",
                unitDesc: "Ounce",
                isEqualTo: 28.00,
                toUnit: "g"
            },
            {
                ID: 4,
                unitSymbol: "lb",
                unitDesc: "Pounds",
                isEqualTo: 16.00,
                toUnit: "oz"
            },
            {
                ID: 5,
                unitSymbol: "CaseCheese",
                unitDesc: "CS",
                isEqualTo: 25.00,
                toUnit: "Kg"
            },
            {
                ID: 6,
                unitSymbol: "Case-5lb",
                unitDesc: "Case 5lb",
                isEqualTo: 5.00,
                toUnit: "lb"
            },
            {
                ID: 7,
                unitSymbol: "Case-10lb",
                unitDesc: "Case 10lb",
                isEqualTo: 10.00,
                toUnit: "lb"
            },
            {
                ID: 8,
                unitSymbol: "Tea",
                unitDesc: "teaspoons",
                isEqualTo: 168.00,
                toUnit: "g"
            }
        ];
            
		var unitsofMeasures = [
			{
                ID: 1,
                name: "Weight",
                desc: "Weight",
                useMeasuring: false,
                posScreenPrompt: "",
                measuringUnit: "",
                units: angular.copy(unitList)
            },
            {
                ID: 2,
                name: "Length",
                desc: "Length",
                useMeasuring: false,
                posScreenPrompt: "",
                measuringUnit: "",
                units: angular.copy(unitList)
            },
            {
                ID: 3,
                name: "Volume",
                desc: "Volume",
                useMeasuring: false,
                posScreenPrompt: "",
                measuringUnit: "",
                units: angular.copy(unitList)
            },
            {
                ID: 4,
                name: "Area",
                desc: "Area",
                useMeasuring: false,
                posScreenPrompt: "",
                measuringUnit: "",
                units: angular.copy(unitList)
            }
		];

		return {
			getUnitsofMeasures : function(searchText) {
				return $filter('filter')(unitsofMeasures, {name: searchText})
            },
            getUnitList : function() {
                return unitList;
            },
            addUnitsofMeasure : function(unitsofMeasure) {
                var temp = {
                    ID: elementId++,
                    name: unitsofMeasure.name,
                    desc: unitsofMeasure.desc,
                    useMeasuring: unitsofMeasure.useMeasuring,
                    posScreenPrompt: unitsofMeasure.posScreenPrompt,
                    measuringUnit: unitsofMeasure.measuringUnit,
                    units: angular.copy(unitList)
                }

                unitsofMeasures.push(temp);
            },
            addUnitValue : function(unit,unitsofMeasure) {
                var unitsofMeasureIndex = unitsofMeasures.findIndex(UnitsofMeasure => UnitsofMeasure.ID == unitsofMeasure.ID);
                var unitLength = unitsofMeasures[unitsofMeasureIndex].units.length - 1
                var temp = {
                    ID: unitsofMeasures[unitsofMeasureIndex].units[unitLength].ID + 1,
                    unitSymbol: unit.unitSymbol,
                    unitDesc: unit.unitDesc,
                    isEqualTo: (unit.isEqualTo != undefined ? unit.isEqualTo : 0),
                    toUnit: unit.toUnit
                }

                unitsofMeasures[unitsofMeasureIndex].units.push(temp);
            },
            deleteUnitsofMeasure: function(item) {
                var index = unitsofMeasures.findIndex(unitsofMeasure => unitsofMeasure.ID == item.ID);
                unitsofMeasures.splice(index, 1);
            },
            deleteUnitValue: function(unitsofMeasure, unit) {
                var unitsofMeasureIndex = unitsofMeasures.findIndex(UnitsofMeasure => UnitsofMeasure.ID == unitsofMeasure.ID);
                var unitIndex = unitsofMeasures[unitsofMeasureIndex].units.findIndex(Unit => Unit.ID == unit.ID);
                unitsofMeasures[unitsofMeasureIndex].units.splice(unitIndex, 1);
            },
            saveUnitsofMeasure: function(item,unitsofMeasure) {
                var index = unitsofMeasures.findIndex(unitsofMeasure => unitsofMeasure.ID == item.ID);
                unitsofMeasures[index].name = unitsofMeasure.name;
                unitsofMeasures[index].desc = unitsofMeasure.desc;
                unitsofMeasures[index].useMeasuring = unitsofMeasure.useMeasuring;
                unitsofMeasures[index].posScreenPrompt = unitsofMeasure.posScreenPrompt;
                unitsofMeasures[index].measuringUnit = unitsofMeasure.measuringUnit;
			},
            saveUnitValue: function(unitsofMeasure, unit, newUnit) {
                var unitsofMeasureIndex = unitsofMeasures.findIndex(UnitsofMeasure => UnitsofMeasure.ID == unitsofMeasure.ID);
                var unitIndex = unitsofMeasures[unitsofMeasureIndex].units.findIndex(Unit => Unit.ID == unit.ID);
                unitsofMeasures[unitsofMeasureIndex].units[unitIndex].unitSymbol = newUnit.unitSymbol;
                unitsofMeasures[unitsofMeasureIndex].units[unitIndex].unitDesc = newUnit.unitDesc;
                unitsofMeasures[unitsofMeasureIndex].units[unitIndex].isEqualTo = (newUnit.isEqualTo != undefined ? newUnit.isEqualTo : 0);
                unitsofMeasures[unitsofMeasureIndex].units[unitIndex].toUnit = newUnit.toUnit;
            },
			getUnitsofMeasureByIndex : function(item) {
                var tempUnitofMeasure = angular.copy(unitsofMeasures.filter(unitsofMeasure => unitsofMeasure.ID == item.ID)[0]);
                tempUnitofMeasure.units = $filter('filter')(tempUnitofMeasure.units, {unitSymbol: tempUnitofMeasure.measuringUnit})
                return tempUnitofMeasure; 
            },
            getUnitValuebyIndex : function(unitsofMeasure, unit) {
                var unitsofMeasureIndex = unitsofMeasures.findIndex(UnitsofMeasure => UnitsofMeasure.ID == unitsofMeasure.ID);
                return unitsofMeasures[unitsofMeasureIndex].units.filter(Unit => Unit.ID == unit.ID)[0];
            },
            getUnitsFromUnitsofMeasureByFiltering : function(unitsofMeasure) {
                var unitsofMeasureIndex = unitsofMeasures.findIndex(UnitsofMeasure => UnitsofMeasure.ID == unitsofMeasure.ID);
                return $filter('filter')(unitsofMeasures[unitsofMeasureIndex].units, {unitSymbol: unitsofMeasure.measuringUnit})
            }
		};
    });

    module.directive('selectOnClick', ['$window', function ($window) {
        if(ionic.Platform.isIOS()) {
            return {
                restrict: 'A',
                link: function (scope, element, attrs) {
                    element.on('click', function () {
                        if (!$window.getSelection().toString()) {
                            this.setSelectionRange(0, this.value.length)
                        }
                    });
                }
            };
        }
        else {
            return {
                restrict: 'A',
                link: function (scope, element) {
                    var focusedElement;
                    element.on('click', function () {
                        this.select();
                        focusedElement = this;
                    });
                    element.on('blur', function () {
                        focusedElement = null;
                    });
                }
            };
        }
    }]);
    
	module.config(['$stateProvider', '$provide', '$urlRouterProvider',
	'$httpProvider', function ($stateProvider, $provide, $urlRouterProvider, $httpProvider) {
		$stateProvider
		.state('tab.unitsofmeasures', {
			url: '/unitsofmeasures',
			LoginRequired: true,
			views: {
				'tab-view': {
					templateUrl: 'modules/common_html/templates/view.html',
					controller: 'UnitsofMeasureController'
				}
			}
		})
		.state('tab.editunitsofmeasures', {
			url: '/editunitsofmeasure/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/unitsof_measures/templates/unitsof-measures-edit.html',
                    controller: 'EditUnitsofMeasureController'
				}
			}
		})
		.state('tab.addunitsofmeasures', {
			url: '/editunitsofmeasure/:name',
            LoginRequired: true,
            views: {
				'tab-view': {
					templateUrl: 'modules/unitsof_measures/templates/unitsof-measures-edit.html',
                    controller: 'AddUnitsofMeasureController'
				}
			}	
		})
        .state('tab.editunitsvalue', {
            url: '/editunitsvalue/:name/:unit',
            LoginRequired: true,
            views: {
                'tab-view': {
                    templateUrl: 'modules/unitsof_measures/templates/units-edit.html',
                    controller: 'EditUnitsValueController'
                }
            }
        })
        .state('tab.addunitsvalue', {
            url: '/editunitsvalue/:name',
            LoginRequired: true,
            views: {
                'tab-view': {
                    templateUrl: 'modules/unitsof_measures/templates/units-edit.html',
                    controller: 'AddUnitsValueController'
                }
            }   
        })
	}]);

    module.controller('UnitsofMeasureController', function($scope,$state,$ionicPopup,$filter,$rootScope,$ionicScrollDelegate,unitsofMeasureFactory){
        $scope.selectedItem = null;
        $scope.itemSelected = false;
        $scope.title = "Manage Units of Measures";
        $scope.searchTitle = "Units of Measures";

        
       

        
            
            {
        }

        $scope.gotoAddEditPage = function(pagename){
            if(pagename == 'edit' && $scope.selectedItem != null){
                $state.go('tab.editunitsofmeasures',{name: JSON.stringify($scope.selectedItem)});
            }
            if(pagename == 'add'){
                $state.go('tab.addunitsofmeasures',{name: 'add'});
            } 
        }

        $scope.setSelectedItem = function(item) {
            $scope.selectedItem = item;
            $scope.itemSelected = true;
        }

        $scope.clearSelectedItem = function() {
            $scope.selectedItem = null;
            $scope.itemSelected = false;
        }

        $scope.deleteItem = function() {
            if($scope.selectedItem != null) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to delete?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        unitsofMeasureFactory.deleteUnitsofMeasure($scope.selectedItem);
                        $rootScope.$emit('updateUnitsofMeasures', {
                            editType: "Deleted"
                        });
                    }
                })
            }
        }

        $scope.searchItem = function() {
            $scope.entries = angular.copy(unitsofMeasureFactory.getUnitsofMeasures($scope.searchContent));
            $scope.showContent = true;
            $scope.clearSelectedItem();
            $scope.scrollMainToTop();
        }
        
        $rootScope.$on('updateUnitsofMeasures', function(event, arg) {
            $scope.entries = angular.copy(unitsofMeasureFactory.getUnitsofMeasures($scope.searchContent));
        });
        
        $scope.scrollMainToTop = function() {
             $ionicScrollDelegate.$getByHandle('mainScroll').scrollTop();
        };
    })

    module.controller('EditUnitsofMeasureController', function($scope,$rootScope,$state,$stateParams,$ionicPopup,$ionicHistory,unitsofMeasureFactory){
        $scope.selectedItem = angular.copy(JSON.parse($stateParams.name));
        $scope.unitsofMeasure = angular.copy(unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem));
        $scope.searchTitle = $scope.unitsofMeasure.name;
        $scope.title = "Edit Units of Measure";

        $rootScope.$on('updateUnitsOfMeasuresUnits', function (event, arg) {
            $scope.unitsofMeasure.units = angular.copy(unitsofMeasureFactory.getUnitsFromUnitsofMeasureByFiltering(arg.unitsofMeasures));

        });

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.unitsofMeasure.desc.length == 0) {
                $scope.unitsofMeasure.desc = $scope.unitsofMeasure.name;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.unitsofMeasure, unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitsofMeasure(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveUnitsofMeasure = function() {
            unitsofMeasureFactory.saveUnitsofMeasure($scope.selectedItem,$scope.unitsofMeasure);
            $rootScope.$emit('updateUnitsofMeasures', {
                editType: "Saved"
            });
            var popupMessage = $ionicPopup.alert( {
                title: 'Record saved successfully.',
                subTitle: ''
            })
        }

        $scope.clearUnitsofMeasure = function() {
            if(!angular.equals($scope.unitsofMeasure, unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitsofMeasure(); 
                    }
                    else{
                        $scope.unitsofMeasure = angular.copy(unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem));
                    }
                })
            }
        }

        $scope.deleteUnitsofMeasure = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    unitsofMeasureFactory.deleteUnitsofMeasure($scope.selectedItem);
                    $rootScope.$emit('updateUnitsofMeasures', {
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.unitsofMeasure, unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.unitsofMeasure = angular.copy(unitsofMeasureFactory.getUnitsofMeasureByIndex($scope.selectedItem));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.addUnits = function() {
            $state.go('tab.addunitsvalue',{name: JSON.stringify($scope.unitsofMeasure)});
        }

        $scope.editUnitsValue = function(unit) {
            $state.go('tab.editunitsvalue',{name: JSON.stringify($scope.unitsofMeasure), unit: JSON.stringify(unit)});
        }

        $scope.searchUnit = function() {
            $scope.unitsofMeasure.units = angular.copy(unitsofMeasureFactory.getUnitsFromUnitsofMeasureByFiltering($scope.unitsofMeasure));
        }
    })

    module.controller('AddUnitsofMeasureController', function($scope,$ionicPopup,$ionicHistory,$rootScope,unitsofMeasureFactory){
        $scope.showSearchbar = true;
        $scope.title = "Add Units of Measure";

        $scope.unitsofMeasure = {
            name : "",
            desc : "",
            posScreenPrompt: "",
            measuringUnit: "",
            useMeasuring: false,
            units: angular.copy(unitsofMeasureFactory.getUnitList())
        }
        var oriUnitsofMeasure = angular.copy($scope.unitsofMeasure);

        $scope.autoFillDescription = function() {
            if($scope.unitsofMeasure.desc.length == 0) {
                $scope.unitsofMeasure.desc = angular.copy($scope.unitsofMeasure.name);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.unitsofMeasure, oriUnitsofMeasure)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitsofMeasure(); 
                    }
                    $ionicHistory.goBack();
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveUnitsofMeasure = function() {
            if(!angular.equals($scope.unitsofMeasure, oriUnitsofMeasure)) {
                unitsofMeasureFactory.addUnitsofMeasure($scope.unitsofMeasure);
                $rootScope.$emit('updateUnitsofMeasures', {
                    editType: "Added"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                }).then(function() {
                    $scope.unitsofMeasure = angular.copy(oriUnitsofMeasure);
                })
            }
        }

        $scope.addUnitsofMeasure = function() {
            $scope.clearUnitsofMeasure();
        }

        $scope.clearUnitsofMeasure = function() {
            if(!angular.equals($scope.unitsofMeasure, oriUnitsofMeasure)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitsofMeasure(); 
                    }
                    $scope.unitsofMeasure = angular.copy(oriUnitsofMeasure);
                })
            }
        }

        $scope.cancelEdit = function() {
            if(!angular.equals($scope.unitsofMeasure, oriUnitsofMeasure)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.unitsofMeasure = angular.copy(oriUnitsofMeasure); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('EditUnitsValueController', function($scope,$rootScope,$state,$stateParams,$ionicPopup,$ionicHistory,unitsofMeasureFactory){
        $scope.selectedUnitsOfMeasure = angular.copy(JSON.parse($stateParams.name));
        $scope.selectedUnit = angular.copy(JSON.parse($stateParams.unit));
        $scope.unit = angular.copy(unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit));
        $scope.searchTitle = $scope.unit.unitSymbol;
        $scope.title = "Edit Units Value";

        
       

        
            
            {
        }

        $scope.autoFillDescription = function() {
            if($scope.unit.unitDesc.length == 0) {
                $scope.unit.unitDesc = $scope.unit.unitSymbol;
            }
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.unit, unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            unitsofMeasureFactory.saveUnitValue($scope.selectedUnitsOfMeasure, $scope.selectedUnit, $scope.unit);
                            $rootScope.$emit('updateUnitsOfMeasuresUnits', {
                                unitsofMeasures: $scope.selectedUnitsOfMeasure,
                                editType: "Saved"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        }
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
        
        $scope.saveUnitValue = function() {
            var errorCheck = document.getElementsByClassName('error-message');
            var validity = true;
            for(var i = 0; i < errorCheck.length; i++) {
                if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                    validity = false;
                }
            }

            if(validity) {
                unitsofMeasureFactory.saveUnitValue($scope.selectedUnitsOfMeasure, $scope.selectedUnit, $scope.unit);
                $rootScope.$emit('updateUnitsOfMeasuresUnits', {
                    unitsofMeasures: $scope.selectedUnitsOfMeasure,
                    editType: "Saved"
                });
                var popupMessage = $ionicPopup.alert( {
                    title: 'Record saved successfully.',
                    subTitle: ''
                })
            } else {
                var popupMessage = $ionicPopup.alert( {
                    title: 'Invalid Input.',
                    subTitle: ''
                })
            }
        }

        $scope.clearUnitValue = function() {
            if(!angular.equals($scope.unit, unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitValue();
                    }
                    else{
                        $scope.unit = angular.copy(unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit));
                    }
                })
            }
        }

        $scope.deleteUnitValue = function() {
            var popupMessage = $ionicPopup.confirm( {
                title: 'Are you sure you want to delete?',
                cancelText: 'No',
                okText: 'Yes'
            }).then(function(val) {
                if(val == true){
                    unitsofMeasureFactory.deleteUnitValue($scope.selectedUnitsOfMeasure, $scope.selectedUnit);
                    $rootScope.$emit('updateUnitsOfMeasuresUnits', {
                        unitsofMeasures: $scope.selectedUnitsOfMeasure,
                        editType: "Deleted"
                    });
                    $ionicHistory.goBack(); 
                }
            })
        }

        $scope.cancelEditValue = function() {
            if(!angular.equals($scope.unit, unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit))) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.unit = angular.copy(unitsofMeasureFactory.getUnitValuebyIndex($scope.selectedUnitsOfMeasure, $scope.selectedUnit));
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })

    module.controller('AddUnitsValueController', function($scope,$rootScope,$stateParams,$ionicPopup,$ionicHistory,unitsofMeasureFactory){
        $scope.showSearchbar = true;
        $scope.selectedUnitsOfMeasure = angular.copy(JSON.parse($stateParams.name));
        $scope.title = "Add Units Value";
        $scope.unit = {
            unitSymbol : "",
            unitDesc : "",
            isEqualTo: 0,
            toUnit: ""
        }
        var oriUnit = angular.copy($scope.unit);

        $scope.autoFillDescription = function() {
            if($scope.unit.unitDesc.length == 0) {
                $scope.unit.unitDesc = angular.copy($scope.unit.unitSymbol);
            }
        }

        
       //var margintop = 75 + subtoppadding - 55;

        
            
            {
        }

        $scope.goBack = function() {
            if(!angular.equals($scope.unit, oriUnit)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        var errorCheck = document.getElementsByClassName('error-message');
                        var validity = true;
                        for(var i = 0; i < errorCheck.length; i++) {
                            if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                                validity = false;
                            }
                        }
            
                        if(validity) {
                            unitsofMeasureFactory.addUnitValue($scope.unit,$scope.selectedUnitsOfMeasure);
                            $rootScope.$emit('updateUnitsOfMeasuresUnits', {
                                unitsofMeasures: $scope.selectedUnitsOfMeasure,
                                editType: "Added"
                            });
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Record saved successfully.',
                                subTitle: ''
                            }).then(function() {
                                $scope.unit = angular.copy(oriUnit);
                            })
                            $ionicHistory.goBack();
                        } else {
                            var popupMessage = $ionicPopup.alert( {
                                title: 'Invalid Input.',
                                subTitle: ''
                            })
                        }
                    } else {
                        $ionicHistory.goBack();
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }

        $scope.saveUnitValue = function() {
            if(!angular.equals($scope.unit, oriUnit)) {
                var errorCheck = document.getElementsByClassName('error-message');
                var validity = true;
                for(var i = 0; i < errorCheck.length; i++) {
                    if(errorCheck[i].classList.length == 1 && errorCheck[i].classList[0] == "error-message") {
                        validity = false;
                    }
                }
    
                if(validity) {
                    unitsofMeasureFactory.addUnitValue($scope.unit,$scope.selectedUnitsOfMeasure);
                    $rootScope.$emit('updateUnitsOfMeasuresUnits', {
                        unitsofMeasures: $scope.selectedUnitsOfMeasure,
                        editType: "Added"
                    });
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Record saved successfully.',
                        subTitle: ''
                    }).then(function() {
                        $scope.unit = angular.copy(oriUnit);
                    })
                } else {
                    var popupMessage = $ionicPopup.alert( {
                        title: 'Invalid Input.',
                        subTitle: ''
                    })
                }
            }
        }

        $scope.addUnitValue = function() {
            $scope.clearUnitValue();
        }

        $scope.clearUnitValue = function() {
            if(!angular.equals($scope.unit, oriUnit)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Save or Cancel changes',
                    cancelText: '<a class="button button-positive icon ion-close-circled"></a>',
                    okText: '<a class="button button-positive icon ion-checkmark-circled"></a>',
                    cancelType: 'button-positive'
                }).then(function(val) {
                    if(val == true){
                        $scope.saveUnitValue(); 
                    }
                })
            }
        }

        $scope.cancelEditValue = function() {
            if(!angular.equals($scope.unit, oriUnit)) {
                var popupMessage = $ionicPopup.confirm( {
                    title: 'Are you sure you want to cancel?',
                    cancelText: 'No',
                    okText: 'Yes'
                }).then(function(val) {
                    if(val == true){
                        $scope.unit = angular.copy(oriUnit); 
                    }
                })
            }
            else {
                $ionicHistory.goBack();
            }
        }
    })
})();